
capture program drop factorZScore
program factorZScore, rclass

	syntax varlist(min=1)
	
	// prepare macros
	// - var_list: list of variables to be used in index
	// - Additional variables used on the side: pm_treatment miss_count index_name
	local remove_vars pm_treatment miss_count index_name
	local var_list : list varlist - remove_vars
	
	local ind_name = index_name[1] // still need to figure out how to call vars & macros
	
	
	********************************************************************************
	***** 1. standardize variables at country level 

	foreach var in `var_list' {
		
		quietly sum `var' 
		local `var'_mean `r(mean)'
		local `var'_sd	   `r(sd)'
		
		gen z_`var' = (`var' - ``var'_mean') / ``var'_sd'
	}
	
	// capture no. of vars to drop later if all are missing
	ds `var_list'
	local var_count : word count(`r(varlist)') 

	
	********************************************************************************
	***** 2. compute factor score weights (w_i) using factor loadings
		
	// compute control group’s loading on each component
	quietly factor `var_list' if pm_treatment == 0
	matrix loadings = e(L) // save matrix of all factors
	matrix A = loadings[1...,1] // store first factor
	matrix list A
	local n = rowsof(A) // capture no. of components

	//extract relative weights from first factor
	forval i = 1/`n' {
		local load_`i' = A[`i',1] // capture actual load
		mata : st_matrix("B", colsum(st_matrix("A"))) // capture sum of all loads
		local w_`i' = `load_`i''/B[1,1] // calculate relative load
	}
		
		// drop -ve weights to ignore components with opposite directions to what was hypothesized

		// CAUTION: ensure all variables increase in the same positive direction
		
		local dropped_vars 0
		forval i = 1/`n' {
			if `w_`i'' < 0 {
				local dropped_vars = `dropped_vars' + 1 // count dropped variable
				local w_`i' = 0 // drop negative weights
			}
			dis "`w_`i''"
		}
		dis in red "No. of vars dropped for opposite direction = `dropped_vars'"
	
	
	********************************************************************************
	***** 3. Compute Factor Score Weighted Mean (fsw_mean)

	local i = 0
	gen fsw_mean = 0 // if miss_count == 0 // Removed strict condition here following zindex approach
	foreach var in `var_list'{

		// make use of as much info as is available
		replace z_`var' = 0 if missing(z_`var') 

		// run thru the i's. They are as many as the vars by design
		local i = `i' + 1 

		// compute mean = w_1*z_var1 + ... + w_n*z_varn
		replace fsw_mean = fsw_mean + `w_`i'' * z_`var' 
	}

	* tab pm_treatment, sum(fsw_mean) // control mean = 0. but sd != 1


	********************************************************************************
	***** 4. Standardize Factor Score Weighted Mean (fsw_mean)

	quietly sum fsw_mean if pm_treatment == 0
	local ctrl_mean_fsw_mean = `r(mean)'
	local ctrl_sd_fsw_mean = `r(sd)'
	gen `ind_name'_f_index = (fsw_mean - `ctrl_mean_fsw_mean') / `ctrl_sd_fsw_mean'

	replace `ind_name'_f_index = . if miss_count == `var_count' // set observations to missing if all components are missing
	drop fsw_mean z_* miss_count index_name // My inefficient process makes these necessary byproducts
	
end
