/*******************************************************************************
This is a program that fixes missing values in continuous variables.
	If a continuous variable is divisible by +/-
		1)  8 or 9 
			and any of 111, 1111, 11111, 111111, 1111111, or 11111111
		2)  8 or 9 
			and -11 (I assume -88 and -99 are true missings while 88 or 99 are plausible)
	
	then the respondent most likely tried to say they 
		- refused to answer (999)
		- didn't know (888)
*******************************************************************************/

capture prog drop fix_continuous
prog define fix_continuous
	syntax varlist

	dis as text "Checking for -88, -99, or (+/-) multiple of 8 or 9 * 1111, 1111, etc"
	foreach var in `varlist' {
		local countchanges 0
		local valueschanged ""
		foreach i in 8 9 {
			foreach divisor in 111 1111 11111 111111 1111111 11111111 {
				
				
				if `i' == 8 local recodeval ".d" // don't know
				if `i' == 9 local recodeval ".r" // refused
				
				local checkfor = `divisor' * `i'
				qui recode `var' (`checkfor' = `recodeval') ///  eg  8888
							 (-`checkfor' = `recodeval') /// eg -8888
								if mod(abs(`var'), `i') == 0 & /// 
								mod(abs(`var'), `divisor') == 0 & ///
								mod(abs(`var'), 10) != 0
								
				local countchanges = `countchanges' + `r(N)'
				if `r(N)' > 0 local valueschanged "`valueschanged'" " " "`checkfor'"
			}
			foreach divisor in 11 {
				
				if `i' == 8 local recodeval ".d" // don't know
				if `i' == 9 local recodeval ".r" // refused
				
				local checkfor = `divisor' * `i'
				qui recode `var' (-`checkfor' = `recodeval') /// -88 or -99
								if mod(abs(`var'), `i') == 0 & /// 
								mod(abs(`var'), `divisor') == 0 & ///
								mod(abs(`var'), 10) != 0
				local countchanges = `countchanges' + `r(N)'
				if `r(N)' > 0 local valueschanged "`valueschanged'" " " "`checkfor'"
			}
		}
		dis "For variable `var'"
		dis "  Total recodes: `countchanges'"
		dis "  Values changed: `valueschanged'"
// 		sleep 2000 // hold script here for 2 seconds
	}

	
end



