/*******************************************************************************
This program generates locals and adds to stored estimates (estadd) 
- control mean
- control SD
- share of zeros in control (returns % as string with 0 d.p.)
- add control BL mark 
- add permutation T-statistic
*******************************************************************************/

capture prog drop reg_stats
program define reg_stats, rclass
	syntax varlist(max=3 numeric), var_count(integer)							///
									[bl_ctrl_var(string) cluster_var(string) 	///
									strata_var(string) weight_var(string) 		///
									perm(string) QUIetly]
	
	nois dis as text "	- Running do-file: reg_stats"

	`quietly' {
		return add
		
		local var `1'                             // define input 1 as var
		local treatvar `2'                        // define input 2 as treatvar 
		local reg_obs = subinstr("`3'", ",","",.) // define input 3 as reg_obs and remove comma
		
		//---------------------------------
		// control mean and SD (BL optional)
		
		qui sum `var' if `treatvar' == 0 & `reg_obs' == 1
		qui loc ctrl_mean `r(mean)'											
		qui loc ctrl_sd `r(sd)'												
			
		matrix fu_mat = (`ctrl_mean', `ctrl_mean') // Two instead of four control means
		return mat fu_mat = fu_mat
			
		if abs(`ctrl_mean') < 0.00001 local ctrl_mean = abs(`ctrl_mean') // abs if practically zero
			
		foreach stat in mean sd { // round and store mean and sd
			qui loc round_`stat' : di %15.2f `ctrl_`stat''
			return loc control_`stat' `round_`stat''
			qui estadd local control_`stat' "`round_`stat''", replace
		}
		
		//---------------------------------
		// BL control mean
		if "`bl_ctrl_var'" != "" {   // save mean of continuous bl control var if no het var for control treatment
			qui sum `bl_ctrl_var' if `treatvar' == 0 & `reg_obs' == 1, detail
			qui loc blctrl_mean `r(mean)'
			if abs(`blctrl_mean') < 0.00001 local blctrl_mean = abs(`blctrl_mean') // abs if practically zero
			loc round_mean_bl : di %15.2f `blctrl_mean'
			qui estadd local control_mean_bl "`round_mean_bl'", replace        
		}
		else {
			qui estadd local control_mean_bl " ", replace
		}
		return loc control_mean_bl `round_mean_bl'
		
		//---------------------------------
		// add BL control mean mark
		capture confirm variable `var'_tr_bl
		if _rc == 0 {
			 local markhere "$\approx$" // similar
		}
		else if _rc != 0 {
			capture confirm variable `var'_bl
			if _rc == 0 {
				local markhere "\checkmark" // exact
			}
			else if _rc != 0 {
				local markhere "$\times$" // dne
			}
		}
		qui estadd local control_mean_mark "`markhere'", replace
		return loc control_mean_mark "`markhere'"
		
		//---------------------------------
		// share of zeros in the control group
		// % of 0s of dependent var for control treatment if no het var for control treatment
		qui count if `treatvar' == 0 & `reg_obs' == 1 
		dis "`r(N)': control group size"
		local ctrl_n = "`r(N)'"

		qui count if `treatvar' == 0 & `var' == 0 & `reg_obs' == 1 
		dis "`r(N)': zeros in control"
		local ctrl_zeros = "`r(N)'"

		if `ctrl_n' != 0 {
			local zero_share : di %5.0fc `ctrl_zeros'/`ctrl_n' * 100
			qui estadd local ctrl_0_share = "`zero_share'\%", replace
			return local ctrl_0_share "`zero_share'\%"
		}
		else if `ctrl_n' == 0 {
			local zero_share : di %5.0fc `ctrl_zeros'/`ctrl_n' // inf.
			qui estadd local ctrl_0_share = "`zero_share'", replace
			return local ctrl_0_share "`zero_share'"
		}
		
		//---------------------------------
		// permutation T-statistic
		if "`perm'" != "" {
				qui ritest `treatvar' _b[`treatvar']/_se[`treatvar'], reps(${n_reps}) 		///
				seed(${n_seed}) strata(`strata_var') cluster(`cluster_var') nodots force: 	///
				reg `var' `treatvar' i.`strata_var' [pw = `weight_var'] 					///
				if `reg_obs' == 1, cluster(`cluster_var')		
				
				local tpv = r(b)[1,1]
				local ppv = r(p)[1,1]
				local permute_test  : di %15.2fc `tpv'
				if 		`ppv' < 0.01 local symbol "\sym{***}"
				else if `ppv' < 0.05 local symbol "\sym{**}"
				else if `ppv' < 0.10 local symbol "\sym{*}"
				else 				 local symbol ""
				local t_mgnpt = "`permute_test'`symbol'"
				qui estadd local mgnpt = "`t_mgnpt'", replace : est`var_count'		
				return local mgnpt "mgnpt"						
		}
	}
end
