/*******************************************************************************
To be run from inside the regs program
Define list of variables for each regression table.
*******************************************************************************/

capture prog drop regs_vars
program define regs_vars, rclass

	nois dis "	- Running do-file: regs_vars"

	**** Define Tables 
	
	****************************************************************************
	** PRIMARY OUTCOMES DIRECT TREATMENT 
	
		
	forvalues i = 1/4 {		
		
		* 1. Household Welfare (Primary Outcomes)

		return	local prim1_hh_t`i' 	consum_day_eq_xof food_day_eq_xof nonfood_day_eq_xof 	///
										FIES_rvrs_raw diversity_score FCS food_index4	
		
		return	local prim1_hh1_t`i' 	consum_day_pc_xof food_day_pc_xof nonfood_day_pc_xof 	///
										FIES_rvrs_raw diversity_score FCS food_index6	
		
		return	local prim1_hh2_t`i' 	consum_day_xof food_day_xof nonfood_day_xof 			///
										FIES_rvrs_raw diversity_score FCS food_index5
									
		* 2. Beneficiary Welfare (Primary Outcomes)
		
		return	local prim2_beno_t`i' 	share_ben_revenues ctrl_hh_index intrahh_vars_index		///
										fin_supp_index_2 social_support_index soc_stand_index	///
										collective_action_index soc_cohsn_index ment_hlth_index ///
										gse_index future_expct_index
	
		* 3. Agricultural Outcomes
		
		return	local prim3_ben_t`i'	ctben_ag_12 ag_plot_ha_benef 							///
										tot_ben_ag_days_omben tot_ben_nom_ag_days 				///
										tot_hhlb_ag_days_omben 									/// tot_hhlb_ag_days ag_r_hrv_day_ben_xof_imp 
										ag_r_hrv_ben_xof_imp_98	 						
																	
		return	local prim3_chef_t`i'	hhh_ag_12 ag_plot_ha_chef 								///
										tot_chef_ag_days_omchef tot_chef_nom_ag_days			///
										tot_hhlc_ag_days_omchef 								/// tot_hhlc_ag_days ag_r_hrv_day_chef_xof_imp
										ag_r_hrv_chef_xof_imp_98  						
																
		* 4. Non-Ag Activities Outcomes 
									
		return local prim4_ben_t`i'		ctben_na_12 na_bus2_op_wn_12_ben 						///
										tot_ben_bus_days tot_ben_rev12_98 						/// 
										tot_ben_pro12_98 tot_busmths_uniq_ben 					///
										bus_assval_98_ben 										///
										business_closure_ben input_regional_market_ben 
									
		return local prim4_chef_t`i' 	hhh_na_12 na_bus2_op_wn_12_chef tot_chef_bus_days 		///
										tot_chef_rev12_98 tot_chef_pro12_98 					///
										tot_busmths_uniq_chef bus_assval_98_chef 				///
										business_closure_chef input_regional_market_chef											
																																														
		* 5. Salaried Employment: 
		
		return local prim5_ben_t`i' 	sal_empl_ben tot_empl_time_month_ben 					///
										tot_empl_rev12_ben_xof ag_empl_ben 						///
										tot_ag_time_month_ben tot_ag_empl_rev12_ben_xof   	
											
		return local prim5b_ben_t`i' 	nonag_empl_ben tot_nonag_time_month_ben 				///
										tot_nonag_empl_rev12_ben_xof

		return local prim5_chef_t`i' 	sal_empl_chef tot_empl_time_month_chef 					///
										tot_empl_rev12_chef_xof ag_empl_chef 					///
										tot_ag_time_month_chef tot_ag_empl_rev12_chef_xof   		
		
		return local prim5b_chef_t`i' 	nonag_empl_chef tot_nonag_time_month_chef 				///
										tot_nonag_empl_rev12_chef_xof
											
		* 6. Livestock and Savings 
		
		return local  prim6_ben_t`i' 	ctben_liv_12 tot_ben_liv_days tot_ani_ben_contr_98 		///
										tot_ani_count_tlu_ben tot_bt_tontine_d saving_xof 
									
		return local prim6_chef_t`i' 	hhh_liv_12 tot_chef_liv_days tot_ani_chef_contr_98 		///
										tot_ani_count_tlu_chef
		
		* 7. Secondary Agriculture
		return local scnd7_t`i'		ag_plot_n ag_plot_ha ag_r_hrv_xof_imp_98 ag_input_index 	///
									ag_r_seeds_d ag_r_fert_d ag_r_pest_d ag_r_paidlab_d 		// ag_hrv_12_xof_imp_98
		return local scnd6_t`i'		ag_r_seeds_d ag_r_fert_d ag_r_pest_d ag_r_paidlab_d
		
		* 8. Secondary Business
		return local scnd8_t`i'		bus2_dum na_bus2_op_wn_12 na_bus2_op_wn_12_joint_s 			///
									tot_hh_rev12_98 tot_hh_pro12_98 							///
									bus_assval_98 tot_busmths_uniq bus_activity_index2 			///
									business_closure_hh input_regional_market_hh

		* 9. Secondary Livestock 
		return local scnd9_t`i' 	ani_hh_dum div_ani tot_ani_count_tlu tot_ani_hh_contr_98 	///
									liv_bov liv_ane liv_cham liv_chev liv_cap liv_ov liv_vol
		
		* 10. Non-Standardized Consumption and Food Security
		return local scnd5_t`i' 	z_food_day_eq_xof z_nonfood_day_eq_xof z_FIES_rvrs_raw 		///
									z_FCS_W z_diversity_score food_index4
									
		************************************************************************
		* Supplementary Tables: 
	
		* 1. Non-Standardized Consumption and Food Security
		return local supp_9_t`i' 	non_livestock_index ag_asset_index 							///
									tot_cred_amt_d tot_cred_amt_xof  							///
									loan_out_d loan_out_xof 									///		
									trans_out_d tot_trans_out_xof								///
									trans_in_d tot_trans_in_xof
						
		return local supp_10_t`i' 	food_day_prod_eq_xof food_day_buy_eq_xof 					///
									food_day_gift_eq_xof		
									
		* 2. Productive Measures Compliance
		return local supp_25_t`i' 	mes_participe mes_avec_d mes_germe_d mes_coach_d 			///
									mes_bourse_d mes_one mes_two 
					  
		* 3. Agricultural Outcomes by Main Crops 
		return local supp_26_t`i' 	Sésame_d Arachide_d Mil_d Sorgho_d Sésame_sold_d 			///
									Arachide_sold_d Mil_sold_d Sorgho_sold_d
												   
		* 4. Mental Health Index Components 
		return local supp_27_t`i' 	ment_hlth_index less_depressed less_disability 				///
									stair_satis_today stairs_peace health_ment_z
				
		* 5. Self-Efficacy Index Components 
		return local supp_28_t`i'	gse_index gse1 gse3 gse4 gse7 gse8 gse9 ros4 
					   				
		* 6. Future Expectations Index Components 
		return local supp_29_t`i'	future_expct_index stair_status_future_new 					///
									stair_satis_future_new 					   
									
		* 7. Social Support Index Components 
		return local supp_30_t`i' 	social_support_index role soc_tips soc_tips_in 				///
									soc_confl soc_confl_in other_market

		* 8. Financial Support Index Components 
		return local supp_31_t`i' 	fin_supp_index_2 accesstofunds_rvrs ask_siblings 			///
									ask_otherfam ask_friends ask_otherknown ce3_new
								
		* 9. Social Standing Index Components 
		return local supp_32_t`i'	soc_stand_index stair_good_today_new stair_respect_new 		///
									stair_opinion_new stair_status_today
																
		* 10. Social Cohesion & Community Closeness Index Components 
		return local supp_33_t`i'	soc_cohsn_index aff_ieff for_trust1 enemy_rvrs 				///
									tens_comm_rvrs los2
		
		* 11. Collection Action Index Components 
		return local supp_34_t`i' 	collective_action_index partic soc_post 					///
									aut_fond_xof_w aut_volu worktogether_new
									
		* 12. Intra-HH Dynamics Index Components 
		return local supp_35_t`i' 	intrahh_vars_index partner_vars_index rel_disagree 			///
									rel_interest los3 hh_vars_index emp_move 					///
									tens_house_rvrs los1 
															
		* 14. Control Over HH Resources Index Components 	
		return local supp_37_t`i' 	ctrl_hh_index dec_pow_spend dec_pow_large dec_pow_fert 		///
									dec_pow_care dec_pow_his_earn dec_pow_edu dec_could_spend 	///
									dec_could_large dec_could_fert dec_could_care

		* 15. Perceptions of Productive Measures: 
		return local supp_38_t`i' 	mes_select1 mes_select2 mes_select3 mes_select4 			///
									mes_select5 mes_select6 mes_equi
									
		* 16. Perceptions of Productive Measures 2: 
		return local supp_39_t`i' 	mes_better1 mes_better2 mes_better3 mes_better4 mes_better5 ///
									mes_better_ten mes_husband1 mes_husband2 mes_husband3 		///
									mes_husband_ten 	
		
		* 17. Perceptions of Cash Transfers: 
		return local supp_40_t`i' 	perc_whynotselect1 perc_whynotselect2 perc_whynotselect3 	///
									perc_whynotselect4 perc_whynotselect5 perc_whynotselect6 	///
									perc_hhdiff_poorer perc_hhdiff_richer perc_hhdiff_none 		///
									perc_equi 								
									
		* 18. Perceptions of Cash Transfers 2: 
		return local supp_41_t`i' 	perc_select_steps_1 perc_select_steps_2 perc_select_steps_3 ///
									perc_intrahh_tensions0 perc_intrahh_tensions1 				///
									perc_intrahh_tensions2 perc_intrahh_tensions3 				///
									perc_tensions_improved perc_tensions_deteriorated 			///
									perc_tensions_notaffected perc_tens_per
		
		* 19. Perceptions of Cash Trasnfers 3: 
		return local supp_42_t`i' 	perc_confiance0 perc_confiance1 perc_confiance2 			///
									perc_soutien0 perc_soutien1 perc_soutien2 					///
									perc_engagement0 perc_engagement1 perc_engagement2 			///
									perc_proximite0 perc_proximite1 perc_proximite2

		* 20. Household Transfers Received	
		return local supp_43_t`i' 	trans_in_d tot_trans_in_xof trans_invill_d 					///
									tot_trans_invill_xof trans_in_ben_d tot_trans_in_ben_xof 	///
									trans_invill_ben_d tot_trans_invill_ben_xof 
						
		* 21. Household Transfers Sent Out
		return local supp_44_t`i' 	trans_out_d tot_trans_out_xof trans_outvill_d 				///
									tot_trans_outvill_xof trans_out_ben_d tot_trans_out_ben_xof ///
									trans_outvill_ben_d tot_trans_outvill_ben_xof gross_trans_xof
	}

	**** Exports 
	return local all_sections 		prim1_hh_t1 prim1_hh_t2						///
									prim1_hh_t3 prim1_hh_t4						///
									prim2_beno_t1 prim2_beno_t2					///
									prim3_ben_t1 prim3_chef_t1					///
									prim4_ben_t1 prim4_chef_t1					///
									prim5_ben_t1 prim5_chef_t1					///
									prim6_ben_t1 prim6_chef_t1					///
									prim3_ben_t2 prim3_chef_t2					///
									prim4_ben_t2 prim4_chef_t2					///
									prim5_ben_t2 prim5_chef_t2					///
									prim6_ben_t2 prim6_chef_t2					///	
									prim3_ben_t3 prim3_ben_t4					///
									prim4_ben_t3 prim4_ben_t4					///					
									prim6_ben_t3 prim6_ben_t4					///
									prim3_chef_t3 prim3_chef_t4					///
									prim4_chef_t3 prim4_chef_t4					///								
									prim6_chef_t3 prim6_chef_t4					///	
									scnd6_t1 scnd6_t2  							///
									scnd5_t1 scnd5_t2 scnd5_t3 scnd5_t4 		///
									supp_10_t1 supp_10_t2 supp_10_t3 supp_10_t4 ///
									supp_27_t1 supp_27_t2 supp_27_t3 supp_27_t4 ///									
									supp_28_t1 supp_28_t2 supp_28_t3 supp_28_t4 ///									
									supp_29_t1 supp_29_t2 supp_29_t3 supp_29_t4 ///		
									supp_30_t1 supp_30_t2 supp_30_t3 supp_30_t4 ///									
									supp_31_t1 supp_31_t2 supp_31_t3 supp_31_t4 ///	
									supp_32_t1 supp_32_t2 supp_32_t3 supp_32_t4 ///	
									supp_33_t1 supp_33_t2 supp_33_t3 supp_33_t4 ///	
									supp_34_t1 supp_34_t2 supp_34_t3 supp_34_t4 ///	
									supp_35_t1 supp_35_t2 supp_35_t3 supp_35_t4 ///									
									supp_37_t1 supp_37_t2 supp_37_t3 supp_37_t4 //									
end
