/*****************************************************************************
Title: 00_clean_rand_strata
Creating randomization strata.

Input: ${pmt}/PMT_DATA_HH_FINAL_revisedv2.dta
Output: ${ed}/sample_bl.dta, ${ed}/sample_fu.dta, ${ed}/sample_pop.dta
*****************************************************************************/

	****************************************************************************
	* -------------- I. Generate Strata ---------------- *
	****************************************************************************

	use "${pmt}/PMT_DATA_HH_FINAL_revisedv2.dta", clear
	keep hhid ben_i hhsize PMT fcs_profile village region cantonpop superficie*	

	** Village level variables

	distinct village // There are 115 beneficiarie villages
	
	bys village: egen numBeneficiary=sum(ben_i)

	// For land unit conversion, assumes Cord= 1/2 hectare
	gen AgLandHH=superficieterre
	replace AgLandHH=AgLandHH*0.0001 if superficieterreunite==2
	replace AgLandHH=AgLandHH*0.5 if superficieterreunite==3

	bys village: egen AgLandVill=mean(AgLandHH)
	bys village: egen popVill=sum(hhsize)
	bys village: egen avgVilPMT=mean(PMT)

	/*
		Stratified by region and indicators for village size, agricultural land, PMT scores
		drop all village with less than 10 beneficiaries 
	*/

	xtile land=AgLandVill, nq(2)
	xtile population=popVill, nq(2)
	xtile wealth=avgVilPMT, nq(2)

	duplicates drop village, force 
	drop if numBeneficiary<10

	gen strata =  . 
	replace strata = 1  if region == 1 & land == 1 & population == 1 & wealth == 1
	replace strata = 2  if region == 1 & land == 1 & population == 1 & wealth == 2
	replace strata = 3  if region == 1 & land == 1 & population == 2 & wealth == 2
	replace strata = 4  if region == 1 & land == 1 & population == 2 & wealth == 1
		
	replace strata = 5  if region == 2 & land == 2 & population == 1 & wealth == 1
	replace strata = 6  if region == 2 & land == 2 & population == 1 & wealth == 2
	replace strata = 7  if region == 2 & land == 2 & population == 2 & wealth == 2
	replace strata = 8  if region == 2 & land == 2 & population == 2 & wealth == 1
		
	replace strata = 9  if region == 1 & land == 2 & population == 1 & wealth == 1
	replace strata = 10 if region == 1 & land == 2 & population == 1 & wealth == 2
	replace strata = 11 if region == 1 & land == 2 & population == 2 & wealth == 2
	replace strata = 12 if region == 1 & land == 2 & population == 2 & wealth == 1
		
	replace strata = 13 if region == 2 & land == 1 & population == 1 & wealth == 1
	replace strata = 14 if region == 2 & land == 1 & population == 1 & wealth == 2
	replace strata = 15 if region == 2 & land == 1 & population == 2 & wealth == 2
	replace strata = 16 if region == 2 & land == 1 & population == 2 & wealth == 1
	
	
	****************************************************************************
	* -------------- II. Select study population samples ---------------- *
	****************************************************************************
	
	// exclude villages with equal or fewer than 20 household beneficiaries 
	keep if numBeneficiary >= 20
	keep village strata
	tempfile data_village
	save 	`data_village'

	// bring in treatment_status 
	use "${pmt}/PMT_DATA_HH_FINAL_revisedv2.dta", clear
	merge 1:1 hhid using "${pop}/all_villages.dta", gen(status)
	merge m:1 village using `data_village', gen(village_study)
	keep if village_study == 3
	
	local keep_vars hhid region sousprefecture canton village 		/// 
					treatVill treatment_status pm_treatment strata	///
					sampled_fu sampled_bl
	keep  `keep_vars'
	order `keep_vars'
	
	foreach var in region sousprefecture canton village {
		rename `var' p_`var'
	}
	
	// experimental design sample data
	foreach rd in bl fu {
		preserve 
			keep if sampled_`rd' == 1
			save "${ed}/sample_`rd'", replace
		restore 		
	}

	// experimental design population data
	save "${ed}/sample_pop", replace
		