/*****************************************************************************
Title: 01_clean_preparation
Prepare Chad Baseline Data
	Outline:
	1. Prepare household data
	2. Prepare household member data
	3. Prepare data by survey section and save each file in long and wide format
*****************************************************************************/
  
	****************************************************************************
	*--------------------- I. Prepare household data --------------------------*
	****************************************************************************

	** a. prep main file
	*------------------- 
	
	* Variable types changed during SurveyCTO import -- fix

	use 			"${deidentified_${phase}}/tchad_ie_baseline9.dta", clear
	drop if 		hhid==. // those observations are empty.

	qui ds activity* consolactivity* plot_name*, has(type numeric)
	foreach var in `r(varlist)' {
		tostring 	`var', replace
	}

	tempfile 		main_file
	save 			`main_file'

	*prep intro
	gen 		__PRELOADED__ = "Preloaded informtation"
	order		__PRELOADED__, before(p_region_code)

	label var 	p_region_code 			"Preloaded region"
	label var 	p_sousprefecture_code 	"Preloaded sous-prefecture"
	label var 	p_sousprefecture_txt  	"Preloaded sous-prefecture"
	label var 	p_canton_code 			"Preloaded canton"
	label var 	p_village_code 			"Preloaded village"
	label var 	p_hhsize 				"Preloaded household size"
	label var 	p_benef_pos 			"Preloaded  position"
	label var	tel_works 				"Preloaded phone works"
	
	merge 1:1 hhid using "${ed}/sample_${ph}.dta", gen(merge_population)
	keep if merge_population == 3
	drop merge_population strata
	
	gen ben_i_FINAL = 0 
	replace ben_i_FINAL = 1 if inlist(treatment_status, 1, 2, 4)
	
	*save
	compress
	save "${intermediate_${phase}}/chad_main_2018", replace

	preserve
		keep 		hhid - list_chef benef  
		rename 		list_chef chef_pos
		label var	chef_pos 				"(Updated) Head of household position in household roster"
		label drop 	benef
		rename 		benef benef_pos
		label var	benef_pos "(Updated) CT Beneficiary position in household roster"
		gen 		benef_diff = 0 
		replace 	benef_diff = 1 if benef_pos != p_benef_pos
		label var 	benef_diff "(Updated) CT Beneficiary different from preloaded beneficiary"
		
		compress
		save "${intermediate_${phase}}/chad_hh_2018", replace
	restore

	
	****************************************************************************
	*----------------- II. Prepare household member data --------------------- *  
	****************************************************************************

	// put both surveycto loops over members together in same file (rpt_mem and rpt_mem2)

	// roster: name, age, sex, relation with household head, marital status
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_roster-rpt_mem.dta", clear

	*get position number of preloaded member
	split 		key, parse([ ])
	destring 	key2, gen(mem_pos)
	label var	mem_pos "Position in Roster"
	so 			hhid mem_pos
	order 		mem_pos, after(hhid)

	** drop variables
	drop 		parent_key key setof* key1 key2
	
	tempfile	 members
	save 		`members'

	** roster: marital status, education level, physical state/wellbeing
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_members-rpt_mem2.dta", clear

	** get position number of household member
	split 		key, parse([ ])
	destring 	key2, gen(mem_pos)
	label var 	mem_pos "Position in roster"
	so 			hhid mem_pos
	order 		mem_pos, after(hhid)

	** drop variables
	drop 		parent_key key setof* key1 key2

	tempfile 	members2
	save 		`members2'

	use 		`members'
	merge 1:1 	hhid mem_pos using `members2'

	order 		mem_pos, after(hhid)
	gen 		old_new = ""
	order 		old_new, after(mem_pos)
	replace 	old_new = "pre-loaded" if p_mem_id != ""
	replace 	old_new = "new this round" if p_mem_id == ""
	label var	old_new "preloaded member or new this round"
	drop 		p_mem_id

	***** Merge in beneficiary position
	merge m:1 	hhid using "${intermediate_${phase}}/chad_main_2018", ///
		keepusing(p_benef_pos benef ben_i_FINAL consent) gen(_merge2) 
	// Note: 81 hhds not matched (not surveyed actually: 1740-81=1659-1 hhd withou
	drop if 	consent == 0
	drop 		_merge2 consent

	gen 		p_benef = 1  if p_benef_pos ==  mem_pos & ben_i_FINAL==1
	order 		p_benef, after(p_marital_code)
	label		variable p_benef "preloaded CT beneficiary?"

	label drop 	benef
	gen 		is_benef = p_benef if mem_pos == benef 
	order 		is_benef, after(posif_chef)
	drop 		benef _merge add_new

	*** Labelling
	gen 		__Preloaded__ = "Preloaded member information"
	order 		__Preloaded__
		
	label var 	p_sex 			"Preloaded: sex"
	label var 	p_age 			"Preloaded: age"
	label var 	p_relation_code "Preloaded: relationship to preloaded household head"
	label values p_relation_code relation
	drop 		p_relation_txt
	rename 		p_relation_code p_relation
	label var 	p_marital_code 	"Preloaded: marital status"
	label values p_marital_code marital
	label var	still_member 	"Preloaded member is still a member of household"
	label var 	not_member_why 	"Why preloaded member not still a member of household"
	label var 	not_member_why_o "Other"

	gen 		__Updated__ = "Updated member information"
	order		__Updated__, before(still_member)
	drop 		posif_here
	order 		is_chef, before(posif_chef)
	label var 	is_chef "Is household head"
	rename 		posif_chef pos_chef
	order 		relation_o, after(relation)
	order 		rank_fem, after(relation_o)

	label var 	sex 			"Sex"
	label var 	age 			"Age"
	label var 	relation 		"Relation to household head"
	label var 	relation_o 		"Other"
	label var 	rank_fem 		"Seniority of wife"
	label var 	new_mem_why 	"Why was this member not preloaded as a household member"
	label var 	pos_chef 		"Chef position if this member is household head"

	drop 	    hh_mm_age // only needed in SurveyCTO
	label var 	hh_mm_key 		"Household head or beneficiary - key member for SurveyCTO"
	label var 	marital 		"Marital status"
	label var 	spouse_in 		"Is the spouse in the household"
	label var 	spouses 		"Who are the spouses in the household (roster position)"
	label var 	read 			"Can read"
	label var 	read_w 			"What languages can they read"

	compress
	save "${intermediate_${phase}}/members_long.dta", replace

	** add a prefix for reshape
	foreach var of varlist old_new - phy_work {
		rename `var' `var'_
	}
	reshape wide old_new_-phy_work_, i(hhid) j(mem_pos)

	// Save
	compress
	save "${intermediate_${phase}}/members_wide.dta", replace


	****************************************************************************
	*----------------- III. Prepare data by survey section ------------------- *
	****************************************************************************

	* ------------------------------------------------------------------------ *
	* ---------------------------- Prep Agriculture -------------------------- *
	* ------------------------------------------------------------------------ *
	
	* ------------------------------- Plots ---------------------------------- *

	// Main plot list
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_agriculture-section_plot-rpt_plots.dta", clear
	so  		hhid plot_pos

	** generate key
	split 		key, parse([ ])
	drop 		key1
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key2
	order 		__key__, after(hhid)

	compare 	__key__ plot_pos
	list 		hhid if __key__<plot_pos     
	* checking hhds for which  __key__ <plot_pos as shown from compare
	
	** not equal in hhid = 6730, 25431, 25500,  (replace plot_pos = __key__)
	replace 	plot_pos = __key__ 	if 	inlist(hhid, 6730, 25431, 25500)

	** clean strings
	ds, has(type string)
	foreach var in `r(varlist)' {
		replace `var' = trim(itrim(`var'))
	}

	** save
	compress
	tempfile	 main_plotlist
	save 		 `main_plotlist'

	// Dry plot list
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_agriculture-section_cropsdry1-rpt_plotdry", clear

	* convert variable types for append
	ds drycodeorother* dcropname*, has(type numeric)
	foreach var in `r(varlist)' {
		tostring `var', replace
	}

	tempfile 	plotdry2
	save 		`plotdry2'

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(hhid)
	so 			hhid __key__

	** ensure dcrop1_o - dcropname10 are strings
	ds 			dcrop1_o - dcropname10, has(type numeric)
	
	foreach var in `r(varlist)' {
		tostring `var', replace
	}

	** clean strings
	ds, has(type string)
	foreach var in `r(varlist)' {
		replace `var' = trim(itrim(`var'))
	}

	** drop missing observations
	drop if missing(dry_plot_name)

	** save
	compress
	tempfile 	main_dryplotlist
	save 		`main_dryplotlist'

	// Rain plot list
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_agriculture-section_cropsrain1-rpt_plotrain", clear

	* convert variable type for append
	ds 			raincodeorother* rcropname*, has(type numeric)
	foreach var in `r(varlist)' {
		tostring `var', replace
	}

	tempfile 	plotrain2
	save 		`plotrain2'

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	order 		__key__, after(hhid)
	drop 		parent_key key setofrpt* 

	so 			hhid __key__

	** ensure rcrop1_o - rcropname10 are strings
	ds 			rcrop1_o - rcropname10, has(type numeric)
	foreach var in `r(varlist)' {
		tostring `var', replace
	}

	** clean strings
	ds, has(type string)
	foreach var in `r(varlist)' {
		replace `var' = trim(itrim(`var'))
	}

	** drop missing observations
	drop if missing(rain_plot_name)

	** save
	compress
	tempfile 	main_rainplotlist
	save 		`main_rainplotlist'

	// Merge main_rainplotlist and main_dryplotlist
	use 		`main_rainplotlist', clear
	merge 1:1 	hhid __key__ using `main_dryplotlist' // Only 11 hhds matched!!
	drop 		_merge
	tempfile 	merged_plotlist
	save 		`merged_plotlist', replace

	use 		`main_plotlist', clear
	merge 1:1 	hhid __key__ using `merged_plotlist'
	drop 		_merge

	** clean
	drop if 	missing(plot_name)
	drop 		__key__

	** label variables
	label var 	plot_pos 			 "position dans la liste"
	label var 	plot_name 			 "parcelle"
	label var 	plot_ha 			 "taille de parcelle (hectares)"
	label var 	plot_key 			 "parcelle gere ou possede par la beneficiaire ou le chef du menage"
	label var 	plot_israin 		 "rain plot"
	label var 	plotpos_israinandkey "parcelle clef et pluviale"
	label var 	plot_isdry 			 "dry plot"
	label var 	plotpos_isdryandkey  "parcelle clef et seche"

	forvalues i = 1/60 {
	label var 	days_mem`i' 		 "nombre de jours que personne `i' a travaille sur la parcelle"
	}

	label var 	dry_plot_name 		 "parcelle - seche"

	forvalues i = 1/10 {
	label var 	drycodeorother`i' 	 "code ou nom de la culture - seche"
	label var 	dcropname`i' 		 "nom de la culture - seche"
	label var 	raincodeorother`i' 	 "code ou nom de la culture - pluviale"
	label var 	rcropname`i' 		 "nom de la culture - pluviale"
	}

	label var 	rain_plot_name 		 "parcelle - pluviale"
	label var 	plot_dry_harv 		 "les cultures recoltes sur la parcelle seche"
	label var 	plot_dry_sold 		 "les cultures vendus sur la parcelle seche"
	label var 	plot_rain_grew 		 "les cultures cultives sur la parcelle pluviale"
	label var 	plot_rain_harv 		 "les cultures recoltes sur la parcelle pluviale"
	label var 	plot_rain_sold 		 "les cultures vendus sur la parcelle pluviale"

	** save long
	compress
	save "${intermediate_${phase}}/main_plotlist_long", replace

	** reshape wide
	ds 			hhid plot_pos, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	qui ds plot_name_*
	local count = wordcount("`r(varlist)'")
	di "`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 	"${intermediate_${phase}}/main_plotlist_wide", replace


	* ----------------------------- Dry Crops -------------------------------- *

	// Dry crops 1
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_drykeycond-rpt_dcrops", clear

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(plot_no)
	destring 	key4, gen(crop_no)
	order 		hhid plot_no crop_no, first
	so 			hhid plot_no crop_no
	drop 		parent_key key setofrpt* key1 key2 key3 key4

	** drop empty observations
	drop if		missing(dcrop_name)

	** save temporary file
	compress
	tempfile 	dry_crops_1
	save 		`dry_crops_1'
	
	// Dry crops 2
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_agriculture-section_cropsdry2-rpt_dcrops2", clear

	** generate crop position (position in harvested crop list) from 'key' variable
	split 		key, parse([ ])
	destring 	key2, gen(crop_pos)
	order		hhid crop_pos, first
	so 			hhid crop_pos
	drop 		parent_key key setofrpt* key1 key2

	** drop empty observations
	drop if 	missing(dcrop2name)

	** save temporary file
	compress
	tempfile 	dry_crops_2
	save 		`dry_crops_2', replace 

	// MERGE
	
	// 1 - Produce final dry crops 1 dataset
	 
	*  take 'crop_pos' variable from dcrops2 dataset to add into dcrops1 dataset
	use 		`dry_crops_2', clear
	keep 		hhid crop_pos dcrop2name
	tempfile 	dcrop2_merge
	save 		`dcrop2_merge'
	use 		`dry_crops_1', clear

	* generate linking variable, "dcrop2name"
	gen 		dcrop2name = dcrop_name

	* merge
	merge m:1 	hhid dcrop2name using `dcrop2_merge'
	// _m = 1 when harvesting hadn't begun or if harvest was entirely lost. Drop if _m == 2.
	drop if 	_merge == 2
	drop 		_merge
	order 		hhid plot_no crop_no crop_pos, first
	so 			hhid plot_no crop_no crop_pos

	* This is the final "DryCrops_1" dataset
	compress
	save 		"${intermediate_${phase}}/drycrops_1_long", replace

	** reshape wide
	egen 		plot_crop_no = concat(plot_no crop_no), punct("_")
	order 		plot_crop_no, after(crop_no)
	drop 		plot_no crop_no

	ds 			hhid plot_crop_no, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
	}

	ds 			hhid plot_crop_no, not
	reshape 	wide `r(varlist)', i(hhid) j(plot_crop_no) s

	* In the reshapem the first number in the suffix is the plot number.
	* The second number in the suffix is the crop number.

	compress
	save 		"${intermediate_${phase}}/drycrops_1_wide", replace

	
	// 2 - Produce final dry crops 2 dataset
	 
	* take 'plot_no' from dcrops1 and merge into dcrops2
	use 		"${intermediate_${phase}}/drycrops_1_long", clear

	keep 		hhid dcrop_name plot_no
	** reshape dataset
	* want to reshape dataset into unique household-crop observations.
	byso 		hhid dcrop_name : gen n = _n
	reshape 	wide plot_no , i(hhid dcrop_name) j(n)

	** generate list of plots by crop
	ds 			plot_no*
	foreach var in `r(varlist)' {
		tostring `var', replace
		replace `var' = "" if `var' == "."
	}

	ds 			plot_no*
	egen 		plot_no = concat(`r(varlist)'), punct(" ")

	** save
	keep 		hhid dcrop_name plot_no
	ren 		dcrop_name dcrop2name
	tempfile 	plot_no
	save 		`plot_no'

	** add plot_no to dcrops2
	use 		`dry_crops_2', clear
	merge 1:1 	hhid dcrop2name using `plot_no'
	order		hhid crop_pos plot_no, first
	* _m = 2 are crops that were not harvested/sold by the household and are therefore not in dcrops2
	drop if 	_merge == 2
	drop 		_merge

	* This is the final Dry Crops 2 dataset
	compress
	save 		"${intermediate_${phase}}/drycrops_2_long", replace


	** reshape wide
	ds 			hhid crop_pos, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
	}

	ds 			hhid crop_pos, not
	reshape 	wide `r(varlist)', i(hhid) j(crop_pos)

	compress
	save 		"${intermediate_${phase}}/drycrops_2_wide", replace


	* ---------------------------- Rain Crops -------------------------------- *

	// Rain crops 1
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_rainkeycond-rpt_rcrops.dta", clear

	** generate plot and crop number using 'key' variable
	split 		key, parse([ ])
	destring 	key2, gen(plot_no)
	destring 	key4, gen(crop_no)
	order 		hhid plot_no crop_no, first
	so 			hhid plot_no crop_no
	drop 		parent_key key setofrpt* key1 key2 key3 key4

	** drop empty observations
	drop if 	missing(rcrop_name)

	** save temporary file
	compress
	tempfile 	rain_crops_1
	save 		`rain_crops_1', replace

	// Rain crops 2
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_agriculture-section_cropsrain2-rpt_rcrops2", clear

	** generate crop position (position in harvested crop list) from 'key' variable
	split 		key, parse([ ])
	destring 	key2, gen(crop_pos)
	order 		hhid crop_pos, first
	so 			hhid crop_pos
	drop 		parent_key key setofrpt* key1 key2

	** drop empty observations
	drop if 	missing(raincodeorother)
	drop if 	raincodeorother == "."

	** save temporary file
	compress
	tempfile 	rain_crops_2
	save 		`rain_crops_2', replace

	// MERGE
	
	// 1 - Produce final rain crops 1 dataset
	  
	*take 'crop_pos' variable from rcrops2 dataset to add into rcrops1 dataset
	use 		`rain_crops_2', clear
	keep 		hhid crop_pos rcrop2name
	tempfile 	rcrop2_merge
	save 		`rcrop2_merge'

	use 		`rain_crops_1', clear
	** generate linking variable, "rcrop2name"
	gen 		rcrop2name = rcrop_name

	** merge
	merge m:1 	hhid rcrop2name using `rcrop2_merge'
	* _m = 1 when harvesting hadn't begun or if harvest was entirely lost. Drop if _m == 2.
	drop if 	_merge == 2
	drop 		_merge

	order 		hhid plot_no crop_no crop_pos, first
	so 			hhid plot_no crop_no crop_pos

	* This is the final "rainCrops_1" dataset
	compress
	save 		"${intermediate_${phase}}/raincrops_1_long", replace

	** reshape wide
	gen 		plot_crop_no = string(plot_no)+"_"+string(crop_no)
	order 		plot_crop_no, after(crop_no)
	drop 		plot_no crop_no

	ds 			hhid plot_crop_no, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
	}

	ds 			hhid plot_crop_no, not
	reshape 	wide `r(varlist)', i(hhid) j(plot_crop_no) s

	* In the reshape, the first number in the suffix is the plot number.
	* The second number in the suffix is the crop number

	compress
	save 		"${intermediate_${phase}}/raincrops_1_wide", replace


	// 2 - Produce final rain crops 2 dataset
	  
	* take 'plot_no' from rcrops1 and merge into rcrops2
	use 		"${intermediate_${phase}}/raincrops_1_long", clear
	keep 		hhid rcrop_name plot_no

	** reshape dataset
	* want to reshape dataset into unique household-crop observations.
	byso 		hhid rcrop_name : gen n = _n
	reshape 	wide plot_no , i(hhid rcrop_name) j(n)

	** generate list of plots by crop
	ds 			plot_no*
	foreach var in `r(varlist)' {
		tostring `var', replace
		replace `var' = "" if `var' == "."
	}

	ds 			plot_no*
	egen 		plot_no = concat(`r(varlist)'), punct(" ")

	** save
	keep 		hhid rcrop_name plot_no
	ren 		rcrop_name rcrop2name
	tempfile 	plot_no
	save 		`plot_no', replace

	** add plot_no to rcrops2
	use 		 `rain_crops_2', clear
	merge 1:1	 hhid rcrop2name using `plot_no'
	order 		 hhid crop_pos plot_no, first
	* _m = 2 are crops that were not harvested/sold by the household and are therefore not in rcrops2
	drop if 	 _merge == 2
	drop 		 _merge
	
	* This is the final rain Crops 2 dataset
	compress
	save 		 "${intermediate_${phase}}/raincrops_2_long", replace

	** reshape wide
	ds 			 hhid crop_pos, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
	}

	ds 			 hhid crop_pos, not
	reshape 	 wide `r(varlist)', i(hhid) j(crop_pos)

	compress
	save 		 "${intermediate_${phase}}/raincrops_2_wide", replace


	* ------------------------------------------------------------------------ *
	* ----------------------------- Prep Assets ------------------------------ *
	* ------------------------------------------------------------------------ *
	
	* ------------------------ Agricutural Assets ---------------------------- *

	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_assets-rpt_ag_ass.dta", clear
	so 			hhid ag_ass_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(ag_ass_pos)

	compare	 	__key__ ag_ass_pos
	** equal
	drop 		ag_ass_pos
	so 			hhid __key__

	** rename variables to be consistent
	ren 		ass_ag ag_asset
	ren 		ass_ag_n ag_asset_n
	ren 		ag_ass_name ag_asset_name

	** save long
	compress
	save 		"${intermediate_${phase}}/assets_ag_long", replace

	** reshape wide
	ds 			hhid __key__, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			ag_asset_name_*
	local count = wordcount("`r(varlist)'")
	display		"`count'"

	forvalues i = 1 / `count' {
		foreach varstub in `stubnames' {
			display "display variable: `varstub'`i'"
			display "display label: `varstub'`i'"
			label variable `varstub'`i' "`l_`varstub''"
		}
	}

	compress
	save "${intermediate_${phase}}/assets_ag_wide", replace

	* ------------------------- Household Assets ----------------------------- *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_assets-rpt_hh_ass.dta", clear

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(ass_hh_pos)

	compare 	__key__ ass_hh_pos
	
	** equal
	drop 		ass_hh_pos
	so 			hhid __key__

	** rename variables to be consistent
	ren 		ass_hh* hh_asset*

	compress
	save 		"${intermediate_${phase}}/assets_hh_long", replace

	** reshape wide, then save labels for after reshape
	ds 			hhid __key__, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			hh_asset_name_*
	local count = wordcount("`r(varlist)'")
	display 	"`count'"

	forvalues i = 1 / `count' {
		foreach varstub in `stubnames' {
			display "display variable: `varstub'`i'"
			display "display label: `varstub'`i'"
			label variable `varstub'`i' "`l_`varstub''"
		}
	}

	compress
	save 		"${intermediate_${phase}}/assets_hh_wide", replace

	
	* ------------------------------------------------------------------------ *
	* ------------------------- Prep Cash Transfers -------------------------- *
	* ------------------------------------------------------------------------ *
	
	* Check if Chad has a cash transfer section in survey instrument
	
	
	* ------------------------------------------------------------------------ *
	* --------------------------- Prep Employment ---------------------------- *
	* ------------------------------------------------------------------------ *
	
	* -------------------------- 1. Employment  ------------------------------ *


	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_emploi-rpt_empl", clear

	* reset variables that should be string as string
	ds 			empl1-empl5, has(type numeric)
	
	foreach var in `r(varlist)' {
			tostring `var', replace
			replace `var' = "" if `var' == "."
			}

	** drop if missing data
	drop if		missing(empl_name)

	** generate key
	split 		key, parse([ ])
	drop 		key1
	destring 	key2, replace
	order 		hhid  key2, first

	// drop
	drop 		setofrpt_sal setofrpt_empl

	** label variables
	label var 	empl_name "Repondant"
	label var 	empl_worked "Employée"
	label var 	empl_work_n "Nombre de métiers salariés"

	** save long
	compress
	tempfile 	employment
	save 		`employment', replace

	
	* ----------------------------- 2. Work  --------------------------------- *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_emploi-rpt_wrk.dta", clear

	** drop if missing data
	drop if 	missing(wrk_key_pos)

	** generate key
	split 		key, parse([ ])
	drop 		key1
	destring 	key2, replace
	order 		hhid key2, first
	so 			hhid key2

	// drop
	drop 		key setofrpt_wrk

	// label
	label var 	wrk_key_name "Répondant"
	label var 	wrk_sal "Emploi salarié"

	** save long
	compress
	tempfile 	work
	save 		`work', replace

	
	*** MERGE
	use 		`work', clear
	merge 1:1 	hhid key2 using `employment', gen(_m1)
	drop 		_m1 parent_key key
	order 		hhid key2, first

	replace 	empl_name = wrk_key_name if missing(empl_name) & !missing(wrk_key_name)

	compress
	save 		"${intermediate_${phase}}/work.dta", replace

	** reshape wide
	drop 		key2
	ds 			hhid wrk_key_pos, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
	}

	ds 			hhid wrk_key_pos, not
	reshape 	wide `r(varlist)', i(hhid) j(wrk_key_pos)

	rename *_2 *_chef
	rename *_1 *
			
	compress
	save 		"${intermediate_${phase}}/work_wide.dta", replace

	* --------------------------- 3. Salary  --------------------------------- *


	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_empl_cond-rpt_sal.dta", clear

	drop if 	missing(empl_name2) & missing(empl_type)

	** generate key
	split 		key, parse([ ])
	drop 		key1 key3
	destring 	key2, replace
	destring 	key4, replace

	assert		key4 == empl_pos

	// drop
	drop 		parent_key key setofrpt_sal

	// order
	order 		hhid key2 key4

	// rename
	ren 		empl_name2 empl_name
	
	save 		"${intermediate_${phase}}/salary_long", replace

	// reshape wide
	ds 			hhid key2 key4, not
	
	foreach var in `r(varlist)' {
		ren	`var' `var'_
	}

	ds 			hhid key2 key4, not
	reshape 	wide `r(varlist)', i(hhid key2) j(key4)


	tempfile 	salary
	save 		`salary', replace

	use "${intermediate_${phase}}/work.dta", clear
	merge 1:1 	hhid key2 using `salary'
	drop 		_merge

	order 		hhid key2

	gen 		repondant = wrk_key_name, after(hhid)
	drop 		wrk_key_name empl_name
	drop 		wrk_key_pos
	ren 		key2 rep_pos


	// NOTE: there are some households who work in salaried employment but have missing salary data
	gen 		prob_sal = ((wrk_sal30 == 1 | wrk_sal12 == 1) & missing(empl1))
	replace 	prob_sal = . if (wrk_sal30 == 0 & wrk_sal12 == 0)

	compress
	save 		"${intermediate_${phase}}/salary_wide", replace


	* ------------------------------------------------------------------------ *
	* ----------------------------- Prep Finance ----------------------------- *
	* ------------------------------------------------------------------------ *
	
	* ------------------------------- Credit  -------------------------------- *
	
	use  "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_finance-part_credit-rpt_cred.dta", clear
	so 			hhid cred_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(*_pos)
	
	compare 	__key__ *_pos
	** equal
	drop 		*_pos
	so 			hhid __key__

	** gen cred_name_o & label cred_name when cred_pos == 7
	gen 		cred_name_o = cred_name if __key__ == 7
	order 		cred_name_o, after(cred_name)
	replace 	cred_name = "Autre personne ou groupe a specifier" if __key__ == 7

	** save long
	compress
	save 		"${intermediate_${phase}}/credit_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}


	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			cred_name_o_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/credit_wide", replace


	* ------------------------------ Savings  -------------------------------- *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_finance-part_othersave-gp_savemoreinfo.dta", clear
	so 			hhid saves_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofgp* key1 key2
	order 		__key__, after(saves_pos)

	compare 	__key__ saves_pos
	** equal
	drop 		*_pos
	so 			hhid __key__

	** gen saves_loc_name_o
	gen 		saves_loc_name_o = saves_loc_name if __key__ == 9
	order 		saves_loc_name_o, after(saves_loc_name)
	replace 	saves_loc_name = "Autre endroit a specifier" if __key__ == 8

	** save long
	compress
	save 		"${intermediate_${phase}}/savings_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			saves_loc_name_o_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/savings_wide", replace

	
	* ------------------------------ Tontines  ------------------------------- *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_finance-part_tontines-rpt_ton.dta", clear
	
	so 			hhid ton_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(ton_pos)

	compare 	__key__ ton_pos
	** equal
	drop 		ton_pos
	so 			hhid __key__

	** save long
	compress
	save 		"${intermediate_${phase}}/tontines_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			ton_fr_o_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/tontines_wide", replace

	
	* ------------------------------------------------------------------------ *
	* --------------------------- Prep Consumption --------------------------- *
	* ------------------------------------------------------------------------ *
	
	* --------------------------- Food Consumption --------------------------- *
	
	**append consum2
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_foodconsumption-rpt_consum2.dta", clear
	so 			hhid consum2_pos

	tempfile 	consum2
	save 		`consum2', replace

	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_foodconsumption-rpt_consum1.dta", clear
	so		 	hhid consum1_pos
	keep 		hhid consum1_pos consum1_name consum

	** rename for merge
	ren 		consum1_pos consum2_pos

	merge 1:m 	hhid consum2_pos using `consum2'
	l 			hhid consum2_pos if _merge != 3
	drop 		_merge

	duplicates 	t hhid consum2_pos, gen(dup)

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(food_loop)
	so 			hhid food_loop
	order		food_loop, after(hhid)
	drop 		parent_key key setofrpt* key1 key2

	/** Cleaning:
	2 cases where with extra obs: food_loop != consum2_pos: hhid=25911 & hhid=26347
	**/
	drop if 	food_loop == 34 & consum2_pos == 35 & inlist(hhid, 25911)
	drop if 	food_loop == 33 & consum2_pos == 35 & inlist(hhid, 26347)

	drop 		food_loop // because consum2_pos is actually the correct code
	replace 	consum2_name = consum1_name if missing(consum2_name) & !missing(consum1_name)
	replace 	consum2_ate = consum if missing(consum2_ate) & !missing(consum)
	drop 		dup consum1_name consum

	** rename variables
	ren 		*consum2_* *consum_*

	** reshape wide
	ds 			hhid consum_pos, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	duplicates  t hhid consum_pos, gen(dup)
	byso 	    hhid consum_pos : gen n = _n
	drop if     dup > 0 & n > 1
	drop 		dup n

	ds 			hhid consum_pos, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(consum_pos)

	ds 			consum_name_*
	local count = wordcount("`r(varlist)'")
	di		 	"`count'"

	forvalues i = 1 / `count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	**save wide
	compress
	save 		"${intermediate_${phase}}/foodconsumption_wide", replace

	**reshape back to long
	reshape 	long
	ren 		*_ *

	compress
	save 		"${intermediate_${phase}}/foodconsumption_long", replace


	* ------------------------- Non-Food Consumption ------------------------- *
	
	// celebrations 1
	use  "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_nfconsumption-gp_cel-rpt_cel1.dta", clear
	so 			hhid cel1_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(cel1_pos)

	compare 	__key__ cel1_pos
	** equivalent
	drop 		cel1_pos
	so 			hhid __key__

	** save
	compress
	tempfile 	cel1
	save 		`cel1', replace

	
	// celebrations 2
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_nfconsumption-gp_cel-rpt_cel2.dta", clear
	so 			hhid cel2_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(cel2_pos)

	compare 	cel2_pos __key__
	** equivalent
	drop 		cel2_pos
	so 			hhid __key__

	** save
	compress
	tempfile 	cel2
	save		`cel2', replace

	** MERGE
	use 		`cel1', clear
	merge 1:1 	hhid __key__ using `cel2'
	drop 		_merge

	** save long
	compress
	save 		"${intermediate_${phase}}/nf_celebrations_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}


	ds 			hhid __key__, not
	local stubnames "`r(varlist)'"
	reshape wide `r(varlist)', i(hhid) j(__key__)

	ds 			cel1_name_*
	
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/nf_celebrations_wide", replace

		
	// Non-food consumption
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_nfconsumption-gp_nonfood-rpt_nonfood.dta", clear
	so 			hhid nonfood_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(nonfood_pos)

	compare 	__key__ nonfood_pos
	** equal
	drop 		nonfood_pos
	so 			hhid __key__

	** clean string variables
	ds, has(type string)
	
	foreach var in `r(varlist)' {
		replace `var' = trim(itrim(`var'))
	}

	** save long
	compress
	save 		"${intermediate_${phase}}/nonfood_consumption_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}


	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			nonfood_name_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/nonfood_consumption_wide", replace


	* ------------------------------------------------------------------------ *
	* ---------------------------- Prep Livestock ---------------------------- *
	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_livestock-rpt_ani1.dta", clear

	split 		key, parse([ ])
	drop 		key1

	ren 		key2 livestock_pos
	destring 	livestock_pos, replace
	so 			hhid livestock_pos
	order 		livestock_pos, after(hhid)
	drop 		parent_key key setofrpt*

	drop 		ani1_pos			// identical to livestock_pos 

	save 		"${intermediate_${phase}}/livestock_long", replace

	** reshape wide, then save labels for after reshape    //we don't have ani_who ..
	foreach var of varlist  ani1_name -  ani_count{
	ren `var' `var'_
	local l_`var'_ : variable label `var'_
	}

	ds 			ani1_name_ - ani_count_
	local 		stubnames "`r(varlist)'"
	reshape 	wide ani1_name_ - ani_count_, i(hhid) j(livestock_pos)

	ds 			ani1_name_*
	local count = wordcount("`r(varlist)'")
	display 	"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			display "display variable: `varstub'`i'"
			display "display label: `varstub'`i'"
			label variable `varstub'`i' "`l_`varstub''"
		}
	}

	save 		"${intermediate_${phase}}/livestock_wide", replace

	
	* ------------------------------------------------------------------------ *
	* ---------------------------- Prep Business ----------------------------- *
	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_na-rpt_bus1", clear

	ds 		bus1_act_no* list_anyowner, has(type numeric)
	foreach var in `r(varlist)' {
		tostring `var', replace
			}

	split 		key, parse([ ])
	ren 		key2 bus_pos
	destring 	bus_pos, replace
	order 		bus_pos, after(hhid)

	drop 		parent_key key setofrpt_bus1 key1

	egen 		bus_d = anymatch(bus1_food - bus1_extra), v(1)

	assert 		bus_d == has_thisloopsbus
	drop 		bus_d
	ren 		has_thisloopsbus bus_d


	#delimit ;
	label define business_types
	1 "food"
	2 "tail"
	3 "constr"
	4 "comm"
	5 "prof"
	6 "serv"
	7 "trans"
	8 "art"
	9 "other";
	#delimit cr

	gen 		 bus_type = bus_pos
	label values bus_type business_types
	order 		 bus_type, after(bus_pos)
	order 		 bus_d, after(bus_type)

	drop 		 bus1_food - bus1_extra pos_anyowner_* list_anyowner 

	rename		 bus1_act_* bus_name_*
	rename 		 bus1_n bus_n

	label var    bus_pos 	"position"
	label var 	 bus_type 	"business type"
	label var 	 bus_d 		"household has this business"
	label var 	 bus_n 		"number of these businesses household has"
	
	forvalues i = 1/4 {
	label var 	bus_name_no`i' "Activitiy `i'"
	}

	compress
	save 		"${intermediate_${phase}}/chad_business", replace


	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_na-gp_bus2-rpt_bus2.dta", clear

	** generate key
	split 		key, parse([ ])
	drop 		key1
	ren 		key2 __key__
	label var 	__key__ "position in roster"
	destring 	__key__, replace
	so 			hhid __key__
	drop 		parent_key key setofrpt_*
	order 		__key__, after(hhid)
	so 			hhid __key__

	** relabel actdays_mem
	forvalues i = 1/60 {
	label var 	actdays_mem`i' "nombre de jours membre `i' a travaille les 30 derniers jours dans l'activite"
	}

	** hhid = 273314. bus2_pos = 3 is wrong -- surveycto error
	drop 		bus2_pos

	** drop unused 'actdays' variables
	drop 		actdays_mem27 - actdays_mem60

	** save
	compress
	save 		"${intermediate_${phase}}/business_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		}

	ds 			hhid __key__, not
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	** save
	compress
	save 		"${intermediate_${phase}}/business_wide", replace


	* ------------------------------------------------------------------------ *
	* ---------------------------- Prep Transfers ---------------------------- *
	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_transfers-rpt_trans.dta", clear
	so 			hhid trans_pos

	** generate key
	split		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(trans_pos)

	compare 	__key__ trans_pos
	** equal
	drop 		trans_pos
	so 			hhid __key__

	** save long
	compress
	save 		"${intermediate_${phase}}/transfers_long", replace

	** reshape wide
	ds 			hhid __key__, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			trans_*
	local count = wordcount("`r(varlist)'")/2
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/transfers_wide", replace

	
	* ------------------------------------------------------------------------ *
	* ----------------------------- Prep Programs ---------------------------- *
	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/tchad_ie_baseline9-gp_consent-section_programs-rpt_prog.dta", clear
	so 			hhid prog_pos

	** generate key
	split 		key, parse([ ])
	destring	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(prog_pos)

	compare 	__key__ prog_pos
	** equal
	drop 		prog_pos
	so 			hhid __key__

	** save long
	compress
	save 		"${intermediate_${phase}}/programs_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			prog_type_o_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 	"${intermediate_${phase}}/programs_wide", replace
