/*****************************************************************************
Title: 02_identification
Cleaning identification data from baseline survey.

Input: ${intermediate_${phase}}/chad_main_${phase_yr}.dta & ${ed}/sample_${ph}.dta
Output: ${constructed}/identification.dta
*****************************************************************************/

	use 		"${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear
	merge 1:1 hhid using "${ed}/sample_${ph}.dta", keepusing(strata) // add strata
	sort hhid
	keep if _merge == 3
	drop _merge

	** country
	gen 		country = "chad"
	label var 	country "country"

	** ccode
	gen 		ccode = "TCD"
	label var 	ccode "Country code"

	tempfile 	id_1
	save 		`id_1'


	* ------------------------ Pre-Filled Location --------------------------- *
	
	use 		"${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear

	keep 		hhid p_region* p_sousprefecture* p_village* p_canton*
	foreach x in region sousprefecture village canton {
		// encode p_`x'_txt, gen(p_`x') // generated when creating strata
		capture confirm var p_`x'_txt
		if _rc == 0 order p_`x', after(p_`x'_txt)
		label var p_`x' "`x' prior to baseline"
		// label drop p_`x'
		drop p_`x'_code
	}

	tempfile 	prefill_loc
	save 		`prefill_loc'


	* ------------------------- Baseline Location ---------------------------- *
	
	use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear
	 
	*Region
	gen 		region_txt = p_region_txt 
	encode 		region_txt , gen(region_)
	order 		region_, after(region_txt)
	label drop 	region_

	*souspref
	gen 		sousprefecture_txt = p_sousprefecture_txt 
	encode 		sousprefecture_txt , gen(sousprefecture_)
	order 		sousprefecture_, after(sousprefecture_txt)
	label drop 	sousprefecture_

	foreach var in  sousprefecture_txt region_txt sousprefecture_txt {
		label var `var' "`var' at baseline"
	}

	keep 		hhid region_ region_txt  ///
				sousprefecture_ sousprefecture_txt
				
	tempfile 	base_loc
	save 		`base_loc'

	* -------------------------- Treatment Status ---------------------------- *
	
	use 		`id_1', clear
	keep 		hhid consent country ccode strata pm_treatment treatVill treatment_status  
	merge m:1 	hhid using `prefill_loc'
	drop 		_merge
	merge m:1 	hhid using `base_loc'
	drop 		_merge

	gen 		village = p_village 
	ren 		sousprefecture_ sousprefecture

	keep if 	consent == 1
	so 			hhid

	**** Defining treatment dummies: 
	
	* 1. Treatment Specification 
	drop pm_treatment 
	gen pm_treatment = .
	replace pm_treatment = 0 if treatment_status == 4
	replace pm_treatment = 1 if treatment_status == 1
	label var pm_treatment "PM Treatment"
	label define treat_1 0 "Control" 1 "Treatment", modify
	label values pm_treatment treat_1	
	
	* 2. Pooled Spillover Specification 
	gen both_spillover_dummy = .
	replace both_spillover_dummy = 0 if treatment_status == 4 | treatment_status == 5
	replace both_spillover_dummy = 1 if treatment_status == 2 | treatment_status == 3
	label var both_spillover_dummy "Pooled Spillover"
	label define treat_2 0 "Control" 1 "Pooled Spillover", modify
	label values both_spillover_dummy treat_2
	
	* 3. CT Spillover Specification 
	gen ct_spillover_dummy = . 
	replace ct_spillover_dummy = 0 if treatment_status == 4
	replace ct_spillover_dummy = 1 if treatment_status == 2
	label var ct_spillover_dummy "CT Spillover"
	label define treat_3 0 "Control" 1 "CT Spillover", modify
	label values ct_spillover_dummy treat_3
	
	* 4. CT Spillover Specification 
	gen non_ct_spillover_dummy = . 
	replace non_ct_spillover_dummy = 0 if treatment_status == 5
	replace non_ct_spillover_dummy = 1 if treatment_status == 3
	label var non_ct_spillover_dummy "Non-CT Spillover"
	label define treat_4 0 "Control" 1 "Non-CT Spillover", modify
	label values non_ct_spillover_dummy treat_4

	compress
	save 		"${constructed_${phase}}/identification.dta", replace
	
	* ----------------------- Remove extra households ------------------------- *
	
	local dta_files       : dir "${intermediate_${phase}}" files "*.dta"
	foreach dta_file in `dta_files' {
		use "${intermediate_${phase}}/`dta_file'", clear
		merge m:1 hhid using "${constructed_${phase}}/identification.dta", ///
			keepusing(hhid) gen(sample_check)
		drop if sample_check != 3 
		drop sample_check
		
		qui compress
		save "${intermediate_${phase}}/`dta_file'", replace
	}
	