	***************************************************************************
	*																		  *
	*				  DEMOGRAPHIC DATA CLEANING CHAD ASP IE 			      *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning demographic datay
    */

	***************************************************************************
	
	** loading dataset of household members - long format 
	use 		"${intermediate_${phase}}/members_long.dta", clear
	
	** merging with main dataset in order to identify hhid to be dropped because not surveyed (using consent variable)
	merge m:1 	hhid using "${intermediate_${phase}}/chad_main_${phase_yr}", keepus(hh_size_actual handicap consent keypos1)
	drop if  	consent != 1

	* ensure that all observations were matched
	assert  _merge == 3 
	drop 	_merge

	* creating a dummy for whether the household member is a productive beneficiary: 
	drop is_benef
	gen is_benef = (mem_pos == keypos1)
	
	* making sure that every household has a household head 
	byso 		hhid : egen has_chef = total(is_chef)
	assert 		has_chef == 1 

	byso 		hhid : egen has_benef = total(is_benef)
	assert 		has_benef == 1 
	drop 		has_chef has_benef  

	gen 		chef_pos  = mem_pos if is_chef == 1
	gen 		benef_pos = mem_pos if is_benef == 1

	so 			hhid chef_pos
	by 			hhid : carryforward chef_pos, replace
	so 			hhid benef_pos
	by 			hhid : carryforward benef_pos, replace

	** mem_n
	*gen mem_n = hh_size_actual In chad, hh_size_actual didn't calculate correctly 
	gen 		is_member = 0 
	replace is_member = 1 if old_new == "new this round" & lastname != ""  
	replace is_member = 1 if still_member == 1 

	bysor 		hhid : egen mem_n = total(is_member) 
	label var 	mem_n 		"Number of members in household"
	count if mem_n != hh_size_actual

	** adult_n
	gen 		adult = (age >= 15 & age < .)
	byso 		hhid : egen adult_n = total(adult)
	label var 	adult_n 	"Number of adults age 15+ in household"
	assert 		adult_n <= mem_n

	** workage_n
	gen 		workage = (age >= 15 & age <= 65)
	byso 		hhid : egen workage_n = total(workage)
	label var 	workage_n 	"Number of adults age 15-65 in housheold"
	assert 		workage_n <= mem_n

	** child_n
	gen 		child = (age <= 14)
	byso 		hhid : egen child_n = total(child)
	label var 	child_n "Number of children age 0-14 in household"
	assert 		child_n <= mem_n

	** earlychild_n
	gen 		earlychild = (age >=0 & age <= 5)
	byso 		hhid : egen earlychild_n = total(earlychild)
	label var 	earlychild_n "Number of children age 0-5 in household"
	assert 		earlychild_n <= child_n

	** oldchild_n
	gen 		olderchild = (age >= 6 & age <= 14)
	byso 		hhid : egen olderchild_n = total(olderchild)
	label var 	olderchild_n "Number of children age 6-14 in household"
	assert 		olderchild_n <= child_n

	** elder_n
	gen 		elder = (age >= 66 & age <.)
	byso 		hhid : egen elder_n = total(elder)
	label var 	elder_n "Number of adults age 66+ in household"
	assert 		elder_n <= adult_n
	
	** equiv_n
	gen equiv_n = 1 + ((adult_n-1)*0.7) + (0.5*(child_n))  
	label variable equiv_n "Adult equivalents"
	assert equiv_n <= mem_n 

	// assertions on household size
	*assert adult_n + child_n == mem_n  // 53 contradictions to assertion
	assert 		earlychild_n + olderchild_n == child_n
	assert 		elder_n + workage_n == adult_n

	** depend
	gen 		depend = (mem_n - workage_n)/mem_n
	label var 	depend "Dependency ratio"

	** extended
	replace 	relation_o = trim(itrim(lower(relation_o)))
	label copy 	relation relation_extend

	#delimit;
	label define relation_extend
	18 "tante/oncle"
	19 "frère/soeur de conjoint"
	, add;
	#delimit cr

	gen 		relation_recode = relation, after(relation_o)
	label val 	relation_recode relation_extend

	// 116-139, not really relevant
	replace 	relation_recode = 18 if relation_o == "oncle"
	replace 	relation_recode = 16 if relation_o == "la liste n'était pas complete"
	replace 	relation_recode = 16 if relation_o == "fille de sa belle fille"
	replace 	relation_recode = 12 if relation_o == "beĺle fille"
	replace 	relation_recode = 12 if relation_o == "belle fille"
	replace 	relation_recode = 12 if relation_o == "beau fils"
	replace 	relation_recode = 12 if relation_o == "gendre"
	replace 	relation_recode = 16 if relation_o == "fille de son ex coepouse"
	replace 	relation_recode = 16 if relation_o == "ex coepouse"
	replace 	relation_recode = 18 if relation_o == "tante du chef du ménage"
	replace 	relation_recode = 18 if relation_o == "tante du chef du menange"
	replace 	relation_recode = 16 if relation_o == "belle fille de belle soeur"
	replace 	relation_recode = 13 if relation_o == "belle soeur"
	replace 	relation_recode = 4  if relation_o == "fille de la repondante clef"
	replace 	relation_recode = 18 if relation_o == "tante"
	replace 	relation_recode = 7  if relation_o == "petit fils"
	replace 	relation_recode = 6  if relation_o == "autre parent"
	replace 	relation_recode = 12 if relation_o == "conjoint du petite fille"
	replace 	relation_recode = 18 if relation_o == "tante de la repondante clef"
	replace 	relation_recode = 4  if relation_o == "enfant de la reponde clef"
	replace 	relation_recode = 11 if relation_o == "petite fille de son frère"
	replace 	relation_recode = 12 if relation_o == "conjointe du petit fils"
	replace 	relation_recode = 13 if relation_o == "beau frere"

	#delimit;
	replace relation_recode=4 if 
	inlist(relation_o,
	"fille de la cojointe",
	"fille de la conjointe"
	"fille du chef de menage",
	"fille du chef de menage",
	"fille du chef de menage",
	"fils de la conjointe",
	"fils de la conjointe",
	"fils du chef de menage")
	|
	inlist(relation_o,
	"fils du chef de menage",
	"la fille de la conjointe")
	;
	#delimit cr

	#delimit;
	replace 	relation_recode= 11 if 
	inlist(relation_o,
	"la fille du beau frere de chef menage",
	"nièce de la conjointe", 
	"fils de la grande de lepouse du chef de ménagenmena",
	"nièce de la conjointe du chef de menage");

	replace 	relation_recode = 18 	if  relation_o=="demi frère";

	replace 	relation_recode = 18 	if 
	inlist(relation_o,
	"tante",
	"tante du chef de menage",
	"tante du chef de ménage");

	replace 	relation_recode = 19 	if 
	inlist(relation_o,
	"soeur de l époue du chef de ménage",
	"soeur de la conjointe",
	"tante"
	"tante du chef de menage"
	"tante du chef de ménage");
	#delimit cr

	replace 	relation_recode = 14 	if relation_o== "belle mère du chef de menage"
	replace 	relation_recode = 13 	if relation_o== "belle soeur du chef de menage"

	gen 		ext = (relation_recode >= 6 & relation_recode < .)
	byso 		hhid : egen extended = max(ext)
	label var 	extended 		"Household contains extended family members"

	** extend_share
	by 			hhid : egen xt_share = total(ext)
	gen 		extend_share = xt_share/mem_n
	label var	extend_share 	"Share of extended family members in the household"

	** same_cb
	by 			hhid : egen same_cb = max(is_chef == 1 & is_benef == 1)
	label var 	same_cb 		"Household head and CT beneficiary are the same person"

	** hhh_fem
	gen 		hh_fem = 0
	replace 	hh_fem = 1 if (sex == 2  & is_chef == 1)
	byso 		hhid : egen hhh_fem = max(hh_fem)
	label var 	hhh_fem 		"Household head is female"
	drop 		hh_fem

	** hhh_age
	gen 		hhh_age = age if is_chef == 1
	so 			hhid hhh_age
	by 			hhid : carryforward hhh_age, replace
	label var 	hhh_age 		"Household head age"

	** ctben_fem
	gen 		ctben_f = 0
	replace 	ctben_f = 1 if (is_benef == 1 & sex == 2 )
	byso 		hhid : egen ctben_fem = max(ctben_f)
	label var 	ctben_fem 		"CT beneficiary is female"
	drop 		ctben_f

	** ctben_age
	gen 		ctben_age = age if is_benef == 1
	so 			hhid ctben_age
	by 			hhid : carryforward ctben_age, replace
	label var 	ctben_age "CT beneficiary age"

	** ctben_relation
	gen 		ctben_relation = relation_recode if is_benef == 1
	so 			hhid ctben_relation
	by 			hhid : carryforward ctben_relation, replace
	label var 	ctben_relation "CT beneficiary relationship to household head"
	label val 	ctben_relation relation_extend

	** poly
	gen 		poly_d = 0
	replace 	poly_d = 1 if is_chef == 1 & marital == 3
	replace 	poly_d = 1 if is_benef == 1 & marital == 3
	byso 		hhid : egen poly = max(poly_d)
	label var 	poly "Polygamous head of household or CT beneficiary"
	drop 		poly_d

	*** poly_hhh_fem
	gen 		poly_hh_fem = 0
	replace 	poly_hh_fem = 1 if (is_chef == 1 & marital == 3 & sex == 2 )
	byso 		hhid : egen poly_hhh_fem = max(poly_hh_fem)
	label var 	poly_hhh_fem "Polygamous female household head"
	drop 		poly_hh_fem

	*** poly_hhh_mal
	gen 		poly_hh_mal = 0
	replace 	poly_hh_mal = 1 if (is_chef == 1 & marital == 3 & sex == 1)
	byso 		hhid : egen poly_hhh_mal = max(poly_hh_mal)
	label var 	poly_hhh_mal "Polygamous male household head"
	drop 		poly_hh_mal

	/* I start counting years of education from Primaire. Garderie/Jardin des Enfants is assigned to
	zero years of education */

	** hhh_edu
	gen 		hh_edu = 0
	replace		hh_edu = (edu_lvl-1) if is_chef == 1
	replace 	hh_edu = 0 if hh_edu < 0
	replace 	hh_edu = 0 if missing(hh_edu) & edu == 0
	byso 		hhid : egen hhh_edu = max(hh_edu)
	label var 	hhh_edu 		"Household head years of education"
	drop 		hh_edu

	** ctben_edu
	gen 		ben_edu = 0
	replace 	ben_edu = (edu_lvl-1) if is_benef == 1
	replace 	ben_edu = 0 if ben_edu < 0
	replace 	ben_edu = 0 if missing(ben_edu) & edu == 0
	byso 		hhid : egen ctben_edu = max(ben_edu)
	label var 	ctben_edu 		"CT beneficiary years of education"
	drop 		ben_edu

	** hhh_noeduc
	gen 		hhh_noeduc = 0
	replace 	hhh_noeduc = 1 if hhh_edu == 0
	label var 	hhh_noeduc 		"Household head has no years of education "

	** ctben_noeduc
	gen 		ctben_noeduc = 0
	replace 	ctben_noeduc = 1 if ctben_edu == 0
	label var 	ctben_noeduc 	"CT beneficiary has no years of education"

	** hhh_prim
	gen 		hhh_prim = 0
	replace 	hhh_prim = 1 if hhh_edu >= 7 & !missing(hhh_edu)
	label var	hhh_prim 		"Household head completed primary school"

	** ctben_prim
	gen 		ctben_prim = 0
	replace 	ctben_prim = 1 if ctben_edu >= 7 & !missing(ctben_edu)
	label var 	ctben_prim 		"CT beneficiary completed primary school"

	** hhh_lit
	gen 		hh_lit = 0
	replace 	hh_lit = 1 if (is_chef == 1 & read == 1)
	byso 		hhid : egen hhh_lit = max(hh_lit)
	label var 	hhh_lit 		"Household head is literate"
	drop 		hh_lit

	** ctben_lit
	gen 		ben_lit = 0
	replace 	ben_lit = 1 if (is_benef == 1 & read == 1)
	byso 		hhid : egen ctben_lit = max(ben_lit)
	label var 	ctben_lit "CT beneficiary is literate"
	drop		ben_lit

	** hhh_health
	foreach var in phy_lift phy_walk phy_work {
		*1. generate the mean of each component
		egen mean_`var'_hh = mean(`var') if is_chef == 1
		*2. generate the standard deviation of each component
		egen sd_`var'_hh = sd(`var') if is_chef == 1
		*3. subtract the mean and divide by the sd of each component
		gen std_`var'_hh = (`var'-mean_`var'_hh)/sd_`var'_hh if is_chef == 1
		** this gives us a standardized version of each component
	}

	egen 		A_health_hh = rowmean(std_phy_lift_hh std_phy_work_hh std_phy_walk_hh) if is_chef == 1
	egen 		A_health_mean_hh = mean(A_health_hh) if is_chef == 1
	egen 		A_health_sd_hh = sd(A_health_hh) if is_chef == 1

	gen 		hhh_health = (A_health_hh-A_health_mean_hh)/A_health_sd_hh if is_chef == 1
	label var 	hhh_health "Household head activities of daily living index"

	bysort 		hhid : egen t_hhh_health = min(hhh_health) 
	replace 	hhh_health = t_hhh_health 
	drop 		t_hhh_health 
	replace 	hhh_health = . if same_cb ==  1

	** ctben_health
	foreach var in phy_lift phy_walk phy_work {
		*1. generate the mean of each component
		egen mean_`var'_ben = mean(`var') if is_benef == 1
		*2. generate the standard deviation of each component
		egen sd_`var'_ben = sd(`var') if is_benef == 1
		*3. subtract the mean and divide by the sd of each component
		gen std_`var'_ben = (`var'-mean_`var'_ben)/sd_`var'_ben if is_benef == 1
		** this gives us a standardized version of each component
	}
	
	egen 		A_health_ben = rowmean(std_phy_lift_ben std_phy_work_ben std_phy_walk_ben) if is_benef == 1
	egen 		A_health_mean_ben = mean(A_health_ben) if is_benef == 1
	egen 		A_health_sd_ben = sd(A_health_ben) if is_benef == 1

	gen 		ctben_health = (A_health_ben-A_health_mean_ben)/A_health_sd_ben if is_benef == 1
	label var 	ctben_health "Beneficiary activities of daily living index"

	bysort 		hhid : egen t_ctben_health = min(ctben_health) 
	replace 	ctben_health = t_ctben_health 
	drop 		t_ctben_health 
	replace		ctben_health = .m if ctben_health == .  // 0 missing

	** child_school
	gen 		tag_child_school = ((age >= 6 & age <= 14) & edu_now == 1)
	byso 		hhid : egen count_child_school = total(tag_child_school)
	gen 		child_school = count_child_school / olderchild_n
	replace 	child_school = 0 if olderchild_n == 0
	label var 	child_school "Proportion of children aged 6-14 in school"

	** girl_school
	gen 		tag_girl_school = ((age >= 6 & age <= 14) & edu_now == 1 & sex == 2 )
	byso 		hhid : egen count_girl_school = total(tag_girl_school)
	byso 		hhid : egen girl_n = total(olderchild & sex == 2 )
	gen 		girl_school = count_girl_school / girl_n
	replace 	girl_school = 0 if girl_n == 0
	label var 	girl_school "Proportion of girls aged 6-14 in schoool"

	** boy_school
	gen 		tag_boy_school = ((age >= 6 & age <= 14) & edu_now == 1 & sex == 1)
	byso 		hhid : egen count_boy_school = total(tag_boy_school)
	byso 		hhid : egen boy_n = total(olderchild & sex == 1)
	gen 		boy_school = count_boy_school / boy_n
	replace 	boy_school = 0 if boy_n == 0
	label var 	boy_school 	"Proportion of boys aged 6-14 in schoool"

	** handicap
	label var 	handicap 	"Someone is handicapped in the household"

	*** Export
	order 		hhid same_cb benef_pos chef_pos  hhh_fem poly poly_hhh_fem poly_hhh_mal ///
				ctben_fem hhh_age ctben_age ctben_relation hhh_edu ctben_edu hhh_prim   ///
				ctben_prim hhh_noeduc ctben_noeduc hhh_lit ctben_lit hhh_health
				
	order 		ctben_health mem_n adult_n workage_n child_n earlychild_n olderchild_n  ///
				elder_n equiv_n depend child_school girl_school, after(hhh_health)
	order		boy_school extended extend_share handicap, after(girl_school)

	keep 		hhid - handicap

	foreach var of varlist same_cb - ctben_health {
		display as error "`var'"
		sort hhid `var'
		by hhid  : assert `var'[1] == `var'[_N]
		
	}

	duplicates drop
	so 			hhid
	compress
	save 		"${constructed_${phase}}/demographics", replace
