	***************************************************************************
	*																		  *
	*				    ACTIVITIES CLEANING CHAD ASP IE 			  	      *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning activities data 
    */

	****************************************************************************

	****************************************************************************
	*------------------------- OUTCOME VARIABLES ------------------------------*
	****************************************************************************

	use 	"${intermediate_${phase}}/chad_main_${phase_yr}", clear
	drop if consent == 0
	keep 	hhid keypos1 pos_chef 
		
	* Beneficiary and Household Head are the same person
	gen 	same_cb = (keypos1 == pos_chef)
	keep hhid same_cb
	
	* work dataset
	if "$ph" == "bl" {		
		merge 1:1 hhid using "${intermediate_${phase}}/work_wide.dta"
	}
	else if "$ph" == "fu" {
		merge 1:1 	hhid using "${intermediate_${phase}}/work.dta"	
	}	
	assert 		_merge == 3
	drop		_merge	
	* dropping irrelevant variables:
	drop empl1 - empl5 empl1_chef - empl5_chef	
	
	*----------------------------- PART I  ------------------------------------*
	
	** hhh_x_12/ctben_x_12
	
	**  CT Beneficiary
	foreach x in ag liv sal na {
		*ctben_x_12
		gen 	ctben_`x'_12 = 0
		replace ctben_`x'_12 = 1 if (wrk_`x'30  == 1 | wrk_`x'12 == 1)
	}
	
	** Household Head
	foreach x in ag liv sal na {
		*hhh_x_12
		gen 	hhh_`x'_12 = 0
		replace hhh_`x'_12 = 1 if (wrk_`x'30_chef  == 1 | wrk_`x'12_chef == 1)
	}	
	
	// in those cases where the hh head is also the beneficiary, instead of giving 0 values, we 
	// just attribute the value of the beneficiary to the household head (since they're the same person)
	// in that way, consistent with the way the other hh head outcomes have been dealt with
		
	foreach x in ag liv sal na {
		replace hhh_`x'_12 = ctben_`x'_12 if same_cb == 1
	}	

	** any_x_12

	foreach x in ag liv sal na {
		so 		hhid hhh_`x'_12
		by 		hhid : carryforward hhh_`x'_12, replace

		so 		hhid ctben_`x'_12
		by 		hhid : carryforward ctben_`x'_12, replace

		gen 	any_`x'_12 = 0
		replace any_`x'_12 = 1 if (hhh_`x'_12 == 1 | ctben_`x'_12 == 1)
	}

	label var 	hhh_ag_12 		"Head of household works in agriculture (last 12 months)"
	label var 	ctben_ag_12 	"CT beneficiary works in agriculture (last 12 months)"
	label var 	any_ag_12 		"Head of household or CT beneficiary works in agriculture (last 12 months)"

	label var 	hhh_liv_12 		"Head of household works in livestock (last 12 months)"
	label var 	ctben_liv_12 	"CT beneficiary works in livestock (last 12 months)"
	label var 	any_liv_12 		"Head of household or CT beneficiary works in livestock (last 12 months)"

	label var 	hhh_sal_12 		"Head of household works in wage employment (last 12 months)"
	label var 	ctben_sal_12 	"CT beneficiary works in wage employment (last 12 months)"
	label var 	any_sal_12 		"Head of household or CT beneficiary works in wage employment (last 12 months)"

	label var 	hhh_na_12 		"Head of household works in non-agricultural employment (last 12 months)"
	label var 	ctben_na_12		"CT beneficiary works in non-agricultural employment (last 12 months)"
	label var 	any_na_12 		"Head of household or CT beneficiary works in non-agricultural employment (last 12 months)"

	// Missing variables are in households without a household head
	keep hhid ctben_* hhh_*
	duplicates drop
	isid hhid 
	tempfile 	 temp_activities_1	
	save 		`temp_activities_1'	
	

	*----------------------------- PART II  -----------------------------------*

	***** Beneficiary: ******
	use "${intermediate_${phase}}/salary_long.dta", clear
	
	if "$ph" == "bl" {
		merge m:1 hhid using "${intermediate_${phase}}/chad_main_${phase_yr}", keepusing(keypos1 pos_chef consent)
		
		drop if consent == 0
		keep if _merge == 3
		drop _merge 
		
		* Beneficiary and Household Head are the same person
		gen 	same_cb = (keypos1 == pos_chef)
		
		* is_chef is_benef dummies 
		gen is_benef = (key2 == 1)
		gen is_chef  = (key2 == 2)
		
		* if same cb, respondent is classified as benef first
		replace is_chef = 0 if same_cb == 1		
	}

	/* Employment types
	1 Agriculture  (Production et commercialisation)
	2 Elevage  (Production et commercialisation)
	3 Pêche/Chasse/cueillette  (autoconsommation et vente)
	4 Petits commerces informels/ambulant (carte téléphonique, eau, petits articles di
	5 Journalier /Service du secteur informel (docker, coxer, ouvrier journalier, char
	6 Ouvrier/Artisan (menuisier, maçon, électricien, briquetiers, …)
	7 Fonctionnaire/salarié formel et informel)/Pension/Retraite
	8 Commerçant/Entrepreneur (boutique, magasin, y compris restaurant, etc.)
	9 Transferts d'argent reçus
	10 Don/Aide/Mendicité
	11 Autre (spécifiez)
	*/

	gen 		empl_type_recode = empl_type, after(empl_type)
	
	if "$ph" == "bl" {
		replace 	empl_type_recode = 1 if empl_type_o == "Vente de maïs"
		replace 	empl_type_recode = 2 if empl_type_o == "Faire le linge"

		replace 	empl_type_recode = 2 if empl_type_o == "Chaque"					// "Fabrication de brique"
		replace 	empl_type_recode = 2 if empl_type_o == "Faire le linge"			// "Faire le linge"
		replace 	empl_type_recode = 2 if empl_type_o == "Lavage habit"			// "Lavage habit"
		replace 	empl_type_recode = 2 if empl_type_o == "Lingerie"				// "lingerie"
		replace 	empl_type_recode = 2 if empl_type_o == "Rémunéré  par bénéfice"	// "Intermédiaire"
		replace 	empl_type_recode = 2 if empl_type_o == "Salarié de l'Etat"		// "Agent de sécurité"
		replace 	empl_type_recode = 2 if empl_type_o == "Son propre compte"		// "Boulangere local"
		replace 	empl_type_recode = 2 if empl_type_o == "Travail pour lui même"	// "Tailleur"
		replace 	empl_type_recode = 2 if empl_type_o == "mansonerie"				// "manconerie"

		replace empl_name = trim(itrim(lower(empl_name)))
		replace empl_type_recode = 1 if empl_type_o == "Vente de maïs"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "1"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "apprenti"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "apprenti dans une boutique"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "apprenti maçon"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "aprenti"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "boutiquier"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "chargé de transports"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "elevage"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "gomme arabique"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "infirmier"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "main d'oeuvre"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "main dœuvre"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "manoeuvre"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "maçon"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "michelin"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "tailleur"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "vente eau de puie"
		replace empl_type_recode = 2 if empl_type == 3 & empl_name == "vente légumes"
		
		#delimit;
		replace empl_type_recode=7 if empl_type_recode==11 &
		inlist(empl_name,
		"Enseignante",
		"Tissage",
		"1",
		"Enseignant" ,
		"Conducteur",
		"Boulangerie traditionnelle");
		 #delimit cr
	}
	else if "$ph" == "fu" {
		replace empl_type_recode = 1 if empl_type_o == "Coupe de bois et vente" | ///
									empl_type_o == "Vente de fagots"        | ///
									empl_type_o == "Vente des oignons" 
		replace empl_type_recode = 10 if empl_type_o == "Journalières s'il y a un cérémonie"
		
		replace empl_type_o = "" if empl_type_o == "Coupe de bois et vente" | ///
									empl_type_o == "Vente de fagots"        | ///
									empl_type_o == "Vente des oignons"      | ///
									empl_type_o == "Journalières s'il y a un cérémonie"
	}

	// recode missing
	replace 	empl_rev30 = .r if empl_rev30 == 999
	replace 	empl_rev12 = .r if empl_rev12 == 999
	replace 	empl_rev30 = .d if empl_rev30 == 888
	replace 	empl_rev12 = .d if empl_rev12 == 888
	
	** ctben_sal_12_xof
	if "$ph" == "bl" {
		byso hhid : egen ctben_sal_12_xof = total(empl_rev12) if is_benef == 1
		replace	 	ctben_sal_12_xof = . if same_cb == 1
	}
	if "$ph" == "fu" {
		byso hhid : egen ctben_sal_12_xof = total(empl_rev12) 
	}
	label var 	ctben_sal_12_xof "CT beneficiary earnings from wage employment (last 12 months)"

	** ctben_sal_ag_12
	if "$ph" == "bl" gen ctben_sal_ag = empl_type_recode == 1 & is_benef == 1
	if "$ph" == "fu" gen ctben_sal_ag = empl_type_recode == 1 
	byso 		hhid : egen ctben_sal_ag_12 = max(ctben_sal_ag)
	label var 	ctben_sal_ag_12 "had agricultural wage employment, CT beneficiary, 12 months"
	drop 		ctben_sal_ag
	
	** ctben_sal_nag_12
	if "$ph" == "bl" gen ctben_sal_nag = empl_type_recode == 2 & is_benef == 1
	if "$ph" == "fu" gen ctben_sal_nag = empl_type_recode == 2 
	byso 		hhid : egen ctben_sal_nag_12 = max(ctben_sal_nag)
	label var 	ctben_sal_nag_12 "had non-agricultural wage employment, CT beneficiary, 12 months"
	drop 		ctben_sal_nag	
	
	** ctben_sal_ag_12_xof
	if "$ph" == "bl" byso hhid : egen ctben_sal_ag_12_xof = total(empl_rev12) if is_benef == 1 & empl_type_recode == 1
	if "$ph" == "fu" byso hhid : egen ctben_sal_ag_12_xof = total(empl_rev12) if empl_type_recode == 1	
	label var 	ctben_sal_ag_12_xof "CT beneficiary earnings from agricultural wage employment (last 12 months)"
	
	** ctben_sal_nag_12_xof
	if "$ph" == "bl" byso hhid : egen ctben_sal_nag_12_xof = total(empl_rev12) if is_benef == 1 & empl_type_recode == 2
	if "$ph" == "fu" byso hhid : egen ctben_sal_nag_12_xof = total(empl_rev12) if empl_type_recode == 2	
	label var 	ctben_sal_nag_12_xof "CT beneficiary earnings from non-agricultural wage employment (last 12 months)"
	
	** ctben_sal_day
	if "$ph" == "bl" gen ben_days_worked = (empl_mos*empl_wks*empl_days) if is_benef == 1
	if "$ph" == "fu" gen ben_days_worked = (empl_mos*empl_wks*empl_days)
	byso 		hhid : egen ctben_sal_day = total(ben_days_worked)
	replace 	ctben_sal_day = 365 if ctben_sal_day > 365 & ctben_sal_day != .
	label var 	ctben_sal_day "CT beneficiary days per year in employment/wage work"
	drop 		ben_days_worked
	
	if "$ph" == "fu" {
		keep hhid ctben_sal_12_xof - ctben_sal_day
		duplicates drop
		duplicates tag hhid, gen(dup)
		
		drop if dup == 1 & ctben_sal_ag_12_xof == .
		drop dup
		
		tempfile ben_salary
		save `ben_salary'
	}	

	
	***** HH HEAD ***** 
	if "$ph" == "fu" {
		use "${intermediate_${phase}}/salary_long_chef.dta", clear

		merge m:1 hhid using "${intermediate_${phase}}/chad_main_2021", keepusing(keypos1 pos_chef)
		keep if _merge == 3
		
		* Beneficiary and Household Head are the same person
		gen 	same_cb = (keypos1 == pos_chef)
		drop keypos1 pos_chef
		
		gen 		empl_type_recode = empl_type_chef, after(empl_type_chef)
		
		tab 		empl_type_o_chef

		replace 	empl_type_recode = 1 if empl_type_o_chef == "machine a moudre la farine" | ///
											empl_type_o_chef == "jardinier" | ///
											empl_type_o_chef == "jardinage" | ///
											empl_type_o_chef == "Main d'œuvre  pour  aux champs des autres" | ///
											empl_type_o_chef == "" | empl_type_o_chef == "Orpaillage" | ///
											empl_type_o_chef == "Orpaillage au nord du tchad"
		replace 	empl_type_recode = 2 if empl_type_o_chef == "Convoyeurs troupeaux"
		replace 	empl_type_recode = 8 if empl_type_o_chef == "Petite maintenance  des appareils   électroniques" | ///
											empl_type_o_chef == "Fabrication du  charbon" | /// 
											empl_type_o_chef == "tailleur"
		replace 	empl_type_recode = 5 if empl_type_o_chef == "Chauffeur" | ///
											empl_type_o_chef == "Chauffeur de voiture"
		replace 	empl_type_recode = 7 if empl_type_o_chef == "Enseignant à l'école coranique"
		replace 	empl_type_recode = 10 if empl_type_o_chef == "Pasteur non paye" 
		
		// recode missing
		replace 	empl_rev30_chef = .r if empl_rev30_chef == 999
		replace 	empl_rev12_chef = .r if empl_rev12_chef == 999
		replace 	empl_rev30_chef = .d if empl_rev30_chef == 888
		replace 	empl_rev12_chef = .d if empl_rev12_chef == 888		
	}
	
	** hhh_sal_12_xof
	if "$ph" == "bl" byso hhid : egen hhh_sal_12_xof = total(empl_rev12) if is_chef == 1			
	if "$ph" == "fu" byso hhid : egen hhh_sal_12_xof = total(empl_rev12_chef)
	replace	 	hhh_sal_12_xof = . if same_cb == 1
	label var 	hhh_sal_12_xof "Head of household earnings in wage employment (last 12 months)"		

	** hhh_sal_ag_12
	if "$ph" == "bl" gen hhh_sal_ag = empl_type_recode == 1 & is_chef == 1
	if "$ph" == "fu" gen hhh_sal_ag = empl_type_recode == 1 
	byso 		hhid : egen hhh_sal_ag_12 = max(hhh_sal_ag)
	replace 	hhh_sal_ag_12 = . if same_cb == 1
	label var 	hhh_sal_ag_12 "had agricultural wage employment, household head, 12 months"
	drop 		hhh_sal_ag

	** hhh_sal_nag_12
	if "$ph" == "bl" gen hhh_sal_nag = empl_type_recode == 2 & is_chef == 1
	if "$ph" == "fu" gen hhh_sal_nag = empl_type_recode == 2
	byso 		hhid : egen hhh_sal_nag_12 = max(hhh_sal_nag)
	replace 	hhh_sal_nag_12 = . if same_cb == 1
	label var 	hhh_sal_nag_12 "had non-agricultural wage employment, household head, 12 months"
	drop 		hhh_sal_nag
	
	** hhh_sal_ag_12_xof
	if "$ph" == "bl" byso hhid : egen hhh_sal_ag_12_xof = total(empl_rev12) if is_chef == 1 & empl_type_recode == 1
	if "$ph" == "fu" byso hhid : egen hhh_sal_ag_12_xof = total(empl_rev12_chef) if empl_type_recode == 1
	replace 	hhh_sal_ag_12_xof = . if same_cb == 1
	label var 	hhh_sal_ag_12_xof "Head of household earnings in agricultural wage employment (last 12 months)"
	
	** hhh_sal_nag_12_xof
	if "$ph" == "bl" byso hhid : egen hhh_sal_nag_12_xof = total(empl_rev12) if is_chef == 1 & empl_type_recode == 2
	if "$ph" == "fu" byso hhid : egen hhh_sal_nag_12_xof = total(empl_rev12_chef) if empl_type_recode == 2
	replace 	hhh_sal_nag_12_xof = . if same_cb == 1
	label var 	hhh_sal_nag_12_xof "Head of household from non-agricultural wage employment (last 12 months)"

	** hhh_sal_day
	if "$ph" == "bl" {
		replace 	empl_mos = 1 if empl_mos == 0
		replace 	empl_wks = 1 if empl_wks == 0
		gen 		hh_days_worked = (empl_mos*empl_wks*empl_days) if is_chef == 1		
	}
	else if "$ph" == "fu"{
		replace 	empl_mos_chef = 1 if empl_mos_chef == 0
		replace 	empl_wks_chef = 1 if empl_wks_chef == 0
		gen 		hh_days_worked = (empl_mos_chef*empl_wks_chef*empl_days_chef)		
	}

	byso 		hhid : egen hhh_sal_day = total(hh_days_worked)
	replace 	hhh_sal_day = 365 if hhh_sal_day > 365 & hhh_sal_day != .
	replace 	hhh_sal_day = . if same_cb == 1
	label var 	hhh_sal_day "Head of household days per year in employment/wage work"
	drop 		hh_days_worked
	
	if "$ph" == "fu"{
		keep hhid same_cb - hhh_sal_day
		
		duplicates drop
		duplicates tag hhid, gen(dup)
		drop if dup == 1 & hhh_sal_ag_12_xof == .
		
		drop dup 
		
		tempfile chef_salary
		save `chef_salary'
	}
	
	if "$ph" == "fu" {
		***** TOGETHER ******
		* dataset with all households: 
		use "${intermediate_${phase}}/chad_main_${phase_yr}", clear
		keep hhid keypos1 pos_chef
		
		merge 1:1 hhid using `ben_salary', gen(m_bensal)
		merge 1:1 hhid using `chef_salary', gen(m_chefsal)
		
		drop m_bensal same_cb m_chefsal 
		
		gen same_cb = (keypos1 == pos_chef)
		
		foreach v in ctben_sal_12_xof ctben_sal_ag_12 ctben_sal_nag_12 ctben_sal_ag_12_xof ///
					 ctben_sal_nag_12_xof hhh_sal_12_xof hhh_sal_ag_12 hhh_sal_nag_12      ///
					 hhh_sal_ag_12_xof hhh_sal_nag_12_xof hhh_sal_day {
			replace `v' = 0 if `v' == .
		}		
	}

	** any_sal_12_xof
	foreach var in hhh_sal_12_xof ctben_sal_12_xof {
		so 		hhid `var'
		by 		hhid : carryforward `var', replace
	}

	egen 		any_sal_12_xof = rowtotal(hhh_sal_12_xof ctben_sal_12_xof), missing
	label var 	any_sal_12_xof "CT beneficiary and head of household earnings from wage employment (last 12 months)"

	*div_n_sal_12
	egen 		div_n_sal_12 = rowtotal(hhh_sal_ag_12 hhh_sal_nag_12 ctben_sal_ag_12 ctben_sal_nag_12)
	label var 	div_n_sal_12 "count of household wage types"

	* div_n_sal_12_ben
	egen 		div_n_sal_12_ben = rowtotal(ctben_sal_ag_12 ctben_sal_nag_12)
	label var 	div_n_sal_12_ben "count of beneficiary wage types"

	
	** any_sal_x_12_xof
	foreach x in ag nag {
		so hhid hhh_sal_`x'_12_xof
		by hhid : carryforward hhh_sal_`x'_12_xof, replace
		so hhid ctben_sal_`x'_12_xof
		by hhid : carryforward ctben_sal_`x'_12_xof, replace
		egen any_sal_`x'_12_xof = rowtotal(hhh_sal_`x'_12_xof ctben_sal_`x'_12_xof), missing
	}
	
	label var 	any_sal_ag_12_xof "CT beneficiary and head of household earnings from agricultural wage employment (last 12 months)"
	label var 	any_sal_nag_12_xof "CT beneficiary and head of household earnings from non-agricultural wage employment (last 12 months)"

	if "$ph" == "bl" keep hhid ctben_sal_12_xof - any_sal_nag_12_xof

	replace 	hhh_sal_12_xof = 0 if missing(hhh_sal_12_xof)
	replace 	ctben_sal_12_xof = 0 if missing(ctben_sal_12_xof)
	replace 	hhh_sal_ag_12_xof = 0 if missing(hhh_sal_ag_12_xof) & hhh_sal_ag_12 == 0
	replace 	ctben_sal_ag_12_xof = 0 if missing(ctben_sal_ag_12_xof) & ctben_sal_ag_12 == 0
	replace	 	hhh_sal_nag_12_xof = 0 if missing(hhh_sal_nag_12_xof) & hhh_sal_nag_12 == 0
	replace 	ctben_sal_nag_12_xof = 0 if missing(ctben_sal_nag_12_xof) & ctben_sal_nag_12 == 0
	replace 	any_sal_ag_12_xof = 0 if missing(any_sal_ag_12_xof) & (ctben_sal_ag_12_xof == 0 & hhh_sal_ag_12_xof == 0)
	replace 	any_sal_nag_12_xof = 0 if missing(any_sal_nag_12_xof) & (ctben_sal_nag_12_xof == 0 & hhh_sal_nag_12_xof == 0)
	recode 		hhh_sal_day ctben_sal_day (missing = 0)

	ds 			hhid, not
	foreach var in `r(varlist)' {
		so hhid `var'
		by hhid : carryforward `var', replace
		by hhid (`var'), sort: gen diff_`var' = `var'[1] != `var'[_N]
	}

	drop 	   diff*
	duplicates drop
	tempfile temp_activities_2
	save    `temp_activities_2'


	*----------------------------- PART III  ----------------------------------*

	use "${intermediate_${phase}}/members_long.dta", clear
	keep hhid mem_pos old_new still_member sex age p_relation is_chef is_benef

	byso hhid : egen has_chef = total(is_chef)
	replace is_chef = 1 if has_chef == 0 & p_relation == 1
	gen same_cb = (is_chef == 1 & is_benef == 1)

	gen chef_pos = mem_pos if is_chef == 1
	gen benef_pos = mem_pos if is_benef == 1

	so hhid chef_pos
	by hhid : carryforward chef_pos, replace
	so hhid benef_pos
	by hhid : carryforward benef_pos, replace

	tostring chef_pos, replace
	tostring benef_pos, replace

	replace chef_pos = " "+chef_pos+" "
	replace benef_pos = " "+benef_pos+" "

	keep hhid chef_pos benef_pos same_cb
	duplicates drop

	duplicates t hhid, gen(dup)
	drop if dup > 0 & same_cb == 0
	drop dup

	if "$ph" == "bl" merge 1:1 hhid using "${intermediate_${phase}}/business_wide.dta", keepus(hhid bus2_own2_* bus2_workers_*)
	if "$ph" == "fu" merge 1:1 hhid using "${intermediate_${phase}}/business_wide.dta", keepus(hhid bus2_own_* bus2_workers_*)
	keep if _merge == 3

	if "$ph" == "bl" ds bus2_own2_* bus2_workers_*
	if "$ph" == "fu" ds bus2_own_? bus2_workers_?
	foreach var in `r(varlist)' {
		replace `var' = " "+`var'+" "
	}

	gen hh_own_work = 0
	gen benef_own_work = 0
	if "$ph" == "bl" ds bus2_own2_*
	if "$ph" == "fu" ds bus2_own_?
	
	foreach var in `r(varlist)' {
		replace hh_own_work = 1 if strpos(`var', chef_pos) > 0
		replace benef_own_work = 1 if strpos(`var', benef_pos) > 0
	}
	
	** hhh_bus_12
	byso hhid : egen hhh_bus_12 = max(hh_own_work)
	replace hhh_bus_12 = . if hhh_bus_12 == 1 & same_cb == 1
	label var hhh_bus_12 "Head of household works in household business last 12 months"

	** ctben_bus_12
	byso hhid : egen ctben_bus_12 = max(benef_own_work)
	label var ctben_bus_12 "CT beneficiary works in household business last 12 months"

	** any_bus_12
	by hhid : egen any_bus_12 = max(hhh_bus_12 == 1 | ctben_bus_12 == 1)
	label var any_bus_12 "Household head or CT beneficiary works in household business, 12 months"

	keep hhid hhh_bus_12 ctben_bus_12 any_bus_12
	tempfile temp_activities_3
	save    `temp_activities_3'

	*** Merge & Export
	use `temp_activities_1'
	merge 1:1 hhid using `temp_activities_2', gen(_m2)
	merge 1:1 hhid using `temp_activities_3', gen(_m3)
	drop _m2 _m3

	// replace true zeros
	ds ctben_* hhh_* div_* any_* 
	foreach var in `r(varlist)' {
		recode `var' (missing = 0)
	}

	keep hhid ctben_* hhh_* div_* any_* 
	so hhid
	isid hhid 

	compress
	save "${constructed_${phase}}/activities", replace
