	***************************************************************************
	*																		  *
	*				    EMPLOYMENT CLEANING CHAD ASP IE 			  	      *
	*																		  *
	***************************************************************************
	
********************************************************************************
* Employment																   *
********************************************************************************

* ------ Salaried employment ------ * 

** Beneficiary 
use "${intermediate_${phase}}/salary_long.dta", clear
drop if empl_type == .

if "$ph" == "bl" {
	* key2 benef or chef	
	gen sal_ben = (key2 == 1)	
	gen sal_chef = (key2 == 2)	
	gen empl_time_month_ben = (empl_mos*empl_wks*empl_days)/12 if key2 == 1	
	gen empl_time_month_chef = (empl_mos*empl_wks*empl_days)/12 if key2 == 2	
}
else if "$ph" == "fu" {
	gen sal_empl_ben = 1
	gen empl_time_month_ben = (empl_mos*empl_wks*empl_days)/12
}

** hh-level variables 
bysort hhid: egen tot_empl_time_month_ben = total(empl_time_month_ben)
replace tot_empl_time_month_ben = 30 if tot_empl_time_month_ben > 30

if "$ph" == "fu" {
	keep hhid sal_empl_ben tot_empl_time_month_ben 
	duplicates drop

	* inserting true zeros (other households who do not have salaried employment)
	merge 1:1 hhid using "${constructed_${phase}}/demographics", keepusing(benef_pos)
		
	replace sal_empl_ben = 0 if sal_empl_ben == . 
	replace tot_empl_time_month_ben = 0 if tot_empl_time_month_ben == . 

	drop _merge benef_pos 
	tempfile empl_benef
	save `empl_benef'

	** HOUSEHOLD HEAD 
	use "${intermediate_${phase}}/salary_long_chef.dta", clear
	drop if empl_type_chef == .

	gen sal_empl_chef = 1
	gen empl_time_month_chef = (empl_mos_chef*empl_wks_chef*empl_days_chef)/12
}

** hh-level variables 
bysort hhid: egen tot_empl_time_month_chef = total(empl_time_month_chef)
replace tot_empl_time_month_chef = 30 if tot_empl_time_month_chef > 30

if "$ph" == "bl" {
	bysort hhid: egen sal_empl_ben = total(sal_ben)	
	replace sal_empl_ben = 1 if sal_empl_ben > 1	
	bysort hhid: egen sal_empl_chef = total(sal_chef)	
	replace sal_empl_chef = 1 if sal_empl_chef > 1	
	keep hhid sal_empl_ben sal_empl_chef tot_empl_time_month_ben tot_empl_time_month_chef
}
if "$ph" == "fu" {
	keep hhid sal_empl_chef tot_empl_time_month_chef 
}
duplicates drop

capture label var sal_empl_ben  "Beneficiary Works in Salaried Employment"
capture label var sal_empl_chef "Chef Works in Salaried Employment"
capture label var tot_empl_time_month_ben  "Beneficiary Days Worked in Salaried Employment"
capture label var tot_empl_time_month_chef "Chef Days Worked in Salaried Employment"

* inserting true zeros (other households who do not have salaried employment)
merge 1:1 hhid using "${constructed_${phase}}/demographics", keepusing(benef_pos)
if "$ph" == "bl"  local add_var sal_empl_ben tot_empl_time_month_ben
foreach v in sal_empl_chef tot_empl_time_month_chef `add_var' {	
	replace `v' = 0 if `v' == .	
}
	
replace sal_empl_chef = 0 if sal_empl_chef == . 
drop _merge benef_pos 
if "$ph" == "fu" {
	tempfile empl_chef
	save `empl_chef'

	use `empl_benef', clear 
	merge 1:1 hhid using `empl_chef', gen(m1)
	drop m1
}
tempfile employment_margins
save `employment_margins'


	* ------ Salaried employment Revenues ------ * 
	/*
		Secondary B.2.2 Wage earnings, beneficiary, 12 months (& 1 month)
		Secondary B.3.5 Count of wage-earning sources 	
	*/

use "${intermediate_${phase}}/salary_long.dta", clear
drop if empl_type == .

if "$ph" == "bl" {
	* keeping ben only 
	keep if key2 == 1
}

keep hhid empl_pos empl_rev30 empl_rev12 
fix_continuous empl_rev30 empl_rev12

rename (empl_pos empl_rev30 empl_rev12) (empl_pos_ben empl_rev30_ben empl_rev12_ben)
reshape wide empl_rev30_ben empl_rev12_ben, j(empl_pos_ben) i(hhid)
egen div_empl_ben_n = rownonmiss(empl_rev12*) // count at 12 months only

isid hhid
preserve
	if "$ph" == "bl" {
		use "${intermediate_${phase}}/salary_long.dta", clear	
		drop if empl_type == .	
		* keeping chef only	
		keep if key2 == 2	
		keep hhid empl_pos empl_rev30 empl_rev12	
		fix_continuous empl_rev30 empl_rev12	
		rename empl_pos empl_pos_chef	
		rename empl_rev30 empl_rev30_chef	
		rename empl_rev12 empl_rev12_chef	
	}
	else if "$ph" == "fu" {
		use "${intermediate_${phase}}/salary_long_chef.dta", clear
		rename key2 empl_pos_chef
		drop if empl_type_chef == .		
	}
	keep hhid empl_pos_chef empl_rev30_chef empl_rev12_chef
	fix_continuous empl_rev30_chef empl_rev12_chef
	reshape wide empl_rev30_chef empl_rev12_chef , j(empl_pos_chef) i(hhid)
	egen div_empl_chef_n = rownonmiss(empl_rev12_chef*)
	tempfile chef
	save 	`chef'
restore

merge 1:1 hhid using `chef', gen(_mchefsal)
merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos chef_pos)
keep if _merge == 3
sort _mchefsal
gen same = benef_pos == chef_pos
sort same _mchefsal hhid

foreach var of varlist empl_rev30_chef* empl_rev12_chef* div_empl_chef_n { 
	// drop chef salary if benef == chef & salaries exist for both
	replace `var' = . if same == 1 & _mchefsal == 3
}
drop div_* _mchefsal _merge same *_pos

rename empl_rev12_chef* rev12*_2 
rename empl_rev12_ben*  rev12*_1 
rename empl_rev30_ben*  rev30*_1 
rename empl_rev30_chef* rev30*_2 

foreach pos in 1 2 {
	preserve
		keep hhid rev12*_`pos' rev30*_`pos'
		rename rev12*_`pos' rev12*
		rename rev30*_`pos' rev30*
		// reshape --> hhid, status, income then winsorize
		reshape long rev30 rev12, i(hhid) j(bus_pos)
		tempfile bus`pos'
		save 	`bus`pos''
	restore
}
use `bus1', clear
append using `bus2', gen(pos)
sort hhid pos bus_pos
label define pos 0 "benef" 1 "chef"
label values pos pos

***** -----| Secondary B.2.2
foreach term in 30 12 {

	gen 	rev`term'_win = rev`term'
	_pctile rev`term' , p(98)
	replace rev`term'_win  = `r(r1)' if !missing(rev`term') & rev`term' > `r(r1)' 
	drop 	rev`term'

	if `term' == 30 local unit day
	if `term' == 12 local unit month
	
	gen rev`term'_win_ben_only = rev`term'_win if pos == 0 // pos = 0: benef only 
	bysort hhid : egen tot_empl_rev`term'_ben_xof = total(rev`term'_win_ben_only)
	replace tot_empl_rev`term'_ben_xof = tot_empl_rev`term'_ben_xof / 1000
	label var tot_empl_rev`term'_ben_xof "ONLY Beneficiary's `term'-`unit' Income from salaried job wins. (1000 FCFA) at ${phase}"
	// extend across entire hh to fill missings
	sort hhid tot_empl_rev`term'_ben_xof
	bysort hhid (tot_empl_rev`term'_ben_xof): replace tot_empl_rev`term'_ben_xof = tot_empl_rev`term'_ben_xof[1]

	gen rev`term'_win_chef_only = rev`term'_win if pos == 1 // pos = 1: chef only 
	bysort hhid : egen tot_empl_rev`term'_chef_xof = total(rev`term'_win_chef_only)
	replace tot_empl_rev`term'_chef_xof = tot_empl_rev`term'_chef_xof / 1000
	label var tot_empl_rev`term'_chef_xof "ONLY HH HEAD's `term'-`unit' Income from salaried job wins. (1000 FCFA) at ${phase}"
	// extend across entire hh to fill missings
	sort hhid tot_empl_rev`term'_chef_xof
	bysort hhid (tot_empl_rev`term'_chef_xof): replace tot_empl_rev`term'_chef_xof = tot_empl_rev`term'_chef_xof[1]

	bysort hhid : egen tot_empl_rev`term'_hh_xof = total(rev`term'_win) // no pos condition: chef and benef 
	replace tot_empl_rev`term'_hh_xof = tot_empl_rev`term'_hh_xof / 1000
	label var tot_empl_rev`term'_hh_xof "B.2.2 Beneficiary's and chef's `term'-`unit' Income from salaried job wins. (1000 FCFA) at ${phase}"

	***** -----| Secondary B.3.5
	byso hhid : egen div_empl`term'_ben_n = count(rev`term'_win_ben_only)
	label var div_empl`term'_ben_n "B.3.5 ONLY Beneficiary's No. of `term'-`unit' Salaried jobs at ${phase}"
	// extend across entire hh to fill missings
	sort hhid div_empl`term'_ben_n
	bysort hhid (div_empl`term'_ben_n): replace div_empl`term'_ben_n = div_empl`term'_ben_n[1]

	byso hhid : egen div_empl`term'_n = count(rev`term'_win)
	label var div_empl`term'_n "B.3.5 Beneficiary's and chef's No. of `term'-`unit' Salaried jobs at ${phase}"
}

gen PAP_b2_2 = "PAP B2.2"
gen PAP_b3_5 = "PAP B3.5"
gen empl_extras = "EMPL EXTRAS"

local salaryvars PAP_b3_5 div_empl12_n 		  	  div_empl30_n 		  		///
						  div_empl12_ben_n    	  div_empl30_ben_n   	  	///
				 PAP_b2_2 tot_empl_rev12_ben_xof  tot_empl_rev30_ben_xof  	///
						  tot_empl_rev12_chef_xof tot_empl_rev30_chef_xof 	///
						  tot_empl_rev12_hh_xof   tot_empl_rev30_hh_xof   
keep  hhid `salaryvars'
order hhid `salaryvars'
duplicates drop
isid hhid
tempfile salary_rpt_grp
save 	`salary_rpt_grp'

* merging datasets: 

// Generate monthly and yearly dummies for beneficiary
// wrk_sal30 and wrk_sal12 are not aligned with div_*
gen empl_d30_ben = 1 if div_empl30_ben_n > 0 & !missing(div_empl30_ben_n), before(div_empl30_ben_n) 
gen empl_d12_ben = 1 if div_empl12_ben_n > 0 & !missing(div_empl12_ben_n), before(div_empl12_ben_n)
label var empl_d30_ben "Beneficiary had salaried job in the last 30 days"
label var empl_d12_ben "Beneficiary had salaried job in the last 12 months"

***** -----| bring in all HHs and insert true zeros
merge 1:1 hhid using "${constructed_${phase}}/identification", keepusing(consent)
assert consent == 1
drop _merge consent
merge 1:1 hhid using `employment_margins', gen(_m)

local employment_vars div_empl12_n div_empl12_ben_n empl_d12_ben 	///
					  div_empl30_n div_empl30_ben_n empl_d30_ben 	/// 
					  tot_empl_rev12_ben_xof 						///
					  tot_empl_rev30_ben_xof						///
					  tot_empl_rev12_hh_xof 						///
					  tot_empl_rev30_hh_xof  						///
					  tot_empl_rev12_chef_xof   					///
					  tot_empl_rev30_chef_xof  						///
					  sal_empl_ben tot_empl_time_month_ben 			///
					  sal_empl_chef tot_empl_time_month_chef

foreach var in `employment_vars' {
	replace `var' = 0 if `var' == .
} 

drop PAP_b3_5 PAP_b2_2 _m 

compress
save "${constructed_${phase}}/employment", replace



********************************************************************************
* Ag vs Non-AG Employment													   *
********************************************************************************

foreach categ in ag nonag {
	if "`categ'" == "ag" local list_act "1, 2, 3"
	else 				 local list_act "4, 5, 6, 7, 8, 9, 10"	
	
	* ------ Salaried employment ------ * 
	
	use "${intermediate_${phase}}/salary_long.dta", clear	
	keep if inlist(empl_type, `list_act')
	
	** beneficiary 
	if "$ph" == "bl" {
		gen `categ'_ben = 1	
		gen `categ'_time_month_ben = (empl_mos*empl_wks*empl_days)/12 if key2 == 1	
		gen `categ'_chef = 1	
		gen `categ'_time_month_chef = (empl_mos*empl_wks*empl_days)/12 if key2 == 2
	}
	else if "$ph" == "fu" {
		gen `categ'_empl_ben = 1
		gen `categ'_time_month_ben = (empl_mos*empl_wks*empl_days)/12
	}	
	
	bysort hhid: egen tot_`categ'_time_month_ben = total(`categ'_time_month_ben)
	replace tot_`categ'_time_month_ben = 30 if tot_`categ'_time_month_ben > 30	
	
	if "$ph" == "fu" {
		keep hhid `categ'_empl_ben tot_`categ'_time_month_ben 
		duplicates drop
		* inserting true zeros (other households who do not have salaried employment)
		merge 1:1 hhid using "${constructed_${phase}}/demographics", keepusing(benef_pos)
		replace `categ'_empl_ben = 0 if `categ'_empl_ben == . 
		replace tot_`categ'_time_month_ben = 0 if tot_`categ'_time_month_ben == . 
		drop _merge benef_pos 
		tempfile `categ'_empl_benef
		save ``categ'_empl_benef'

		** household head
		use "${intermediate_${phase}}/salary_long_chef.dta", clear
		rename key2 empl_pos_chef
		keep if inlist(empl_type_chef, `list_act')
		gen `categ'_empl_chef = 1
		gen `categ'_time_month_chef = (empl_mos_chef*empl_wks_chef*empl_days_chef)/12	
	}
	
	bysort hhid: egen tot_`categ'_time_month_chef = total(`categ'_time_month_chef)
	replace tot_`categ'_time_month_chef = 30 if tot_`categ'_time_month_chef > 30
	
	if "$ph" == "bl" {
		bysort hhid: egen `categ'_empl_ben = total(`categ'_ben)	
		replace `categ'_empl_ben = 1 if `categ'_empl_ben > 1	
		bysort hhid: egen `categ'_empl_chef = total(`categ'_chef)	
		replace `categ'_empl_chef = 1 if `categ'_empl_chef > 1
		local add_var `categ'_empl_ben tot_`categ'_time_month_ben
	}
	keep hhid `categ'_empl_chef tot_`categ'_time_month_chef `add_var'
	duplicates drop

	capture label var `categ'_empl_ben  "Beneficiary Works in Salaried `categ' Employment"
	capture label var `categ'_empl_chef "Chef Works in Salaried `categ' Employment"
	capture label var tot_`categ'_empl_time_month_ben "Beneficiary Days Worked in Salaried `categ' Employment"
	capture label var tot_`categ'_empl_time_month_chef "Chef Days Worked in Salaried `categ' Employment"
	
	* inserting true zeros (other households who do not have salaried employment)
	merge 1:1 hhid using "${constructed_${phase}}/demographics", keepusing(benef_pos)	
	foreach v in `categ'_empl_chef tot_`categ'_time_month_chef `add_var' {	
		replace `v' = 0 if `v' == .	
	}	
	drop _merge benef_pos 
	
	if "$ph" == "bl" {
		tempfile `categ'_empl	
		save ``categ'_empl'
	}
	else if "$ph" == "fu" {
		tempfile `categ'_empl_chef 
		save ``categ'_empl_chef'
	}	
	
	
	* ------ Salaried employment Revenues ------ * 
	/*
		Secondary B.2.2 Wage earnings, beneficiary, 12 months (& 1 month)
		Secondary B.3.5 Count of wage-earning sources 	
	*/
	
	use "${intermediate_${phase}}/salary_long.dta", clear
	keep if inlist(empl_type, `list_act')

	if "$ph" == "bl" {	
		* keep ben only	
		keep if key2 == 1
	}
	keep hhid empl_pos empl_rev30 empl_rev12  
	fix_continuous empl_rev30 empl_rev12
	rename empl_pos   empl_pos_ben
	rename empl_rev30 empl_rev30_ben
	rename empl_rev12 empl_rev12_ben

	reshape wide empl_rev30_ben empl_rev12_ben, j(empl_pos_ben) i(hhid)
	egen div_empl_ben_n = rownonmiss(empl_rev12*) // count at 12 months only

	isid hhid

	preserve
		if "$ph" == "bl" {
			use "${intermediate_${phase}}/salary_long.dta", clear	
			drop if empl_type == .	
			keep if inlist(empl_type, `list_act')
			rename empl_pos empl_pos_chef	
			rename empl_rev30 empl_rev30_chef	
			rename empl_rev12 empl_rev12_chef	
			* keep chef only	
			keep if key2 == 2	
		}
		else if "$ph" == "fu" {
			use "${intermediate_${phase}}/salary_long_chef.dta", clear
			rename key2 empl_pos_chef
			drop if empl_type_chef == .
			keep if inlist(empl_type_chef, `list_act')
		}

		keep hhid empl_pos_chef empl_rev30_chef empl_rev12_chef 
		fix_continuous empl_rev30_chef empl_rev12_chef
		reshape wide empl_rev30_chef empl_rev12_chef , j(empl_pos_chef) i(hhid)
		egen div_empl_chef_n = rownonmiss(empl_rev12_chef*)
		tempfile chef
		save 	`chef'
	restore

	merge 1:1 hhid using `chef', gen(_mchefsal)
	merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos chef_pos)
	keep if _merge == 3
	sort _mchefsal
	gen same = benef_pos == chef_pos
	sort same _mchefsal hhid

	foreach var of varlist empl_rev30_chef* empl_rev12_chef* div_empl_chef_n { 
		// drop chef salary if benef == chef & salaries exist for both
		replace `var' = . if same == 1 & _mchefsal == 3
	}
	drop div_* _mchefsal _merge same *_pos


	rename empl_rev12_chef* rev12*_2 
	rename empl_rev12_ben*  rev12*_1 
	rename empl_rev30_ben*  rev30*_1 
	rename empl_rev30_chef* rev30*_2 

	foreach pos in 1 2 {
		preserve
			keep hhid rev12*_`pos' rev30*_`pos'
			rename rev12*_`pos' rev12*
			rename rev30*_`pos' rev30*
			// reshape --> hhid, status, income then winsorize
			reshape long rev30 rev12, i(hhid) j(bus_pos)
			tempfile bus`pos'
			save 	`bus`pos''
		restore
	}
	use `bus1', clear
	append using `bus2', gen(pos)
	sort hhid pos bus_pos
	label define pos 0 "benef" 1 "chef"
	label values pos pos

	***** -----| Secondary B.2.2
	foreach term in 30 12 {

		gen 	rev`term'_win = rev`term'
		_pctile rev`term' , p(98)
		replace rev`term'_win  = `r(r1)' if !missing(rev`term') & rev`term' > `r(r1)' 
		drop 	rev`term'

		if `term' == 30 local unit day
		if `term' == 12 local unit month
		
		gen rev`term'_win_ben_only = rev`term'_win if pos == 0 // pos = 0: benef only 
		bysort hhid : egen tot_empl_rev`term'_ben_xof = total(rev`term'_win_ben_only)
		replace tot_empl_rev`term'_ben_xof = tot_empl_rev`term'_ben_xof / 1000
		label var tot_empl_rev`term'_ben_xof "B.2.2 ONLY Beneficiary's `term'-`unit' Income from salaried `categ' job wins. (1000 FCFA) at ${phase}"
		// extend across entire hh to fill missings
		sort hhid tot_empl_rev`term'_ben_xof
		bysort hhid (tot_empl_rev`term'_ben_xof): replace tot_empl_rev`term'_ben_xof = tot_empl_rev`term'_ben_xof[1]

		gen rev`term'_win_chef_only = rev`term'_win if pos == 1 // pos = 1: chef only 
		bysort hhid : egen tot_empl_rev`term'_chef_xof = total(rev`term'_win_chef_only)
		replace tot_empl_rev`term'_chef_xof = tot_empl_rev`term'_chef_xof / 1000
		label var tot_empl_rev`term'_chef_xof "ONLY HH HEAD's `term'-`unit' Income from salaried `categ' job wins. (1000 FCFA) at ${phase}"
		// extend across entire hh to fill missings
		sort hhid tot_empl_rev`term'_chef_xof
		bysort hhid (tot_empl_rev`term'_chef_xof): replace tot_empl_rev`term'_chef_xof = tot_empl_rev`term'_chef_xof[1]

		bysort hhid : egen tot_empl_rev`term'_hh_xof = total(rev`term'_win) // no pos condition: chef and benef 
		replace tot_empl_rev`term'_hh_xof = tot_empl_rev`term'_hh_xof / 1000
		label var tot_empl_rev`term'_hh_xof "B.2.2 Beneficiary's and chef's `term'-`unit' Income from salaried `categ' job wins. (1000 FCFA) at ${phase}"

		***** -----| Secondary B.3.5
		byso hhid : egen div_empl`term'_ben_n = count(rev`term'_win_ben_only)
		label var div_empl`term'_ben_n "B.3.5 ONLY Beneficiary's No. of `term'-`unit' Salaried `categ' jobs at ${phase}"
		// extend across entire hh to fill missings
		sort hhid div_empl`term'_ben_n
		bysort hhid (div_empl`term'_ben_n): replace div_empl`term'_ben_n = div_empl`term'_ben_n[1]

		byso hhid : egen div_empl`term'_n = count(rev`term'_win)
		label var div_empl`term'_n "B.3.5 Beneficiary's and chef's No. of `term'-`unit' Salaried `categ' jobs at ${phase}"
	}


	gen PAP_b2_2 = "PAP B2.2"
	gen PAP_b3_5 = "PAP B3.5"
	gen empl_extras = "EMPL EXTRAS"

	local salaryvars PAP_b3_5 div_empl12_n 		  		div_empl30_n 		 		///
							  div_empl12_ben_n    		div_empl30_ben_n    		///
					 PAP_b2_2 tot_empl_rev12_ben_xof  	tot_empl_rev30_ben_xof  	///
							  tot_empl_rev12_chef_xof 	tot_empl_rev30_chef_xof  	///
							  tot_empl_rev12_hh_xof   	tot_empl_rev30_hh_xof   
	keep hhid `salaryvars'
	order hhid `salaryvars'
	duplicates drop
	isid hhid
	tempfile salary_rpt_grp
	save 	`salary_rpt_grp'

	// Generate monthly and yearly dummies for beneficiary
	// wrk_sal30 and wrk_sal12 are not aligned with div_*
	gen empl_d30_ben = 1 if div_empl30_ben_n > 0 & !missing(div_empl30_ben_n), before(div_empl30_ben_n) 
	gen empl_d12_ben = 1 if div_empl12_ben_n > 0 & !missing(div_empl12_ben_n), before(div_empl12_ben_n)
	label var empl_d30_ben "Beneficiary had salaried `categ' job in the last 30 days"
	label var empl_d12_ben "Beneficiary had salaried `categ' in the last 12 months"
	
	***** -----| bring in all HHs and insert true zeros
	merge 1:1 hhid using "${constructed_${phase}}/identification", keepusing(consent)
	assert consent == 1
	drop _merge consent

	local employment_vars div_empl12_n div_empl12_ben_n empl_d12_ben 	///
						  div_empl30_n div_empl30_ben_n empl_d30_ben 	/// 
						  tot_empl_rev12_ben_xof 						///
						  tot_empl_rev30_ben_xof 						///
						  tot_empl_rev12_chef_xof 						///
						  tot_empl_rev30_chef_xof  						///
						  tot_empl_rev12_hh_xof 						///
						  tot_empl_rev30_hh_xof

	foreach var in `employment_vars' {
		replace `var' = 0 if `var' == .
	} 
	
	if "`categ'" == "ag" {
		if "$ph" == "bl" {
			// true zeros for beneficiary variables
			merge 1:1 hhid using "${constructed_${phase}}/demographics", keepusing(benef_pos)	
			drop _merge	
			ds *ben* *hh*	
			local b_2_2_vars `r(varlist)'	
			foreach var in `b_2_2_vars' {	
			replace `var' = . if benef_pos == .	
			}	
			drop benef_pos 	
		}
	}
	
	rename tot_empl_rev12_chef_xof 	tot_`categ'_empl_rev12_chef_xof 
	rename tot_empl_rev12_ben_xof 	tot_`categ'_empl_rev12_ben_xof 
	keep hhid tot_`categ'_empl_rev12_chef_xof tot_`categ'_empl_rev12_ben_xof
	drop if hhid == .
	duplicates drop
	isid hhid
	tempfile `categ'_empl_rev 
	save ``categ'_empl_rev'	
}

* ------ Export ------ * 

if "$ph" == "bl" {
	use `ag_empl', clear	
	merge 1:1 hhid using `nonag_empl', gen(m1)	
	merge 1:1 hhid using `ag_empl_rev', gen(m2)	
	merge 1:1 hhid using `nonag_empl_rev', gen(m3)	
	drop m1 m2 m3
} 
else if "$ph" == "fu" {
	use `ag_empl_benef', clear 
	merge 1:1 hhid using `nonag_empl_benef', gen(m1)
	merge 1:1 hhid using `ag_empl_chef', gen(m2)
	merge 1:1 hhid using `nonag_empl_chef', gen(m3)
	merge 1:1 hhid using `ag_empl_rev', gen(m4)
	merge 1:1 hhid using `nonag_empl_rev', gen(m5)	
	drop m1 m2 m3 m4 m5
}

compress 
save "${constructed_${phase}}/ag_nonag_employment.dta", replace