	***************************************************************************
	*																		  *
	*		    PSYCHOLOGY/MENTAL HEALTH CLEANING CHAD ASP IE 			 	  *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning psyhology/mental health data  
    */
	****************************************************************************

********************************************************************************
* PSYCHOLOGY/MENTAL HEALTH												 	   *
********************************************************************************

use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear
merge 1:1 hhid using "${constructed_${phase}}/identification.dta", ///
	gen(_mtreatment) keepusing(pm_treatment)
keep if consent == 1 
assert _mtreatment == 3

keep hhid pm_treatment consent `healthvar' start_mental - end_mental key
drop consent
merge 1:1 hhid using "${constructed_${phase}}/demographics.dta", ///
	gen(_mdemog) keepusing(benef_pos)
assert _mdemog == 3
					rename stair_satis_today_new 	stair_satis_today // 1-3 (change in status)
					rename stair_status_today_new 	stair_status_today // 1-10
if "$ph" == "fu" 	rename stair_inner_peace		stairs_peace

* assertions 
foreach var of varlist cd* srq* {
	// not recoded as mentioned in PAP (from 0-7 to 1-4)
	// MRT at FU has -999 and -888 as options for cd questions
	assert inrange(`var', 0, 7) | missing(`var')
}
foreach var of varlist stair* { // includes stairs_peace at FU
	assert inrange(`var', 1, 10) | missing(`var') // .g at BL and . normal at FU2
}

// Some vars have 1-4 at BL and 5-8 at FU
foreach var in gse* ros4 worktogether_new {
	// if var exists (not all vars exist in each survey)
	capture confirm var `var'
	if _rc == 0 { 
		assert inrange(`var', 1, 4) | missing(`var') // FU MRT includes -999 and -888		
		recode `var' (1=5) (2=6) (3=7) (4=8)
	}
}

if "$ph" == "fu" assert inrange(health_ment, 1, 5) | missing(health_ment)


********************************************************************************
**************   Secondary B.4. Psycho social well being      ******************

********************************************************************************
**** Secondary B.4.1 Mental health and well-being 
* Factor z-score index of 5 components
// reverse depression and disability so that all variables are increasing in wellbeing
// reverse using revrs package from SSC
// no missing values across all components

label var cd1 		"10_16.1: No. of days felt the details of life bothered you more than usual" // bad
label var cd2 		"10_16.2: No. of days felt you had trouble concentrating on what you were doing" // bad
label var cd3_new 	"10_16.3: No. of days felt sad" // bad
label var cd4 		"10_16.4: No. of days felt that what you were doing took all your energy" // bad
label var cd5 		"10_16.5: No. of days felt you were confident in the future" // GOOD
label var cd6_new 	"10_16.6: No. of days felt nervous, tense, or worried" // bad
label var cd7 		"10_16.7: No. of days felt you had trouble sleeping peacefully" // bad
label var cd8 		"10_16.8: No. of days felt happy" // GOOD
label var cd9 		"10_16.9: No. of days felt alone" // bad
label var cd10_new 	"10_16.10: No. of days felt so tired that you could do nothing" // bad

*** new segment about depression cutoffs
// recode all
foreach var of varlist cd* {
	gen `var'_v2 = `var'
	recode `var'_v2 (0=0)(2=1)(3=2)(4=2)(5=3)(6=3)(7=3)
}
ds *_v2
egen cesd_sum = rowtotal(`r(varlist)'), m // only if not missing
gen depressed_11 = cesd_sum >= 11 & !missing(cesd_sum)
gen depressed_13 = cesd_sum >= 13 & !missing(cesd_sum)
gen depressed_15 = cesd_sum >= 15 & !missing(cesd_sum)
 
ds cd*
local all_cd `r(varlist)'
local happy cd5 cd8
local reverse_cd : list all_cd - happy // leave out positive variables (5: happy, 8: confident)
foreach var in `reverse_cd'{
	// not recoded as mentioned in PAP (from 0-7 to 1-4)
	// MRT at FU has -999 and -888 as options for cd questions
	gen `var'_good = `var'
	recode `var'_good (0=7) (1=6) (2=5) (3=4) (4=3) (5=2) (6=1) (7=0) 
}
local less_dprsd_subcomp cd1_good cd2_good cd3_new_good cd4_good cd5 ///
					  cd6_new_good cd7_good cd8 cd9_good cd10_new_good
egen less_depressed = rsum(`less_dprsd_subcomp'), missing
label var less_depressed "B.4.1.1 Less Depression (sum of non-depressed days in last week) ($ph)"

// not recoded as mentioned in PAP. sum, reversed 
label var srq1 "10_17.10 No. of days you have had a headache" // bad
label var srq3 "10_17.3 No. of days your digestion was bad" // bad
label var srq4 "10_17.4 No. of days you had difficulty fulfilling your family rspnsblties" // bad
label var srq5 "10_17.5 No. of days you had difficulties in your daily work" // bad

ds srq*
foreach var in `r(varlist)' {
	gen `var'_good = `var'
	recode `var'_good (0=7) (1=6) (2=5) (3=4) (4=3) (5=2) (6=1) (7=0) 
}
local lses_dis_subcomp srq1_good srq3_good srq4_good srq5_good
egen less_disability = rsum(`lses_dis_subcomp'), missing
label var less_disability "B.4.1.2 Less Disability (sum of non-disabled days in last week) ($ph)"
// all variables now increasing
label var stair_satis_today    "B.4.1.3 Satisfaction today: step on 10-step stairs ($ph)"
capture label var stairs_peace "B.4.1.4 Inner Peace: step on 10-step stairs at $ph" // inner peace (DNE at BL)

	// trimmed because other index components are conditional on isnot_sub
	if "$ph" == "fu" {
		sum health_ment
		local mean `r(mean)'
		local sd `r(sd)'
		gen health_ment_z = health_ment
		replace health_ment_z = (health_ment_z - `mean') / `sd'

		label var health_ment_z		"B.4.1.5 Standardized: mental health is poor, fair, good, vgood, or excellent"		
	}

	// collect variables of interest. All increasing in wellbeing
	if "$ph" == "fu" local fu_vars stairs_peace health_ment_z 
	local mental_vars_keep `less_dprsd_subcomp' less_depressed `lses_dis_subcomp' less_disability ///
							stair_satis_today `fu_vars'
	local mental_vars 							less_depressed 					  less_disability ///
							stair_satis_today `fu_vars' 
							
	*keep hhid pm_treatment `mental_vars'
	egen missing = rowmiss(`mental_vars')

		/*// handle missing values
		assert less_depressed == 0 & disability == 0 if ///
				stair_satis_today == . | ///
				stairs_peace == . | ///
				health_ment == .*/
		// whenever stairs & health_ment are missing, less_depressed and disability are missing too

	zindex `mental_vars', gen(ment_hlth_index) condition(pm_treatment == 0)
	label variable ment_hlth_index "B.4.1 Mental Health Z-index ($ph)"

	// Compute factor zscore
	egen miss_count = rowmiss(`mental_vars')
	gen index_name = "ment_hlth"	// used as local in index varname in factorzscore
	factorZScore `mental_vars' pm_treatment miss_count index_name
	label variable ment_hlth_f_index "B.4.1 Mental Health FZ-index ($ph)"

	
****************************************************************************
**** Secondary B.4.2 Self and social worth 
* Factor z-score index of 2 components
// no missing values

label var gse1 "10_8.1 You can resolve problems if you put enough effort" // good
label var gse3 "10_8.2 It's easy for you to stay on the path you are mapped out and accomplish your goals in life." // good
label var gse4 "10_8.3 You trust that you are capable of doing well in the face of unexpected events." // good
label var gse7 "10_8.4 You can stay calm when faced with difficulties/have the capacity to adapt." // good
label var gse8 "10_8.5 When you need to fix a problem, you can usually find several solutions." // good
label var gse9 "10_8.6 If you find yourself in a difficult situation, you can usually find a solution." // good
label var ros4 "10_9.1 You are able to do things as well as most people."

ds gse* ros4
local gse_comp `r(varlist)'
foreach var in `gse_comp' {
	recode `var' (5=1) (6=2) (7=3) (8=4)
}
// sum of 7 questions from GSE-10 & 1 question from Rosenberg Self-Esteem; (1-4) 
egen gse_sum = rsum(`gse_comp'), m // only where all exist  // no missing observations here. All increasing already		
label var gse_sum "B.4.2.1 Self-efficacy at $ph"
rename gse_sum gse_sum_trim // because missing component 2

// social standing, (1-10)
if "$ph" == "bl" local soc_stand_comp                      stair_respect_new stair_opinion_new stair_status_today
if "$ph" == "fu" local soc_stand_comp stair_good_today_new stair_respect_new stair_opinion_new stair_status_today
egen social_stand_sum = rsum(`soc_stand_comp'), m // only where all exist
label var social_stand_sum "B.4.2.2 Social Standing at $ph"
// no missing observations here either

// collect variables of interest and generate gse_sum
	local worth_vars_keep `gse_comp' gse_sum_trim `soc_stand_comp' social_stand_sum
	zindex gse_sum_trim, gen(gse_index) condition(pm_treatment == 0)
	label variable gse_index "B.4.2 Self Efficacy Z-index at $ph"

zindex social_stand_sum, gen(soc_stand_index) condition(pm_treatment == 0)
label variable soc_stand_index "B.4.2 Social Standing Z-index at $ph"


********************************************************************************
**** Secondary B.4.3 Future expectations index 

	// collect variables of interest
	local future_vars stair_status_future_new stair_satis_future_new 		

	//create factor z-score index using variables after dropping missing observations
	zindex `future_vars', gen(future_expct_index) condition(pm_treatment == 0)
	label variable future_expct_index "B.4.3 Future Expectations Z-index ($ph)"

	// Compute factor zscore
	egen miss_count = rowmiss(`future_vars')
	gen index_name = "future_expct"	// used as local in index varname in factorzscore
	factorZScore `future_vars' pm_treatment miss_count index_name 
	label variable future_expct_f_index "B.4.3 Future Expectations FZ-index ($ph)"
	

********************************************************************************
**** Save 

	// order variables and drop unwanted ones
	order hhid `mental_vars_keep' ment_hlth_index ment_hlth_f_index ///
				depressed_11 depressed_13 depressed_15 				///
				`worth_vars_keep' soc_stand_index gse_index  		///			   
				`future_vars' future_expct_index future_expct_f_index

keep hhid 	`mental_vars_keep' ment_hlth_index ment_hlth_f_index 	///
			depressed_11 depressed_13 depressed_15					///
			`worth_vars_keep' soc_stand_index gse_index  			///			   
			`future_vars' future_expct_index future_expct_f_index
compress
save "${constructed_${phase}}/psychology.dta", replace
