
	***************************************************************************
	*																		  *
	*		    			   SHOCKS CLEANING CHAD ASP IE 			 		  *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning shocks data
    */

	****************************************************************************
	
	use 		"${intermediate_${phase}}/chad_main_${phase_yr}", clear
	keep 		hhid consent start_shocks - end_shocks
	keep if 	consent == 1
	drop 		consent
	compare 	shock_n shock_list
	
	** shock_n
	/* There are cases in which shock_n (count of shocks household experiences) is over-counted
	Compare shock_n with shock_list --I generate a new shock count variable */
	egen 		shock_count = anycount(shock1-shock13), v(1)
	label var 	shock_count "Number of reported shocks in last 12 months"

	// check that shock`i' variables are listed in shock_list
	replace 	shock_list = trim(itrim(shock_list))
	replace 	shock_list = " "+shock_list+" "

	forvalues i = 1/13 {
		gen 	tocheck_`i' = 0
		replace tocheck_`i' = 1 if ((shock`i' == 1 & regexm(shock_list, " `i' ") == 0) | (shock`i' == 0 & regexm(shock_list, " `i' ") == 1))
		assert 	tocheck_`i' == 0 
		drop 	tocheck_`i' 
		}

	/** 
	shock1	"Sécheresse/Pluies irrégulières"? 
	shock2	"Inondations" ?
	shock3	"Maladies des cultures"?
	shock4	"Maladies des animaux"?
	shock5	"Hausse des prix des intrants agricoles"?
	shock6	"Baisse du prix des produits agricoles"?
	shock7	"Hausse des prix des produits alimentaires"?
	shock8	"Perte importante du revenu non agricole du ménage  (non liée à un accident ou une maladie)"?
	shock9	"Maladie grave ou accident d'un membre du ménage"?
	shock10	"Décès d'un membre du ménage"?
	shock11	"Divorce, séparation"?
	shock12	"Vol d'argent, de biens ou de récolte"?
	shock13	"Autre (précisez)"?
	***/ 

	*** clean 'others'
	replace 	shock_o = trim(itrim(lower(shock_o)))

	gen 		shock_o_code = .
	// 14 - pests
	// 15 - prolonged absence of household member
	// 16 - decreased harvest
	// 17 - famine
	// 18 - home destroyed

	*--------------------------------- 1 --------------------------------------*
	sort 		shock_o
	encode 		shock_o, gen(shock_check)
	tab 		shock_check
	replace 	shock_o_code = 1 if shock_o == "le vent"
	replace 	shock_o_code = 1 if shock_o == "le vent a déchirée une partie de la voile de m'bar"
	replace 	shock_o_code = 1 if shock_o == "le vent torrentiel"
	replace 	shock_o_code = 1 if shock_o == "rareté des precipitations hivernales"
	replace 	shock_o_code = 1 if shock_o == "vent fort qui a detruit leurs habitat"
	replace 	shock_o_code = 1 if shock_o == "vents trop fort"
	
	*--------------------------------- 4 --------------------------------------*
	replace 	shock_o_code = 4 if shock_o == "mort de 2 chèvres"
	replace 	shock_o_code = 4 if shock_o == "perte de moutons"
	
	*--------------------------------- 9 --------------------------------------*
	replace 	shock_o_code = 9 if shock_o == "accident de voiture"
	replace 	shock_o_code = 9 if shock_o == "c est son marie qui as un problème mantal"
	replace 	shock_o_code = 9 if shock_o == "c'est mon enfant qui es malade et je cherche de l'argent et je ne trouve pas"
	replace 	shock_o_code = 9 if shock_o == "hospitalisation de ma femme"
	replace 	shock_o_code = 9 if shock_o == "maladie"
	replace 	shock_o_code = 9 if shock_o == "maladie du frere"
	replace 	shock_o_code = 9 if shock_o == "maladie mental d'un membre"
	replace 	shock_o_code = 9 if shock_o == "y as deux de ces enfant qui ont des maladie mental"

	#delimit;
	replace 	shock_o_code = 9 
	if 			inlist(shock_o, 
	"accidents d'un membre hors ménage",
	"le chef de menage a perdu son œil droit",
	"les petites maladies qui dérangent tous les membres de la famille.",
	"pas cultiver a cause de maladie");
	#delimit cr

	*--------------------------------- 10 -------------------------------------*
	replace 	shock_o_code = 10 if shock_o == "decé fils de sa petite soeur"
	replace 	shock_o_code = 10 if shock_o == "dècès"
	replace 	shock_o_code = 10 if shock_o == "décès de sa mere"
	replace 	shock_o_code = 10 if shock_o == "absence permanente du conjoint"
	replace 	shock_o_code = 10 if shock_o == "cas décès d'un parent hors menage"
	replace 	shock_o_code = 10 if shock_o == "cas décès hors ménage"
	replace 	shock_o_code = 10 if shock_o == "accidents d'un membre hors ménage"
	replace 	shock_o_code = 10 if shock_o == "dece d un cousin"
	replace 	shock_o_code = 10 if shock_o == "dece de 2 freres"
	replace 	shock_o_code = 10 if shock_o == "dece de la soeur de repondante clef"
	replace 	shock_o_code = 10 if shock_o == "dece de membres du village incendie des cases du village"
	replace 	shock_o_code = 10 if shock_o == "dece de 2 freres"
	replace 	shock_o_code = 10 if shock_o == "dece de mere du chef de menage , perte de recolte par insectes et oiseaux"
	replace 	shock_o_code = 10 if shock_o == "dece de sa fille aine"
	replace 	shock_o_code = 10 if shock_o == "dece du neveu"
	replace 	shock_o_code = 10 if shock_o == "décès"

	#delimit;
	replace 	shock_o_code = 10 
	if 			inlist(shock_o, 
	"dece d un cousin","dece de 2 freres", "dece de la soeur de repondante clef",
	"dece de ma mere","dece de membres du village incendie des cases du village",
	"dece de mere du chef de menage" , "perte de recolte par insectes et oiseaux"
	"dece de sa fille aine","dece du neveu","décès")

	| 			inlist(shock_o, 
	"cas décès d'un parent hors menage",
	"cas décès hors ménage",
	"pere du chef de menage decede",
	"décès d'un membre hors menage","décès d'un membre hors menage")

	| 			inlist(shock_o, 
	"décès d'un parent hors menage","décès d'un parent hors ménage",
	"décès d'un parent hors ménage.","décès d'un parent hors ménage.",
	"décès d'un parents hors menage","décès d'un parents hors ménage",
	"décès d'un parents.","décès d'une cousine","décès de grand père de la femme du chef de ménage.")
	| 			inlist(shock_o, 
	"décès de l'oncle de chef de menage","décès de l'oncle du chef de ménage",
	"décès de la grand-mère de la conjointe","décès de la mère de l'épouse de chef de ménage.",
	"décès de la troisième épouse de chef de ménage.","décès de mon grand père","décès du père de chef de ménage",
	"décès du père de chef de ménage","décès du père de la conjointe")
	|  			inlist(shock_o, 
	"décès d'un parent hors du menage","décès d'un parent hors du ménage.",
	"décès d'un parent hors menage","décès d'un parent hors menage",
	"décès hors ménage","décédé","décés",
	"décès d'un membre hors ménage","décès d'un oncle hors ménage")
	|  			inlist(shock_o, 
	"décès du père de la répondant clé","décès du père du chef de ménage",
	"décès du père du chef de ménage","décès du tutrice de la repondante clef hors du menage",
	"décès d'un frere","décès d'un frère hors menage","décès d'un membre hors menage","décès d'un membre hors menage", 
	"la mort du grand frère du chef de menage")
	| 			inlist(shock_o, 
	"incendie",
	"incendie dans leur foyer",
	"incendie de la maison du ménage",
	"incendie des cases dece des membres du village"
	"incendié")
	;
	#delimit cr

	*--------------------------------- 13 -------------------------------------*
	replace 	shock_o_code = 13 if shock_o == "c'est un peuvre as chaque fois ils pense as ça"
	replace 	shock_o_code = 13 if shock_o == "endetté"
	replace 	shock_o_code = 13 if shock_o == "extreme pauvrete"
	replace 	shock_o_code = 13 if shock_o == "j'ai pas vue mes enfants depuis 5ans"
	replace 	shock_o_code = 13 if shock_o == "la faim et la soif"
	replace 	shock_o_code = 13 if shock_o == "la pauvrete"
	replace 	shock_o_code = 13 if shock_o == "logement"
	replace 	shock_o_code = 13 if shock_o == "manque de moyen pour survivre"
	replace 	shock_o_code = 13 if shock_o == "mbare detruite"
	replace 	shock_o_code = 13 if shock_o == "na pas de marie agee de 29 ans"
	replace 	shock_o_code = 13 if shock_o == "pauvretés"
	replace 	shock_o_code = 13 if shock_o == "rien en signalé"
	replace 	shock_o_code = 13 if shock_o == "sa filles qui es tombé en seinte"
	replace 	shock_o_code = 13 if shock_o == "si elle pense de son fils décédé"
	replace 	shock_o_code = 13 if shock_o == "soue"
	replace 	shock_o_code = 13 if shock_o == "conflis inter village et éleveur agriculteurs"
	replace 	shock_o_code = 13 if shock_o == "conflit agriculteur éleveur"
	replace 	shock_o_code = 13 if shock_o == "conflit agriculteurs eleveurs"
	replace 	shock_o_code = 13 if shock_o == "conflit agriculteurs éleveurs faisant 2 morts et plusieurs blessés"
	replace 	shock_o_code = 13 if shock_o == "conflit de chefferie entre bessey1 et bessey 2 faisant plusieurs victimes le 14 avril 2018"
	replace 	shock_o_code = 13 if shock_o == "conflit entre nos deux communauté"
	replace 	shock_o_code = 13 if shock_o == "conflit opposant la chefferie de besseye1 et besseye2 faisant plusieurs victimes, dont les enfants"
	replace 	shock_o_code = 13 if shock_o == "conflit éleveur agriculteur"
	replace 	shock_o_code = 13 if shock_o == "conflits éleveurs - agriculteurs"
	replace 	shock_o_code = 13 if shock_o == "champ devaste par les animaux"
	replace 	shock_o_code = 13 if shock_o == "champ devaster par oiseaux"
	replace 	shock_o_code = 13 if shock_o == "champ dévasté par les boeufs"
	replace 	shock_o_code = 13 if shock_o == "champs devaste par les boeufs"
	replace 	shock_o_code = 13 if shock_o == "champs dévasté par des boeufs"
	replace 	shock_o_code = 13 if shock_o == "insécurité"

	#delimit;
	replace 	shock_o_code = 13 
	if 			inlist(shock_o, 
	"conflis inter village et éleveur agriculteurs",
	"conflit agriculteur éleveur",
	"conflit agriculteurs eleveurs",
	"conflit agriculteurs éleveurs",
	"conflit agriculteurs éleveurs",
	"conflit agriculteurs éleveurs")
	| 			inlist(shock_o, 
	"conflit agriculteurs éleveurs faisant 2 morts et plusieurs blessés",
	"conflit de chefferie entre bessey1 et bessey 2 faisant plusieurs victimes le 14 avril 2018",
	"conflit entre nos deux communauté",
	"conflit opposant la chefferie de besseye1 et besseye2 faisant plusieurs victimes, dont les enfants",
	"conflit éleveur agriculteur",
	"conflits éleveurs - agriculteurs")
	| 			inlist(shock_o,
	"manque d'argent","manque d'eau au village",
	"manque de nourriture",
	"manque de nourriture a certaines périodes de l'année"
	"manque de nourriture et d'ustensiles"
	"manque de nourriture et de soins médicaux"
	"manque de nourriture et la non scolarisation des enfants"
	"manque de nourriture et rareté d'eau dans le village"
	"manque de nourriture et soins médicaux")
	| 			inlist(shock_o,
	"manque de nourriture surtout"
	"manque de structure d'éducation adéquate",
	"j'ai pris de bon et je 'arrive pas a payer",
	"je suis très pauvre,la pauvreté m' a touche",
	"la faim et pauvrete",
	"la pauvrete", "perte d'emploi et manque de nourriture",
	"la pauvreté qui nous frappe tous les jours",
	"difficulté d'approvisionnement d'eau",
	"l'eau de boisson est rare")
	| 			inlist(shock_o,
	"pauvrete","je suis veuve et pauvre avec des enfants.",
	"ma main est vide","ma main est vide et je n'ai pas un bon travail",
	"ma main est vide et je suis mère des enfants",
	"main est vide","main vide")
	| 			inlist(shock_o,
	"mésentente avec le chef de ménage et mauvaise récolte",
	"mésentente avec le conjoint","polémique de chefferie",
	"problème avec les peuls généralement appelés mbororo",
	"très soucieux à cause de l'infertilité du sol.","violence conjugale");
	#delimit cr

	*--------------------------------- 15 -------------------------------------*
	replace 	shock_o_code = 15 if shock_o == "départ du conjoint depuis deux ans"

	*--------------------------------- 16 -------------------------------------*
	replace 	shock_o_code = 16 if shock_o == "le feu de brousse"
	replace 	shock_o_code = 16 if shock_o == "les feu de brousse"
	replace 	shock_o_code = 16 if shock_o == "perdue toute sa récolte"
	replace 	shock_o_code = 16 if shock_o == "perte de recolte total cause par des kirkes"
	#delimit ;
	replace 	shock_o_code = 16 if inlist(shock_o,"mauvaise récolte et absence constante du conjoint",
	"mauvaise récolte et absence permanente du conjoint"
	"mauvaise récolte et conflit éleveurs-agriculteurs",
	"mauvaise récolte et manque de nourriture",
	"mauvaise récolte et énorme dépenses en frais médicaux",
	"mauvaise récolte","absence de son epoux",
	"absence permanente du conjoint")
	| 			inlist(shock_o,"perte d'une grande partie de récolte",
	"perte de culture sésame par les insectes et destruction de culture sorgho par les éleveurs.",
	"perte de recolte due aux oiseaux",
	"perte de récolte",
	"perte des produits agricoles",
	"champ devaste par les animaux",
	"champ devaster par oiseaux",
	"champ devaster par oiseaux",
	"champ dévaster par oiseaux")
	| 			inlist(shock_o,
	"champ dévasté par les boeufs",
	"champs devaste par les boeufs",
	"champs dévasté par des boeufs",
	"mon champs a était dévasté par les animaux",
	"destruction complète de mon champ de sésame par les insectes.",
	"destruction du champ par les phacoheres",
	"champ dévasté par les animaux",
	"saccage des champs par les animaux",
	"oiseaux dévaster champ");
	#delimit cr

	*--------------------------------- 17 -------------------------------------*
	replace  	shock_o_code = 17 if shock_o == "famine"

	*--------------------------------- 18 -------------------------------------*
	replace 	shock_o_code = 18 if shock_o == "brûlure de la cuisine et magasin en même temps"
	replace 	shock_o_code = 18 if shock_o == "inondation des parents hors du menage"

	// replace shock1 - shock12 = 1 if recoded
	forvalues i = 1/12 {
		// update shock13 (other shock) = 0 if recoded shock13
		replace shock13 = 0 if   shock_o_code == `i'
		// update shock`i' = 1 if recoded
		replace shock`i' = 1  if shock_o_code == `i'
	}

	egen 		shock_count_recode = anycount(shock1-shock13), v(1)
	label var 	shock_count_recode "Number of reported shocks in last 12 months (recode)"
	compare  	shock_count shock_count_recode
	drop 		shock_count_recode shock_n
	ren 		shock_count shock_n

	** shock_covar
	gen 		shock_covar = (shock1 == 1 | shock2 == 1)
	label var 	shock_covar "experienced drought/irregular rain or floods in last 12 months"

	** shock_price
	gen 		shock_price = (shock5 == 1 | shock6 == 1 | shock7 == 1)
	label var 	shock_price "experienced price shock in last 12 months (agricultural inputs, food, product)"

	** shock_idio
	gen 		shock_idio = (shock3 == 1 | shock4 == 1 | shock9 == 1 | shock10 == 1 | shock11 == 1 | shock12 == 1 | shock13 == 1)
	label var 	shock_idio "experienced crop or livestock disease, sickness, death, divorce or theft, or other"

	**	sho_dro
	gen			sho_dro = shock1
	label var	sho_dro	"Shock: drought / irregular rain"

	**	sho_flo
	gen			sho_flo = shock2
	label var	sho_flo	"Shock: floods"

	**	sho_crop
	gen			sho_crop = shock3
	label var	sho_crop	"Shock: crop disease"

	**	sho_ani
	gen			sho_ani = shock4
	label var	sho_ani		"Shock: livestock disease"

	**	sho_incinpt
	gen			sho_incinpt = shock5
	label var	sho_incinpt	"Shock: increase of price of agricultural inputs"

	**	sho_decag
	gen			sho_decag = shock6
	label var	sho_decag	"Shock: decrease of price of agricultural products"

	**	sho_incfood
	gen			sho_incfood = shock7
	label var	sho_incfood	"Shock: increase of food price"

	**	sho_nagloss
	gen			sho_nagloss = shock8
	label var	sho_nagloss	"Shock: loss of non-agricultural revenue"

	**	sho_sick
	gen			sho_sick = shock9
	label var	sho_sick	"Shock: sickness"

	**	sho_death
	gen			sho_death = shock10
	label var	sho_death	"Shock: death"

	**	sho_div
	gen			sho_div = shock11
	label var	sho_div	"Shock: divorce"

	**	sho_ste
	gen			sho_ste = shock12
	label var	sho_ste	"Shock: theft"

	**	sho_o
	gen			sho_o = shock13
	label var	sho_o	"Shock: other"


	****************************************************************************
	*** Export 
	
	keep 		hhid shock_n shock_covar - sho_o
	if "$ph" == "fu" {
		preserve 	
		   use "${intermediate_${phase}}/shocks_wide.dta", clear
		   
		   keep hhid shock_askabout_1 sho_rev_1 sho_live_1 sho_stock_1 sho_save_1 sho_consum_1  ///
					 sho_asset_1 sho_educ_1 shock_askabout_2 sho_rev_2 sho_live_2 sho_stock_2   ///
					 sho_save_2 sho_consum_2 sho_asset_2 sho_educ_2 shock_askabout_3 sho_rev_3  ///
					 sho_live_3 sho_stock_3 sho_save_3 sho_consum_3 sho_asset_3 sho_educ_3
		   
		   foreach v in rev live stock save consum asset educ {
				gen sho_`v' = 0
				replace sho_`v' = . if sho_`v'_1 == . & sho_`v'_2 == . & sho_`v'_3 == .
				replace sho_`v' = 1 if sho_`v'_1 == 1 | sho_`v'_2 == 1 | sho_`v'_3 == 1
		   }
		   
		   keep hhid sho_rev sho_live sho_stock sho_save sho_consum sho_asset sho_educ	
		   isid hhid 
		   tempfile shock_coping_strategies
		   save    `shock_coping_strategies'
		restore
		merge 1:1 hhid using `shock_coping_strategies', gen(_mCoping)
		drop _mCoping
	}
	 
	compress
	save "${constructed_${phase}}/shocks.dta", replace
