	***************************************************************************
	*																		  *
	*		    	FOOD SECURITY CLEANING CHAD ASP IE 			 		 	  *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning food security 
    */

	****************************************************************************

	********************************************************************************
	* 							FOOD SECURITY (FIES)							   *
	********************************************************************************

		********************************************************************************
		use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear 

		********************************************************************************
		***  Secondary B.1.1 (and Primary A.1.1) Food Insecurity 

			
			capture program drop setup_and_reverse
		program setup_and_reverse


			keep if consent == 1
			drop consent

			rename food* hunger*

			// Label
			label var hunger1 "Dummy: Household/members worried about not having enough food"
			label var hunger2 "Dummy: Household/members unable to eat nutritious and healthy foods"
			label var hunger3 "Dummy: Household/members had to eat a smaller variety of foods"
			label var hunger4 "Dummy: Household/members had to skip a meal"
			label var hunger5 "Dummy: Household/members ate less than they thought they should"
			label var hunger6 "Dummy: Household ran out of food"
			label var hunger7 "Dummy: Household/members were hungry but did not eat"
			label var hunger7b "Frequency: Household/members were hungry but did not eat"
			label var hunger8 "Dummy: Household/members went an entire day without eating"
			label var hunger8b "Frequency that household/members went an entire day without eating"

			// recode missing
			replace hunger8b = 0 if missing(hunger8b) & hunger8 == 0
			replace hunger7b = 0 if missing(hunger7b) & hunger7 == 0

			sort hhid
			keep hhid hunger?

			ds hunger1 hunger2 hunger3 hunger4 hunger5 hunger6 hunger7 hunger8
			foreach var in `r(varlist)' {
				gen `var'_rvrs = `var'
				recode `var'_rvrs (0=1) (1=0)
				
				local lab : var label `var'
				label var `var'_rvrs "Reversed, `lab'"
			}
			keep hhid hunger?_rvrs
			rename hunger*_rvrs hunger_rvrs*
			
			********************************************************************************
			***  Secondary B.1.1 (and Primary A.1.1) Food Insecurity -- Raw sum
			ds hunger_rvrs*
			egen FIES_rvrs_raw = rowtotal(`r(varlist)'), m // no missing values in Niger as food* vars were required
			label var FIES_rvrs_raw "A.1 REVERSED food insecurity experience scale, raw score [0-8], 12 months"
			* divide by 2 for 0-8 range: 
			replace FIES_rvrs_raw = FIES_rvrs_raw/2
			assert inrange(FIES_rvrs_raw, 0, 8) | missing(FIES_rvrs_raw)
			// higher is less insecure (better)

		end


		setup_and_reverse // execute program above
			
			drop if hunger_rvrs1 == .


		/*
		// testing zindex
		ds hunger*
		zindex `r(varlist)', gen(FIES)
		// 1 standardize
		foreach var in `r(varlist)' {
			qui sum `var'
			gen `var'_z = (`var' - `r(mean)' )/ `r(sd)'
		}
		// 2 compute row-wise averages
		egen hunger_z_mean = rowmean(hunger*_z)
		// 3 standardize row-wise averages
		qui sum hunger_z_mean
		gen FIES_mine = (hunger_z_mean - `r(mean)' )/ `r(sd)'
		// confirm correct
		assert FIES_mine == FIES
		*/

		********************************************************************************
		***  Secondary B.1.1 (and Primary A.1.1) Food Insecurity -- RASCH model
		** step 1: collect baseline weights
		// generate severity parameters

		** ---- | Approach 1: Rasch Model using clogit 
		preserve
			reshape long hunger_rvrs, i(hhid) j(insecurity)
			levelsof insecurity, local(count)
			foreach num in `count' {
				gen Th`num' = -(insecurity==`num')
			}

			clogit hunger_rvrs Th2-Th8, group(hhid) // ///----------///// RUN RASCH MODEL
			matrix my_reg = r(table) // collect results
		// 	predict yhat_xb, xb
		// 	predict yhat_score, score
			
			mat list my_reg
			matrix pt_est = (0, my_reg[1,1..7]) // collect and adjust point estimates

			// stopped doing this once I found example 28g in sem manual
		// 	forval i = 1/8 {
		// 		local w`i' = pt_est[1,`i']
		// 		dis "w`i': `w`i''"
		// 		local w_tot = `w_tot' + `w`i''
		// 	}
		// 	dis "`w_tot'"
		// 	forval i = 1/8 {
		// 		local w_rel_`i' = `w`i'' / `w_tot'
		// 		dis "w`i': `w_rel_`i''"
		// 	}
		restore


		** ---- | Approach 2: Rasch Model using gsem
		// 1-PL IRT model with unconstrained variance following SEM manual example 28g at 
		// https://www.stata.com/manuals/semexample28g.pdf#semexample28g
		gsem (Food_insec -> (hunger_rvrs*)@1), logit
		mat A = r(table)
		mat A = A[1,1...]
		mat weights_$ph = A[1,2],A[1,4],A[1,6],A[1,8],A[1,10],A[1,12],A[1,14],A[1,16]
		mat list weights_$ph
		ds hunger* 
		matrix colnames weights_$ph = `r(varlist)'

		tempfile this_phase // keep this phase aside while computing weights
		save 	`this_phase'

		** step 2: prepare severity weights
			matrix everything = weights_$ph'
			matrix colnames everything = weights_$ph
			mat list everything

			preserve
				clear
				svmat everything, names(col) 	

				local w_tot_${ph} = 0
				forval i = 1/`=_N' {
					local w`i'_${ph} `"`=weights_${ph}[`i']'"' // NOT new
					dis "w`i': `w`i'_${ph}'"
					local w_tot_${ph} = `w_tot_${ph}' + `w`i'_${ph}'
				}
				dis "`w_tot'"
				forval i = 1/`=_N' {
					local w_rel_`i'_${ph} = `w`i'_${ph}' / `w_tot_${ph}'
					dis "w`i': `w_rel_`i'_${ph}'"
				}
			restore


		use `this_phase', clear // call back data for this phase and use weights on it



		** step 3: compute household security
		// use baseline parameters to compute security (latent variable)
		// fix notes here

		// bring in treatment status to condition indexes on control group stats
		merge 1:1 hhid using "${constructed_${phase}}/identification.dta", ///
				gen(_mtreat) keepusing(pm_treatment)
		keep if _mtreat == 3
		drop _mtreat

		** ---- | Approach 1: Rasch Model 
		// compute weighted z-index
		// 1) standardize each component
		forval i = 1/8 {
			quietly sum hunger_rvrs`i' if pm_treatment == 0 // condition against control group
			local `i'_mean `r(mean)'
			local `i'_sd   `r(sd)'

			gen hz_`i' = (hunger_rvrs`i' - ``i'_mean') / ``i'_sd'
		}
		// 2) compute weighted average of standardized components
		gen FIES_rvrs_almost = 0
		forval i = 1/8 {
			// take average of rasch-weight-standardized hunger vars
			replace FIES_rvrs_almost = FIES_rvrs_almost + hz_`i' * `w_rel_`i'_${ph}' 
		}
		drop hz_*
		// 3) standardize weighted average of standardized components
		quietly sum FIES_rvrs_almost if pm_treatment == 0 // condition against control group
		local almost_mean = `r(mean)'
		local almost_sd = `r(sd)'
		gen FIES_rvrs_gsem = (FIES_rvrs_almost - `almost_mean') / `almost_sd'
		label var FIES_rvrs_gsem "Food sec. score using GSEM"
		drop FIES_rvrs_almost


		/*
		** ---- | Approach 2: Rasch Model (predicting latent variable)
		// Obtain the predicted value of the latent variable (security) by typing
		predict FIES_rvrs_latent, latent(Food_insec)

		// compare approaches. 89% correlation
		pwcorr FIES_rvrs_gsem FIES_rvrs_latent, sig 
		*/


		keep hhid hunger_rvrs* FIES_rvrs_raw FIES_rvrs_gsem 
		order hhid hunger_rvrs* FIES_rvrs_raw FIES_rvrs_gsem 

		tempfile fies_results
		save 	`fies_results'






	********************************************************************************
	* 					FOOD CONSUMPTION SCORE (FCS)							   *
	********************************************************************************

		


		********************************************************************************
		**** Secondary B.1.2 FCS		(for Secondary B.1.2, see Primary A.1.2)
		
		
		if "$ph" == "bl" {
			** FCS not collected at baseline survey (2018)	
			* but was collected in pre-study PMT survey dating 2017	
			use "${pmt}/PMT_DATA_HH_FINAL_revisedv2.dta", clear 	
			
			* FCS	
			gen  div_certub = cereales + racine 	
			replace div_certub = 7 if !missing(div_certub) & div_certub > 7 // top code if greater than 7	
					
			rename legumineuse 	div_pulse 	
			rename legumes 		div_veg	
			rename fruits 		div_fruit	
			rename viande  		div_meat	
			rename lait    		div_milk	
			rename huiles 		div_oil	
			rename sucre 		div_sugar			
		}
		else if "$ph" == "fu" {
			use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear 
			keep if consent == 1
			drop consent

			drop if div_cereal == .

			gen  div_certub = div_cereal + div_tuber 
			replace div_certub = 7 if !missing(div_certub) & div_certub > 7 // top code if greater than 7
		}
				
		gen FCS = div_certub*2 + div_pulse*3 + div_veg + div_fruit + div_meat*4 + div_milk*4 + div_oil * 0.5 + div_sugar *0.5 	
		label var FCS "B.1.2 Beneficiary Food Consumption Score $ph only"		
	
		* keeping only hhid at baseline 	
		if "$ph" == "bl" {
			keep hhid FCS	
					
			merge 1:1 hhid using "${intermediate_${phase}}/chad_main_${phase_yr}.dta", keepusing(consent)	
			keep if consent == 1 & _merge == 3			
			drop consent 	
			drop _merge				
		}				

		tempfile fcs_results
		save `fcs_results'
			
	********************************************************************************
	* 							FOOD DIVERSITY SCORE 							   *
	********************************************************************************

	
		use "${intermediate_${phase}}/foodconsumption_long", replace

/* Note:
Group food items using:				   http://documents.wfp.org/stellent/groups/public/documents/manual_guide_proced/wfp197216.pdf

We cannot calculate FCS score as recommended above (since we do not ask number of days item was consumed by a household.

We will, instead, generate an indicator y/n indicator of whether food was consumed within the household  
*/


	// label variables
	label 		define yn 0 "NO" 1 "Yes"
	label 		values consum_ate yn

	// checks
	*assert consum_qty >= consum_prod + consum_gift, rc0
	// 1 false assertion

	// Classify food items into 9 food groups
	gen 		foodgroup = .
	replace 	foodgroup = 1 if consum_name == "Riz"
	replace 	foodgroup = 1 if consum_name == "Mais"
	replace 	foodgroup = 1 if consum_name == "Sorgho"
	replace 	foodgroup = 1 if consum_name == "Beignets/Pain"
	replace 	foodgroup = 1 if consum_name == "Farine de ble"
	replace 	foodgroup = 1 if consum_name == "Patate douce"
	replace 	foodgroup = 1 if consum_name == "Mil"
	replace 	foodgroup = 1 if consum_name == "Tubercule de manioc"
	replace 	foodgroup = 1 if consum_name == "Pates alimentaires"
	replace 	foodgroup = 1 if consum_name == "Haricots secs"

	replace 	foodgroup = 2 if consum_name == "Haricot vert"
	replace 	foodgroup = 2 if consum_name == "Noix de cola"


	replace 	foodgroup = 3 if consum_name == "Gombo sec"
	replace 	foodgroup = 3 if consum_name == "Soumbala (base de nere [GAMBAYE=Ndji])"
	replace 	foodgroup = 3 if consum_name == "Soumbala (base de nere [GAMBAYE:Ndji])"
	replace 	foodgroup = 3 if consum_name == "Feuilles de (baobab, haricot, manioc, oseille, gombo, etc.)"

	replace 	foodgroup = 4 if consum_name == "Citron"
	replace 	foodgroup = 4 if consum_name == "Orange/Pamplemousse"
	
	replace 	foodgroup = 5 if consum_name == "Viande de boeuf"
	replace 	foodgroup = 5 if consum_name == "Viande de b�uf"
	replace 	foodgroup = 5 if consum_name == "Viande de mouton/chevre"
	replace 	foodgroup = 5 if consum_name == "Viande de chameau"
	replace 	foodgroup = 5 if consum_name == "Poisson frais"  
	replace 	foodgroup = 5 if  consum_name =="Poisson fume"
	replace 	foodgroup = 5 if consum_name == "Volailles"


	replace 	foodgroup = 6 if consum_name == "Lait caille"
	replace 	foodgroup = 6 if consum_name == "Oeufs"


	replace 	foodgroup = 7 if consum_name == "Sucre"

	replace 	foodgroup = 8 if consum_name == "Huile d'arachide"
	replace 	foodgroup = 8 if consum_name == "Huile de palme"
	replace 	foodgroup = 8 if consum_name == "Autres huiles (soja, karite, etc.)"
	 
	replace 	foodgroup = 9 if consum_name == "Oignon frais"
	replace 	foodgroup = 9 if consum_name == "Tomate sechee"
	replace 	foodgroup = 9 if consum_name == "Piment"
	replace 	foodgroup = 9 if consum_name == "Sel"
	replace 	foodgroup = 9 if consum_name == "Cube (maggi, jumbo, etc.)"

	replace 	foodgroup = 10 if consum_name == "The en paquet ou en sachet"


	#delimit ;
	label 		define foodgroup
	1 "main staples"
	2 "pulses"
	3 "vegetables and leaves"
	4 "fruits"
	5 "meat and fish"
	6 "milk and other dairy"
	7 "sugar and honey"
	8 "oil and butter"
	9 "condiments"
	10 "other";
	#delimit cr

	label 		val foodgroup foodgroup

	byso 		hhid foodgroup : egen diversity_ = max(consum_ate)
	keep 		hhid foodgroup diversity_
	duplicates  drop
	drop if 	foodgroup==.  //consum_name was "." for those hhds
	reshape 	wide diversity_, i(hhid) j(foodgroup)

	egen 		diversity_score = rowtotal(diversity_*)
	
	label var 	diversity_score 	"Household food diversity score"

	label var 	diversity_1 		"Household consumption in the last 7 days, staple foods (indicator)"
	label var 	diversity_2 		"Household consumption in the last 7 days, pulses/beans (indicator)"
	label var 	diversity_3 		"Household consumption in the last 7 days, vegetables/leaves (indicator)"
	label var 	diversity_4 		"Household consumption in the last 7 days, fruits (indicator)"
	label var 	diversity_5 		"Household consumption in the last 7 days, meat/fish (indicator)"
	label var 	diversity_6 		"Household consumption in the last 7 days, milk/other dairy products (indicator)"
	label var 	diversity_7 		"Household consumption in the last 7 days, sugar/honey products (indicator)"
	label var 	diversity_8 		"Household consumption in the last 7 days, oil/butter products (indicator)"
	label var 	diversity_9 		"Household consumption in the last 7 days, condiments/beverages (indicator)"
	label var 	diversity_10 		"Household consumption in the last 7 days, other (indicator)"

	ren 		diversity_1 diversity_staples_d
	ren 		diversity_2 diversity_beans_d
	ren 		diversity_3 diversity_vegetables_d
	ren 		diversity_4 diversity_fruit_d
	ren 		diversity_5 diversity_meats_d
	ren 		diversity_6 diversity_dairy_d
	ren 		diversity_7 diversity_sugar_d
	ren 		diversity_8 diversity_oil_d
	ren 		diversity_9 diversity_condiments_d
	ren 		diversity_10 diversity_other_d

	// ate_meat
	gen 		ate_meat = (diversity_meats_d)
	label var 	ate_meat 			"Household ate meat in last 7 days"


	// SAVE
	
	keep hhid diversity_*
	

		********************************************************************************
		**** merge results


		merge 1:1 hhid using `fies_results'
		if "$ph" == "fu" assert _merge == 3
		drop _merge 
		
		merge 1:1 hhid using `fcs_results'
		assert _merge == 3 
		drop _merge
		
		// FIES only defined where treatment is defined
		
		capture confirm variable FCS
		if _rc == 0 { 
			keep hhid FIES_* FCS* hunger_rvrs* diversity_*
		}
		
		
		********************************************************************************
		**** extra indices: food security scores

		preserve  
		
			* winsorizing FCS: 
			gen FCS_W = FCS
			winsor2 	FCS_W, replace c(1 98)
			 
			keep hhid FCS_W FIES_rvrs_raw diversity_score
			
			* merging consumption data 
			merge 1:1 hhid using "${constructed_${phase}}/consumption.dta", 	///
			keepusing(food_day_pc_xof nonfood_day_pc_xof consum_day_pc_xof		///
					  food_day_eq_xof nonfood_day_eq_xof consum_day_eq_xof		///
					  food_day_xof 	  nonfood_day_xof    consum_day_xof) gen(_m1)
			
			assert _m1 == 3
			drop _m1
			
			* treatment status 
			merge 1:1 hhid using "${constructed_${phase}}/identification.dta", gen(_m2) keepusing(pm_treatment)
			assert _m2 == 3
			drop _m2

			*** creating indices: 
					
			* FCS
			zindex FCS_W, gen(z_FCS_W) condition(pm_treatment == 0)
			
			* FIES
			zindex FIES_rvrs_raw, gen(z_FIES_rvrs_raw) condition(pm_treatment == 0)
			
			* Food Diversity
			zindex diversity_score, gen(z_diversity_score) condition(pm_treatment == 0)
			
			* nonfood
			zindex nonfood_day_eq_xof, gen(z_nonfood_day_eq_xof) condition(pm_treatment == 0)
			
			* food
			zindex food_day_eq_xof, gen(z_food_day_eq_xof) condition(pm_treatment == 0)
			
			* food + nonfood 
			gen foodnonfood = food_day_eq_xof + nonfood_day_eq_xof
			zindex foodnonfood, gen(z_foodnonfood) condition(pm_treatment == 0)

		   * Index with sum of food and non-food
			local zindex_vars foodnonfood  FCS_W FIES_rvrs_raw diversity_score
			zindex `zindex_vars', gen(food_index3) condition(pm_treatment == 0)
			
			* Index with food and non-food as separate components
			local zindex_vars food_day_eq_xof nonfood_day_eq_xof FCS_W FIES_rvrs_raw diversity_score
			zindex `zindex_vars', gen(food_index4) condition(pm_treatment == 0)

			* Index with food and non-food as separate components
			local zindex_vars food_day_xof nonfood_day_xof FCS_W FIES_rvrs_raw diversity_score
			zindex `zindex_vars', gen(food_index5) condition(pm_treatment == 0)
			
			* Index with food and non-food as separate components
			local zindex_vars food_day_pc_xof nonfood_day_pc_xof FCS_W FIES_rvrs_raw diversity_score
			zindex `zindex_vars', gen(food_index6) condition(pm_treatment == 0)
			
			keep hhid z_FCS_W FCS_W z_FIES_rvrs_raw z_diversity_score z_food_day_eq_xof z_nonfood_day_eq_xof ///
			z_foodnonfood food_index3 food_index4 food_index5 food_index6
			
			tempfile food_index
			save    `food_index'
		restore 
			
		merge 1:1 hhid using `food_index'
		assert _merge == 3 
		
		
		********************************************************************************
		**** save datasets 
		
		sort hhid

		compress
		save "${constructed_${phase}}/foodsecurity.dta", replace


 
