	***************************************************************************
	*																		  *
	*		    			LIVESTOCK CLEANING CHAD ASP IE 				 	  *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning livestock data
			 
	** OUTLINE: 	 
				- B.2.4 Livestock sale revenue, beneficiary, (last 12 months) 
				- B.3.4 Livestock Type Count (owned in last 12 months: ani_* not ani_live_*)
				- D.5.0 Livestock Ownership descriptive tables
				- D.5.1 Increase/decrease in animal (by type) in the last 12 months 
				- D.5.2 Value of animal purchases over last 12 months
      */

	****************************************************************************

********************************************************************************
* LIVESTOCK																 	   *
********************************************************************************
use "${intermediate_${phase}}/livestock_wide", clear

********************************************************************************
*** B.3.4 Livestock Type Count (owned in last 12 months: ani_* not ani_live_*)

if "$ph" == "fu" drop *who*
rename ani1_name_* ani_name_*

if "$ph" == "bl" {
	label var 	ani_name_1	"Bovins (Boeuf / Vaches)"	
	label var 	ani_name_2	"Caprins (Chevres)"	
	label var 	ani_name_3	"Ovins (moutons / brebins, etc.)"	
	label var 	ani_name_4	"Volailles (poulet / pintade / canard / etc.)"	
	label var 	ani_name_5	"Chevaux / juments"	
	label var 	ani_name_6	"Chameau / Chamelle"	
	label var 	ani_name_7	"Anes / Anesses"	
	label var 	ani_name_8	"Autre (precisez)"	
	
	*** We don't know what the specified other is in Chad, so drop it from the index	
	drop  		*_8		
}
else if "$ph" == "fu" {
	label variable ani_name_1	"Bovins (Boeuf / Vaches)"
	label variable ani_name_2	"Caprins (Chevres)"
	label variable ani_name_3	"Ovins (moutons / brebins, etc.)"
	label variable ani_name_4	"Volailles (poulet / pintade / canard / etc.)"
	label variable ani_name_5	"Chevaux / juments"
	label variable ani_name_6	"Chameau / Chamelle"
	label variable ani_name_7	"Anes / Anesses"	
}

ds ani_name_* 
local ani_count : word count `r(varlist)' 
nois dis "$ph"
label define yn 0 "non" 1 "oui", replace
forvalues i = 1/`ani_count' {
	if "$ph" == "bl" gen ani_yn_`i' = (ani_`i' == 1 | ani_`i' == 2 )	
    if "$ph" == "fu" gen ani_yn_`i' = (has_livestock_`i' == 1) 

	 // since that referes to ani_live_* not ani_* and label below is for ani_* not ani_live_*
	 label variable ani_yn_`i' "Owned in last 12 months"
	 if "$ph" == "bl" order ani_yn_`i', after(ani_`i')
	 if "$ph" == "fu" order ani_yn_`i', after(has_livestock_`i')
	 label val ani_yn_`i' yn
}

* drop ani_? ani_??

** div_ani_*
gen div_ani_bov = 0
gen div_ani_equi = 0
gen div_ani_ovi = 0
gen div_ani_avi = 0
gen div_ani_o = 0

label var div_ani_bov "Household works with cows/bulls, 12 months "
label var div_ani_equi "Household works with horses/donkeys/camels, 12 months"
label var div_ani_ovi "Household works with sheep/goats,  12 months"
label var div_ani_avi "Household works with poultry,  12 months"
label var div_ani_o "Household works with other animals,  12 months"

	replace div_ani_bov = 1 if (ani_yn_1 == 1)
	replace div_ani_ovi =  1 if (ani_yn_2 == 1)
	replace div_ani_ovi =  1 if (ani_yn_3 == 1)
	replace div_ani_avi = 1 if  (ani_yn_4 == 1)
	replace div_ani_equi = 1 if  (ani_yn_5 == 1)
	replace div_ani_equi = 1 if  (ani_yn_6 == 1)
	replace div_ani_equi = 1 if  (ani_yn_7 == 1)
	
egen div_ani  = rowtotal(div_ani_*) 
label variable div_ani "B.3.4 Count of livestock types"

if "$ph" == "bl" {
		// indicator
	pca 		ani_yn_*
	predict 	livestock_index
	codebook 	livestock_index
	label var 	livestock_index "PCA index of livestock ownership dummies - last 12 months"

	// quantity
	forvalues i = 1/7 {
	  recode 	ani_count_`i' (missing = 0)
	  recode 	ani_count_`i' (888 = .d)
	  recode 	ani_count_`i' (999 = .r)
	  
	  label var ani_count_`i' "Quantity currently owned"
	}

	forvalues i = 1/7 {
		quietly: egen ani_count_`i'_high = pctile(ani_count_`i') if ani_count_`i' > 0, p(99)
		quietly: egen ani_count_`i'_low = pctile(ani_count_`i') if ani_count_`i' > 0, p(1)
		quietly: gen outlier_`i' = ((ani_count_`i' > ani_count_`i'_high & !missing(ani_count_`i')) | ((ani_count_`i' < ani_count_`i'_low) & ani_count_`i' != 0))
		di as error "ani_count_`i'"
		count if outlier_`i' == 1
	}
	drop 		ani_count_*_* 

	pca 		ani_count_*
	predict 	livestock_index_q
	codebook 	livestock_index_q
	label var 	livestock_index_q "PCA index of livestock current ownership quantities"

	recode 		livestock_index_q (. = .d) 
	keep 		hhid *index* div*
	order	 	hhid div* livestock_index*
} 
else if "$ph" == "fu" {
	// list ani_? ani_?? vars. 
	local ani_list
	forvalues i = 1/`ani_count' {
		rename has_livestock_`i' ani12_`i' // ownership in last 12 months
		local addvar ani12_`i'
		local ani_list : list ani_list | addvar
	}	
	
	gen PAP_b3 = "PAP B3"
	keep hhid PAP_b3 div* `ani_list'
	order hhid PAP_b3 div* `ani_list'
	isid hhid 
	tempfile b3_4_ben_liv_count
	save 	`b3_4_ben_liv_count'	
}


********************************************************************************
**** Livestock ownership
**** B.10.3.4 Beneficiary owns livestock (ani_count)
if "$ph" == "fu" {
	use "${intermediate_${phase}}/livestock_long", clear
	merge m:1 hhid using "${constructed_${phase}}/demographics.dta", ///
				keepusing(benef_pos chef_pos) gen(_mergBEN)
	drop if _mergBEN == 2
	drop _mergBEN 

	// temporary measure
	drop if benef_pos == . // removing absent beneficiaries for now although responses exist for someone else in the HH
	qui count if benef_pos != .
	assert `r(N)' == _N // assert all HHs have benefs

	// generate one ani_who var for FU1 and FU2
	label drop ani_who1 ani_who2 ani_who3
	desc ani_who*
	format ani_who* %4.0f

	//confirm that hh members who own livestock only own when animal is alive
	assert (ani_who1 >0 | ani_who2 >0 | ani_who3 > 0) & ///
		(!missing(ani_who1) | !missing(ani_who2) | !missing(ani_who3)) if ///
		ani_live ==1 | ani_live == 2
				
	sort hhid livestock_pos
		
	// count beneficiaries who own livestock
	foreach var in ani_who1 ani_who2 ani_who3 {
		gen `var'_txt = string(`var')
		replace `var'_txt = "" if `var'_txt == "."
	}
	gen ani_who = ani_who1_txt + " " + ani_who2_txt + " " + ani_who3_txt

	// all ctys: count number of owners per animal
	gen own_n = .
	forval i = 1/`=_N' {
		local ani_who_i
		local ani_who_i `"`=ani_who[`i']'"' 
		local uniq_who : list uniq ani_who_i     // collect unique owners only
		local who_num : list sizeof uniq_who	 // count how many
		qui replace own_n = `who_num' in `i'
	}
	replace own_n = 99 if strpos(ani_who, "-1") > 0 // to construct who_is_benef_sole

	// space out position lists for strpos below
	tostring chef_pos, replace
	replace chef_pos = " " + chef_pos + " "
	replace ani_who = " " + ani_who + " "

	** prepare who_is_benef variable
	tostring benef_pos, replace
	gen who_is_benef = strpos(ani_who, benef_pos) > 0
	// some special entries
	replace who_is_benef = 1 if strpos(ani_who, " -1 ") > 0  // -1 = everyone in the HH
	replace who_is_benef = 0 if ani_who == " 0 " // 0 = people outside HH (no changes made)

	**---| 1 household level
	// BENEF DUMMY create dummy variable for each animal if beneficiary is among owners
	byso hhid : egen ani_ben_dum = max(who_is_benef)
	label var ani_ben_dum "B.10.3 (4) Benef owns livestock at $phase"

	// BENEF SOLE DUMMY
	gen who_is_benef_sole = who_is_benef
	replace who_is_benef_sole = 0 if own_n > 1 // more than one owner
	byso hhid : egen ani_sole_dum = max(who_is_benef_sole)
	label var ani_sole_dum "Benef is sole owner of livestock at $phase"

	// CHEF DUMMY
	gen who_is_chef = strpos(ani_who, chef_pos) > 0
	bysort hhid : egen ani_chef_dum = max(who_is_chef)
	label var ani_chef_dum "Chef owns livestock at $phase"

	// CHEF SOLE DUMMY
	gen who_is_chef_sole = who_is_chef
	replace who_is_chef_sole = 0 if own_n > 1 // more than one owner
	byso hhid : egen ani_sole_dum_chef = max(who_is_chef_sole)
	label var ani_sole_dum_chef "Chef is sole owner of livestock at $phase"

	// HH ownership
	gen hh_owns = 1 if ani_live == 1 | ani_live == 2
	replace hh_owns = 0 if ani_who == " 0 " // 0 = people outside HH (no changes made)
	replace hh_owns = 0 if hh_owns == .
	byso hhid : egen ani_hh_dum = max(hh_owns)
	label var ani_hh_dum "HH owns livestock at $phase"

	// count of livestock types for beneficiary only
	preserve
		* keeping livestock owned only by beneficiaries: 
		 keep if ani_ben_dum == 1
		 
		** div_ani_*
		gen div_ani_bov = 0
		gen div_ani_equi = 0
		gen div_ani_ovi = 0
		gen div_ani_avi = 0
		gen div_ani_o = 0

		label var div_ani_bov "Benef works with cows/bulls, 12 months "
		label var div_ani_equi "Benef works with horses/donkeys/camels, 12 months"
		label var div_ani_ovi "Benef works with sheep/goats,  12 months"
		label var div_ani_avi "Benef works with poultry,  12 months"
		label var div_ani_o "Benef works with other animals,  12 months"

		replace div_ani_bov = 1 if (livestock_pos == 1)
		replace div_ani_ovi =  1 if (livestock_pos == 2)
		replace div_ani_ovi =  1 if (livestock_pos == 3)
		replace div_ani_avi = 1 if  (livestock_pos == 4)
		replace div_ani_equi = 1 if  (livestock_pos == 5)
		replace div_ani_equi = 1 if  (livestock_pos == 6)
		replace div_ani_equi = 1 if  (livestock_pos == 7)

		egen div_ani_ben_temp  = rowtotal(div_ani_*) 
		bysort hhid: egen div_ani_ben  = total(div_ani_ben_temp) 
		label variable div_ani_ben "B.3.4 Count of beneficiary livestock types"

		keep hhid div_ani_ben
		duplicates drop 
		isid hhid 
		tempfile ben_div_livestock
		save `ben_div_livestock'
	restore

	gen PAP_b10_3_4 = "PAP B10.3.4"
	keep  hhid PAP_b10_3_4 ani_ben_dum ani_sole_dum ani_chef_dum ani_sole_dum_chef ani_hh_dum // keep livestock ownership dummy
	order hhid PAP_b10_3_4 ani_ben_dum ani_sole_dum ani_chef_dum ani_sole_dum_chef ani_hh_dum // keep livestock ownership dummy
	duplicates drop
	isid hhid 

	// capture all HHs, not just ones in repeat group (demographics includes all consenting HHs) not needed at BL
	merge 1:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos) 
	foreach var in ani_ben_dum ani_sole_dum ani_chef_dum ani_hh_dum {
		replace `var' = 0 if `var' == .
	}
	tempfile 10_3_4
	save    `10_3_4', replace	
}


********************************************************************************
**** B.10.3.5 Beneficiary controls revenues from sale of livestock (ani_count)
**** B.2.4    Livestock sale revenue, beneficiary, (last 12 months) 

// ani_control DNE at BL
if "$ph" == "fu" {	
	use "${intermediate_${phase}}/livestock_long", clear

	merge m:1 hhid using "${constructed_${phase}}/demographics.dta", ///
				keepusing(benef_pos chef_pos) gen(_mergBEN) 
				// will include HHs not in livestock long and HHs without benefs
	tostring benef_pos, replace
	replace benef_pos = " " + benef_pos + " "
	tostring chef_pos, replace
	replace chef_pos = " " + chef_pos + " "
	 
	drop _mergBEN 

	**** B.10.3.5 Beneficiary controls revenues from sale of livestock (ani_count)
	label drop ani_control1 ani_control2
	desc ani_control*
	format ani_control1 ani_control2 %4.0f
	order hhid benef_pos ani_control1 ani_control2
	
	* Generate beneficiary control dummy
	foreach var in ani_control1 ani_control2 {
		gen `var'_txt = string(`var')
		replace `var'_txt = "" if `var'_txt == "."
	}
	gen ani_control = " " + ani_control1_txt + " " + ani_control2_txt + " "
	
	gen ben_control = strpos(ani_control, benef_pos) > 0
	sort hhid livestock_pos 
	
	// count number of livestock-controlling bens per household
	// need not be beneficiary-owned or -managed
	bysort hhid : egen ani_contr_ben_dum = max(ben_control)
	order ani_contr_ben_dum, after (hhid)
	label var ani_contr_ben_dum "B.10.3 (5) Benef controls revenue from the sale of livestock at $phase"

	gen chef_control = strpos(ani_control, chef_pos) > 0
	bysort hhid : egen ani_contr_chef_dum = max(chef_control)
	order ani_contr_chef_dum, after (ani_contr_ben_dum)
	label var ani_contr_chef_dum "Chef controls revenue from the sale of livestock at $phase"
	
	**** OWNERSHIP CHEF AGAIN 

	label drop ani_who1 ani_who2 ani_who3
	desc ani_who*
	format ani_who* %4.0f

	//confirm that hh members who own livestock only own when animal is alive
	assert (ani_who1 >0 | ani_who2 >0 | ani_who3 > 0) & ///
		(!missing(ani_who1) | !missing(ani_who2) | !missing(ani_who3)) if ///
		ani_live ==1 | ani_live == 2
			
	sort hhid livestock_pos
	
	// count beneficiaries who own livestock
	foreach var in ani_who1 ani_who2 ani_who3 {
		gen `var'_txt = string(`var')
		replace `var'_txt = "" if `var'_txt == "."
	}
	gen ani_who = ani_who1_txt + " " + ani_who2_txt + " " + ani_who3_txt

	// all ctys: count number of owners per animal
	gen own_n = .
	forval i = 1/`=_N' {
		local ani_who_i
		local ani_who_i `"`=ani_who[`i']'"' 
		local uniq_who : list uniq ani_who_i     // collect unique owners only
		local who_num : list sizeof uniq_who	 // count how many
		qui replace own_n = `who_num' in `i'
	}
	replace own_n = 99 if strpos(ani_who, "-1") > 0 // to construct who_is_benef_sole

	tostring chef_pos, replace
	replace chef_pos = " " + chef_pos + " "
	replace ani_who = " " + ani_who + " "

	// CHEF DUMMY
	gen who_is_chef = strpos(ani_who, chef_pos) > 0
	bysort hhid : egen ani_chef_dum = max(who_is_chef)
	label var ani_chef_dum "Chef owns livestock at $phase"

	**** B.2.4    Livestock sale revenue, beneficiary, (last 12 months) 

	gen ani_soldval_xof = ani_soldval 
	** value of livestock owned by chef 
	gen ani_value_xof = ani_value 

	gen count_control = 0 
	replace count_control = 1 if ani_control_ano == 0 
	replace count_control = 2 if ani_control_ano == 1 
	
	// winsorize livestock values at livestock type-level
	foreach pp in 95 98 99 {
		
		gen ani_soldval_w`pp' = ani_soldval_xof
		gen ani_value_w`pp' = ani_value_xof
		
		foreach pos in `animal_pos' { 
			_pctile ani_soldval_xof if livestock_pos == `pos' & !missing(ani_soldval_xof) , p(`pp')
			replace ani_soldval_w`pp' = `r(r1)' if livestock_pos == `pos' & ///
											   ani_soldval_xof > `r(r1)' & ///
											   !missing(ani_soldval_xof) 
											   
			_pctile ani_value_xof if livestock_pos == `pos' & !missing(ani_value_xof) , p(`pp')
			replace ani_value_w`pp' = `r(r1)' if livestock_pos == `pos' & ///
											   ani_value_xof > `r(r1)' & ///
											   !missing(ani_value_xof) 
		}
	   
		// beneficiary revenues  
		gen ani_ben_contr_win`pp' = ani_soldval_w`pp' / count_control if ben_control == 1  
		bysort hhid : egen tot_ani_ben_contr_`pp' = total(ani_ben_contr_win`pp')
		replace tot_ani_ben_contr_`pp' = tot_ani_ben_contr_`pp' / 1000
		
		// chef revenues  
		gen ani_chef_contr_win`pp' = ani_soldval_w`pp' / count_control if chef_control == 1  
		bysort hhid : egen tot_ani_chef_contr_`pp' = total(ani_chef_contr_win`pp')
		replace tot_ani_chef_contr_`pp' = tot_ani_chef_contr_`pp' / 1000

		// HH revenues
		bysort hhid : egen tot_ani_hh_contr_`pp' = total(ani_soldval_w`pp')
		replace tot_ani_hh_contr_`pp' = tot_ani_hh_contr_`pp' / 1000
		
		// chef livestock value 
		gen ani_chef_value_win`pp' = ani_value_w`pp' / own_n if who_is_chef == 1  
		bysort hhid : egen tot_ani_chef_value_`pp' = total(ani_chef_value_win`pp')
		replace tot_ani_chef_value_`pp' = tot_ani_chef_value_`pp' / 1000

		label var tot_ani_ben_contr_`pp' "B.2.4 Ben Livestock Sale value (_`pp' wins. 1000 FCFA last 12 months)"
		label var tot_ani_chef_contr_`pp' "B.2.4 Chef Livestock Sale value (_`pp' wins. 1000 FCFA last 12 months)"
		label var tot_ani_hh_contr_`pp'  "B.2.4 HH Livestock Sale value (_`pp' wins. 1000 FCFA last 12 months)"
		label var tot_ani_chef_value_`pp'  "B.2.4 Chef Livestock value (_`pp' wins. 1000 FCFA last 12 months)"
		 
		// hh less benef
		gen tot_ani_hhlb_contr_`pp' = tot_ani_hh_contr_`pp' - tot_ani_ben_contr_`pp'
		label var tot_ani_hhlb_contr_`pp'  "B.2.4 HH less benef livestock Sale value (_`pp' wins. 1000 FCFA last 12 months)"

		// benef/hh
		gen tot_ani_bohh_contr_`pp' = tot_ani_ben_contr_`pp' / tot_ani_hh_contr_`pp' 
		label var tot_ani_bohh_contr_`pp'  "B.2.4 benef/HH fraction livestock sale value (_`pp' win.)"
	} 
	 
	gen PAP_b2 = "PAP B2 B10.3.5"
	keep hhid PAP_b2 	tot_ani_ben_contr* tot_ani_hh_contr* tot_ani_hhlb_contr* ///
						tot_ani_bohh_contr* ani_contr_ben_dum ani_contr_chef_dum ///
						tot_ani_chef_contr* tot_ani_chef_value*
	order hhid PAP_b2 	tot_ani_ben_contr* tot_ani_hh_contr* tot_ani_hhlb_contr* ///
						tot_ani_bohh_contr* ani_contr_ben_dum ani_contr_chef_dum ///
						tot_ani_chef_contr* tot_ani_chef_value*
	duplicates drop
	isid hhid 
	tempfile b2_4_ben_liv_rev12
	save 	`b2_4_ben_liv_rev12'	 
}


********************************************************************************
*** D.5 Livestock
// Value of animal purchases
// HH animal count (scaled by TLU)
// Increase/decrease in animal (TLU) in the last 12 months 

if "$ph" == "fu" {
	use "${intermediate_${phase}}/livestock_long", clear
		
	// only at BL 
	// 	recode ani_count (missing = 0)
	recode ani_count (888 = .d)
	recode ani_count (999 = .r)
	label variable ani_count "Quantity currently owned"

	byso livestock_pos : egen ani_count_high = pctile(ani_count) if ani_count > 0, p(99)
	byso livestock_pos : egen ani_count_low  = pctile(ani_count) if ani_count > 0, p(1)
	byso livestock_pos : gen outlier = ((ani_count > ani_count_high & !missing(ani_count)) | ///
									   ((ani_count < ani_count_low) & ani_count != 0))
	count if outlier == 1
	keep if ani_live == 1 // removes missings turned into zeros that we used in outlier calc

	// purchase values
	sort ani_bot ani_botval
	replace ani_botval = ani_bot if ani_botval == 0 & ani_bot > 100 // 3 cases at FU1 where responses likely reversed
			
			
	// 2 at FU2
	foreach pp in 95 98 99 {
		foreach var in ani_botval { 	
			// winsorize bot values within each animal type
			gen `var'_w`pp' = `var'
			levelsof livestock_pos, local(animal_pos) 
			foreach pos in `animal_pos' {
				_pctile `var' if livestock_pos == `pos' & !missing(`var') , p(98)
				replace `var'_w`pp' = `r(r1)' if livestock_pos == `pos' & ///
												  `var' > `r(r1)' & !missing(`var') 
			}
			byso hhid : egen tot_`var'_`pp' = total(`var'_w`pp') // 1,000 FCFA
			replace tot_`var'_`pp' = tot_`var'_`pp' / 1000
		}
		label variable tot_ani_botval_`pp'  "D.5.2 Value of animal purchases (`pp' wins. 1000 FCFA last 12 months)"
	}
			
	//	manual corrections to livestock counts
	replace ani_count = 30 if ani_count == 30000 & outlier == 1 // assume sticky fingers
		
	/* 
	The TLU conversion factors used are as follows: cattle = 0.70, sheep and goats = 0.10, pigs = 0.20 and chicken = 0.01
	Source: Cattle and Small Ruminant Production Systems in sub-Saharan Africa
	Table 1. Tropical livestock units
	http://www.fao.org/3/Y4176E/y4176e04.htm
	*/ 	
	translate_livestock

	merge m:1 hhid using "${constructed_${phase}}/demographics.dta", ///
		keepusing(benef_pos chef_pos) gen(_mergBEN)
	assert _mergBEN != 1
	keep if _mergBEN == 3
	drop _mergBEN 


	local tlu_vars ani_count ani_ago
	foreach var in `tlu_vars' {
		gen `var'_tlu = `var'
		replace `var'_tlu = `var'_tlu * 0.5  if ani1_name == "Bulls" 
		replace `var'_tlu = `var'_tlu * 0.7  if ani1_name == "Cows or Heifers" 
		replace `var'_tlu = `var'_tlu * 0.7  if ani1_name == "Calves"
		replace `var'_tlu = `var'_tlu * 0.8  if ani1_name == "Donkeys"       // corrected 8/24/2020
		replace `var'_tlu = `var'_tlu * 1.1  if ani1_name == "Camels" 		 // corrected 8/24/2020
		replace `var'_tlu = `var'_tlu * 0.8  if ani1_name == "Horses or Mares" 
		replace `var'_tlu = `var'_tlu * 0.1  if ani1_name == "Goats" 
		replace `var'_tlu = `var'_tlu * 0.1  if ani1_name == "Sheep" 
		replace `var'_tlu = `var'_tlu * 0.1  if ani1_name == "Muttons" 
		replace `var'_tlu = `var'_tlu * 0.03 if ani1_name == "Guinea Fowls"  // corrected 8/24/2020
		replace `var'_tlu = `var'_tlu * 0.01 if ani1_name == "Hens or Chickens"
		replace `var'_tlu = `var'_tlu * 0.2  if ani1_name == "Pork"
			
		// compute HH totals
		byso hhid : egen tot_`var' = total(`var')
		label var tot_`var' "HH animal count (not scaled by TLU)"
			
		byso hhid : egen tot_`var'_tlu = total(`var'_tlu)
		label var tot_`var'_tlu "HH animal count (scaled by TLU)"
	}

	// generate dummy for benef ownership
	tostring benef_pos, replace
	replace benef_pos = " " + benef_pos + " "
		
	// generate dummy for chef ownership
	tostring chef_pos, replace
	replace chef_pos = " " + chef_pos + " "
		
	if "$ph" != "bl" {
		label values *who*
		foreach var in ani_who1 ani_who2 ani_who3 {
			tostring `var', replace
			replace `var' = " " + `var' + " "
			replace `var' = "" if `var' == " . "  
		}
		gen ani_who = ani_who1 + ani_who2 + ani_who3
	}
		
	replace ani_who = itrim(ani_who)
	gen ben_owns = strpos(ani_who, benef_pos) > 0
	gen chef_owns = strpos(ani_who, chef_pos) > 0
		
	// generate benef ownership. Assume beneficiary's animal if they're listed among the owners
	gen ani_count_tlu_ben = ani_count_tlu if ben_owns == 1
	byso hhid : egen tot_ani_count_tlu_ben = total(ani_count_tlu_ben)
	label var tot_ani_count_tlu_ben "Benef. animal count (scaled by TLU)"

	// generate chef ownership. Assume chef's animal if they're listed among the owners
	gen ani_count_tlu_chef = ani_count_tlu if chef_owns == 1
	byso hhid : egen tot_ani_count_tlu_chef = total(ani_count_tlu_chef)
	label var tot_ani_count_tlu_chef "Chef. animal count (scaled by TLU)"

	// generate hh-less-benef ownership
	gen ani_count_tlu_hhlb = ani_count_tlu if ben_owns != 1
	byso hhid : egen tot_ani_count_tlu_hhlb = total(ani_count_tlu_hhlb)
	label var tot_ani_count_tlu_hhlb "HH less Benef. animal count (scaled by TLU)"
	*assert tot_ani_count_tlu_hhlb + tot_ani_count_tlu_ben - tot_ani_count_tlu < 0.0001 // assert animals add up by owner
		
	// generate animal type dummy
	gen 	ani_type = 1 if ani1_name == "Bulls"  | ani1_name == "Cows or Heifers" | ///
							ani1_name == "Calves" | ani1_name == "Bovins (Boeufs- Vaches)" 
	replace ani_type = 2 if ani1_name == "Donkeys" 	
	replace ani_type = 3 if ani1_name == "Camels"
	replace ani_type = 4 if ani1_name == "Horses or Mares"
	replace ani_type = 5 if ani1_name == "Goats"
	replace ani_type = 6 if ani1_name == "Sheep" | ani1_name == "Muttons"
	replace ani_type = 7 if ani1_name == "Guinea Fowls" | ani1_name == "Hens or Chickens"
	replace ani_type = 8 if ani1_name == "Other"
		
	label define ani_types 1 "bov" 2 "ane" 3 "cham" 4 "chev" 5 "cap"  6 "ov"  7 "vol" 8 "other", replace
	label values ani_type ani_types 
		
	// calculate household totals by animal type
	byso hhid ani_type : egen liv_tot = total(ani_count)
	preserve
		keep hhid ani_type liv_tot
		duplicates drop
		isid hhid ani_type 
		reshape wide liv_tot, i(hhid) j(ani_type)

		rename liv_tot1 liv_bov
		rename liv_tot2 liv_ane
		rename liv_tot3 liv_cham
		rename liv_tot4 liv_chev
		rename liv_tot5 liv_cap
		rename liv_tot6 liv_ov
		rename liv_tot7 liv_vol
		capture confirm var liv_tot8
		if _rc == 0 rename liv_tot8 liv_other
			
		// fill in zeros
		ds hhid, not
		foreach var of varlist `r(varlist)' {
			replace `var' = 0 if `var' == .
		}
		tempfile ani_counts
		save 	`ani_counts'
	restore

	// calculate change in TLU over the year
	gen ani_n_diff_tlu = ani_count_tlu - ani_ago_tlu // examined extreme values. Seem to be justified by flows
	byso hhid : egen tot_ani_n_diff_tlu = total(ani_n_diff_tlu)
	label var tot_ani_n_diff_tlu "D.5.1 Increase/decrease in animal (TLU) in the last 12 months"

	** Wrap it up
	local keep_vars tot_ani_botval_98 tot_ani_n_diff_tlu tot_ani_count 			///
					tot_ani_count_tlu tot_ani_count_tlu_ben 					///
					tot_ani_count_tlu_chef tot_ani_count_tlu_hhlb
				
	gen PAP_d5 = "PAP D5"
	keep  hhid PAP_d5 `keep_vars'
	order hhid PAP_d5 `keep_vars'
	duplicates drop	
}
	
	
********************************************************************************
*** merge livestock outcomes
	
if "$ph" == "fu" {
	merge 1:1 hhid using `ani_counts', 		   gen(_mCounts)
	merge 1:1 hhid using `b3_4_ben_liv_count', gen(_mDiv) // all phases
	merge 1:1 hhid using `10_3_4'			 , gen(_m)	  // all phases
	merge 1:1 hhid using `ben_div_livestock',  gen(_mDivBen) 
	merge 1:1 hhid using `b2_4_ben_liv_rev12', gen(_mRev)

	// insert true zeros
	local zeros_vars tot_ani_botval_98 ///
					 tot_ani_count  tot_ani_count_tlu tot_ani_count_tlu_ben tot_ani_count_tlu_chef ///
					 tot_ani_ben_contr_98 tot_ani_chef_contr_98 ///
					 tot_ani_count_tlu_hhlb ///
					 tot_ani_n_diff_tlu    ///
					 div_ani_bov div_ani_equi div_ani_ovi div_ani_ben ///
					 div_ani_avi div_ani_o    div_ani 
	ds				 liv_*
	local zeros_vars `zeros_vars' `r(varlist)'

	foreach var in `zeros_vars' {
		replace `var' = 0 if `var' == .
	}  
}

sort hhid
compress 
save "${constructed_${phase}}/livestock.dta", replace
