

	***************************************************************************
	*																		  *
	*		  			 AGRICULTURE CLEANING CHAD ASP IE 			  		  *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning agriculture data
	
	** OUTLINE:     1. Prep member data : "16b_clean_ag_mem_prep.do" 
						Uses: 
							"${constructed_${phase}}/demographics"
							"${intermediate_${phase}}/members_long"
							"${intermediate_${phase}}/chad_main_2021"
							  
						Creates:
							"${intermediate_${phase}}/member_data_ag"
						
					2. Add household member and community-level data to "main_plotlist_long.dta"
						Uses: 
							"${intermediate_${phase}}/main_plotlist_long"
							"${constructed_${phase}}/identification"
							"${constructed_${phase}}/demographics.dta"
							"${intermediate_${phase}}/member_data_ag"
									
						Creates: 
							NOT SAVED, continues below 
						
					3. Outcome variables from plot-level dataset
						Uses: 	
							ABOVE FILE
							${intermediate_${phase}}/chad_main_2021						
						Creates: 
							"${intermediate_${phase}}/temp_agric_plots" ///// to merge 
						
					4. Crop type counts 
						Uses: 	
							${intermediate_${phase}}/main_plotlist_long
						
						Creates: 
							"${intermediate_${phase}}/crop_types" ///// to merge 
						
						
					5. Agreggated crop statuses: "16c_clean_ag_cropstatus.do" 
						Uses: 
							${intermediate_${phase}}/raincrops_1_long 
							${intermediate_${phase}}/drycrops_1_long
							${intermediate_${phase}}/member_data_wide , maybe use something else 
						
						Creates: 
							(r_cropstatus, d_cropstatus)
							$${constructed_${phase}}/temp_agric_cropstatuses ///// merged in harvest value below 
						
					6. Harvest value: "16d_clean_ag_value.do" 

						Uses: 
							"${intermediate_${phase}}/raincrops_2_long"
							"${intermediate_${phase}}/drycrops_2_long"
							
							"${intermediate_${phase}}/identification.dta"
							"${intermediate_${phase}}/temp_agric_cropstatuses" 
							
						Creates: 
							"${intermediate_${phase}}/price_dataset_harv_`season'"
							"${intermediate_${phase}}/temp_agric_valueandstatus"     ///// to merge 
							
						 
					7. Inputs: "16e_clean_ag_inputs.do" 
						Uses: 
							"${intermediate_${phase}}/chad_main_2021"
							"${intermediate_${phase}}/temp_agric_valueandstatus"
							"${intermediate_${phase}}/main_plotlist_long"
							"${intermediate_${phase}}/members_long"	
						
						Creates: 
							"${intermediate_${phase}}/temp_agric_inputs" /// to merge 
							
						
					8. Merge 
					Merges: 
						"${intermediate_${phase}}/temp_agric_plots"
						"${intermediate_${phase}}/temp_agric_cropcounts"
						"${intermediate_${phase}}/temp_agric_valueandstatus"
						"${intermediate_${phase}}/temp_agric_inputs"

					9. Final outcomes
					
					10. Saving final dataset: "$constructed_${phase}/agriculture"
					
					11. Repeat for household heal only
		
    */

	****************************************************************************

	


pause on

global locations p_village p_canton p_sousprefecture p_region



********************************************************************************
*** 1. Prep member data 
do "${do_folder}/02_cleaning/16b_clean_ag_mem_prep.do" 

********************************************************************************
*** 2. Add household member and community-level data to "${constructed_${phase}_${phase}_${cty}}/main_plotlist_long.dta"
use "${intermediate_${phase}}/main_plotlist_long", clear
merge m:1 hhid using "${constructed_${phase}}/identification", keepus(hhid ${locations} consent)
confirm var ${locations} // confirm locations were defined and merged in
drop _merge


merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(mem_n) 


drop if consent == 0 & _merge == 2 // consent only == 1 or == .
assert consent == 1

// add leading + trailing space
ds, has(type string)
foreach var in `r(varlist)' {
	replace `var' = trim(itrim(`var'))
}

ds plot_man plot_owner plot_worked
foreach var in `r(varlist)' {
	replace `var' = trim(itrim(`var'))

	replace `var' = " "+`var'+" "
}

// merge hh member data
merge m:1 hhid using "${intermediate_${phase}}/member_data_ag", gen(_merge_ag)
so hhid plot_pos
* assert _merge_ag == 3 // can't == 3 because some HHs have no plots... /?\
drop _merge _merge_ag 

// order variables
order consent mem_n chef_pos benef_pos same_cb female_list male_list adult_list ///
adult_f_list adult_m_list child_list child_f_list child_m_list hasplots , after(hhid)

// clean up community variables : order drop rename label variables
order hhid consent ${locations}, first


********************************************************************************
*** 3. Outcome variables from plot-level dataset

/*** 
hhid ag_any, ag_plot_n, ag_r_grew, ag_d_grew, ag_plot_ha, ag_plot_own_ha ///
ag_d_plot_cult_n, ag_r_plot_cult_n ag_irrig ///
ag_r_plot_chef ag_d_plot_chef ag_r_plot_benef ag_d_plot_benef ag_r_plot_fem ///
ag_d_plot_fem 
***/ 

gen ag_any = hasplots
label var ag_any "owns or cultivates any plot in last 12 months"	// this  is not a farmer indicator !!	

/** ag_plot_n **/
// main dataset
merge m:1 hhid using "${intermediate_${phase}}/chad_main_${phase_yr}.dta", keepus(hhid plot_n)
keep if _merge == 3
drop _merge
gen ag_plot_n = plot_n
replace ag_plot_n = 0 if hasplots == 0
label var ag_plot_n "total plots owned or cultivated in last 12 months"
drop plot_n


/** ag_plot_ha **/
gen plot_hectares = plot_size
replace plot_hectares = 0 if hasplots == 0


// convert sq. meters to hectares
replace plot_hectares = plot_size * (1/10000) if plot_size_u == 2


// cleaning: set plot_hectares = . if plot_size < 50 sq meters or > 6 hectares
replace plot_hectares = .m if (plot_size < 50 & plot_size_u == 2)
replace plot_hectares = .m if (plot_size > 6 & plot_size_u == 1)

gen plot_ha_miss = (plot_hectares == .)
byso hhid : egen plot_size_missing = max(plot_ha_miss)

byso hhid : egen ag_plot_ha = total(plot_hectares)
label var ag_plot_ha "total area of plots owned or cultivated in last 12 months"

// benef and chef shares of land
	gen plot_ownmanage = plot_man + plot_owner
	gen uniq_ownman = ""
	gen n_ownman_plot = 0 
	forval i = 1/`=_N' { 
		local all
		local all  `"`=plot_ownmanage[`i']'"'
		local unique_ownman : list uniq all
		replace uniq_ownman = "`unique_ownman'" in `i'
		replace n_ownman_plot = `: list sizeof unique_ownman' in `i'
	}

	// generate ownership dummies
	replace uniq_ownman = " " + uniq_ownman + " "
	gen benef_is_plotownman = .
	replace benef_is_plotownman = strpos(uniq_ownman, benef_pos) > 0
	gen chef_is_plotownman = .
	replace chef_is_plotownman  = strpos(uniq_ownman, chef_pos) > 0

	foreach stub in benef chef {
		// plot ownership
		byso hhid : egen ownman_`stub'_d  = max(`stub'_is_plotownman)
		label var ownman_`stub'_d "total area of plots owned or cultivated by `stub' in last 12 months"
		
		// number of plots owned 
		byso hhid : egen ag_plot_n_`stub' = total(`stub'_is_plotownman)
		label var ag_plot_n_`stub' "Number of plots owned or cultivated by `stub' in last 12 months"
		
		// plot areas
		gen plot_hectares_`stub' = plot_hectares if `stub'_is_plotownman == 1
		byso hhid : egen ag_plot_ha_`stub' = total(plot_hectares_`stub')
		label var ag_plot_ha_`stub' "total area of plots owned or cultivated by `stub' in last 12 months"
		drop plot_hectares_`stub'
	}
	
	drop *_is_plotownman
	
	// cultivates crops not owned by HH
	gen outown = 1 if plot_owner == " 0 ", after(plot_owner)
	replace outown = 0 if outown == .
	byso hhid : egen ag_plotnotown = max(outown) 
	label var ag_plotnotown "Cultivates a plot not owned by HH"


// Where one of the plots owned by the household has missing size, set total plot area owned by the household to missing
foreach var of varlist ag_plot_ha ag_plot_ha_benef ag_plot_ha_chef {
	replace `var' = .m if plot_size_missing == 1
}


/** ag_plot_own_ha **/
gen plot_own_ha = 0 
replace plot_own_ha = plot_hectares if strpos(" 0 ", plot_owner) == 0 
byso hhid : egen ag_plot_own_ha = total(plot_own_ha) 
label var ag_plot_own_ha "total area of plots owned in last 12 months"

replace ag_plot_own_ha = . if plot_size_missing == 1
drop plot_ha_miss plot_size_missing plot_hectares


/** ag_*_plot_cult_n **/
gen tag_rain_cult = (plot_israin == 1 & plot_key == 1)
byso hhid : egen ag_r_plot_cult_n = total(tag_rain_cult)
label var ag_r_plot_cult_n "total key plots cultivated in the rainy season"

gen tag_dry_cult = (plot_isdry == 1 & plot_key == 1)
byso hhid : egen ag_d_plot_cult_n = total(tag_dry_cult)
label var ag_d_plot_cult_n "total key plots cultivated in the dry season"

drop tag_rain_cult tag_dry_cult

#delimit ; 
label define plot_water
			6 "Tap water"
			7 "Container/reservoir", add;
# delimit cr

/** ag_irrig **/
/* NOTE: creating dummy if household has an irrigated plot -- first need to clean plot_water/plot_water_o */


	gen plot_water_recode = plot_water, after(plot_water) 
	label val plot_water_recode plot_water 

	// BL
	replace plot_water_recode = 10 if plot_water_o == "9" // 9
	replace plot_water_recode = 6 if plot_water_o == "Au de robinets a portée" // At the taps within reach
	replace plot_water_recode = 7 if plot_water_o == "Bideau d'eau" // Water canister
	replace plot_water_recode = 7 if plot_water_o == "Bidons d'eau" // Water cans
	replace plot_water_recode = 6 if plot_water_o == "Eau de puies" // Tap water
	replace plot_water_recode = 6 if plot_water_o == "Eau de robine" // Robine water
	replace plot_water_recode = 6 if plot_water_o == "Eau de robinet" // Tap water
	replace plot_water_recode = 2 if plot_water_o == "Fleuve" // River
	replace plot_water_recode = 6 if plot_water_o == "L eau du robinet" // Tap water
	replace plot_water_recode = 6 if plot_water_o == "L eau du robinet" // Tap water
	replace plot_water_recode = 6 if plot_water_o == "Leau du robinet" // Tap water
	replace plot_water_recode = 6 if plot_water_o == "Leau du robinet" // Tap water
	replace plot_water_recode = 6 if plot_water_o == "Leau robinet" // Water tap
	replace plot_water_recode = 4 if plot_water_o == "Pluie" // Rain
	replace plot_water_recode = 4 if plot_water_o == "Pluie" // Rain
	replace plot_water_recode = 4 if plot_water_o == "Pluivial" // Plural
	replace plot_water_recode = 4 if plot_water_o == "Pluviale" // Rain
	replace plot_water_recode = 1 if plot_water_o == "Puit" // Well
	replace plot_water_recode = 1 if plot_water_o == "Puits" // Well
	replace plot_water_recode = 6 if plot_water_o == "Robine" // Robine
	replace plot_water_recode = 6 if plot_water_o == "robinet du voisin" // neighbor's faucet
	replace plot_water_recode = 4 if plot_water_o == "Eau de la pluie" // Rain water
	replace plot_water_recode = 4 if plot_water_o == "Eau de pluies" // Rain water
	replace plot_water_recode = 4 if plot_water_o == "L eau de pluit" // Rain water
	// FU
	replace plot_water_recode = 4 if plot_water_o == "Après inondations sesonnaire" // After seasonal flooding
	replace plot_water_recode = 4 if plot_water_o == "Après inondations sesonnere" // After floods are heard
	replace plot_water_recode = 1 if plot_water_o == "Arrosage" // Watering
	replace plot_water_recode = 6 if plot_water_o == "Robinet" // Faucet
	replace plot_water_recode = 6 if plot_water_o == "Robinets" // Taps

	gen irrig = (plot_water_recode == 1 | plot_water_recode == 2  | plot_water_recode == 3 )

	byso hhid : egen ag_irrig = max(irrig)
	
	drop irrig

** many have robinet or bidon d'eau, assume that not irrigated 


// confirm all "other" responses are handled
label var ag_irrig "has (at least one) irrigated plot"


/** ag_*_plot_chef **/
gen rplot_chef = 0
replace rplot_chef = 1 if plot_israin == 1 & regexm(plot_owner, chef_pos)
replace rplot_chef = 1 if plot_israin == 1 & regexm(plot_man, chef_pos)
byso hhid : egen ag_r_plot_chef = max(rplot_chef)
label var ag_r_plot_chef "head of household owns or manages a rain plot"

gen dplot_chef = 0
replace dplot_chef = 1 if plot_isdry == 1 & regexm(plot_owner, chef_pos)
replace dplot_chef = 1 if plot_isdry == 1 & regexm(plot_man, chef_pos)
byso hhid : egen ag_d_plot_chef = max(dplot_chef)
label var ag_d_plot_chef "head of household owns or manages a dry plot"

drop rplot_chef dplot_chef



/**** BENEFICIARY 
/** ag_*_plot_benef **/
gen rplot_benef = 0
replace rplot_benef = 1 if plot_israin == 1 & regexm(plot_own, benef)
replace rplot_benef = 1 if plot_israin == 1 & regexm(plot_man, benef)
byso hhid : egen ag_r_plot_benef = max(rplot_benef)
label var ag_r_plot_benef "beneficiary owns or manages a rain plot"

gen dplot_benef = 0
replace dplot_benef = 1 if plot_isdry == 1 & regexm(plot_own, benef)
replace dplot_benef = 1 if plot_isdry == 1 & regexm(plot_man, benef)
byso hhid : egen ag_d_plot_benef = max(dplot_benef)
label var ag_d_plot_benef "beneficiary owns or manages a dry plot"

drop rplot_benef dplot_benef
****/ 

/** ag_*_plot_fem **/
split female_list, parse(" ") gen(female_)
gen r_plot_fem = 0
gen d_plot_fem = 0

ds female_*
foreach var in `r(varlist)' {
	replace `var' = " "+`var'+" "

	replace r_plot_fem = 1 if plot_israin == 1 & strpos(plot_owner, `var') > 0
	replace r_plot_fem = 1 if plot_israin == 1 & strpos(plot_man, `var') > 0

	replace d_plot_fem = 1 if plot_isdry == 1 & strpos(plot_owner, `var') > 0
	replace d_plot_fem = 1 if plot_isdry == 1 & strpos(plot_man, `var') > 0

}

byso hhid : egen ag_r_plot_fem = max(r_plot_fem)
byso hhid : egen ag_d_plot_fem = max(d_plot_fem)
label var ag_r_plot_fem "women own or manages a rain plot in household"
label var ag_d_plot_fem "women own or manages a dry plot in household"

drop female_* r_plot_fem d_plot_fem

/** ag_*_grew **/
gen rgrew = (rcrop_n > 0 & !missing(rcrop_n))
byso hhid : egen ag_r_grew = max(rgrew)
label var ag_r_grew "grew at least one annual crop in the rainy season (key plots)"

drop rgrew

if "$ph" == "bl" {
	gen dgrew = (dcrop_n > 0 & !missing(dcrop_n))	
	byso hhid : egen ag_d_grew = max(dgrew)	
	label var ag_d_grew "grew at least one annual crop in the dry season (key plots)"
	drop dgrew
	local bl_var ag_d_grew
}


keep hhid ag_any ag_plot_n ag_plot_n_benef ag_plot_n_chef ag_r_grew `bl_var' ag_plotnotown ///
		  ag_plot_ha ag_plot_ha_benef ag_plot_ha_chef ag_plot_own_ha ///
		  ag_d_plot_cult_n ag_r_plot_cult_n ag_irrig ///
		  ag_r_plot_chef ag_d_plot_chef  ag_r_plot_fem ///
		  ag_d_plot_fem 
*ag_r_plot_benef ag_d_plot_benef 
duplicates drop 
isid hhid 

save "${intermediate_${phase}}/temp_agric_plots", replace 


********************************************************************************
***4. Crop type counts 

use	"${intermediate_${phase}}/main_plotlist_long.dta", clear 



if "$ph" == "bl" {
		local veg "Tomate"	"gombo"	"Aubergine"	"Oignon" "Chou/Salade" "Haricot-vert" ///
				  "Carotte" "Pastèque/melon" "nana" "Courgette, concombre" "melon" ///
				  "jujube" "feuilledebisabe" "diakhtiene" "jaxatu" "lekwaz" "likwaz" ///
				  "courge" "bissap" "bisap" "bissab" "diayedje" // diayedje only here temporarily
		local tuber "Patates douces" "Betterave"
		local pulse "Arachide" "arachides"	"arachide" "Niébé/ Haricots secs" "niebe" "haricot" "khanini"
		local cereal "Mil" "mil" "Maïs"	"Sorgho"	"Blé"	"Petit mil (matri)"	"mais"	"Riz paddy"	"Orge"
		local cash	
}
else if "$ph" == "fu" {
		local veg "bissap"	"hibiscus" "nana" "plante" "Pomme de cajou"	///
				  "Tomate"	"choux" "Oignon" "feuilledementhe"	///
				  "feuilledepatates"  "menthe" "Gombo" "gombo" "goumbo" "Aubergine"	///
				  "Banane" "Pastèque/Melon" "Pastèque/melon" "oseille" "kandia" "kandje" ///
				  "salade" "Chou/Salade" "piment" "bisap" "courge" "couge" "aubegineamere"	///
				  "pasteque" "concombre" "concombres" "citronnelle" "carrot" ///
				  "Carotte" "Courgette, concombre"  "yomb" "Mangue" ///
				  "nbigue" "lkoz" // temporarily placed here /!\
				  
		local tuber "Manioc" "Patate douce" "patatedouce" "Patates douces" "Ignames"
		local pulse "Arachide" "arachide" "Haricot/Niébé" "Niébé/ Haricots secs" ///
					"Haricot-vert" "arico" "navet" "gnebe" "niebe"
		local cereal "Blé" "Mil" "Sorgho" "Maïs" "Riz" "Riz paddy" "boroboro" "Sésame" ///
					"Orge" "Petit mil (matri)"
		local cash "canne" "aloevera" "basilique"
		
		/* uncat (temporarily in vege category): 
			nbigue 
			lkoz
		*/	
}


	foreach type in tuber pulse cereal veg cash { // loop over categories
	
		gen c_div_`type' = 0 
// 		dis "type: ``type''"
		local n: word count "``type''"
		display "n = `n'"
		
		forvalues i = 1/`n' { // loop over crop types in name variables
			local v1 : word `i' of "``type''"
// 			dis "``type''"
			qui ds rcropname? rcropname?? 
			local crops: word count `r(varlist)'
			if "`v1'" != "" { // if there is a crop in this category
				forvalues p = 1/`crops' { // loop over cropname variables
					qui replace rcropname`p' = "" if rcropname`p' == "."
					replace c_div_`type' = c_div_`type' + 1 if rcropname`p' == "`v1'"
				}
			}
		}	
		
		gen div_any_temp = c_div_`type' > 0
		byso hhid: egen div_`type' = max(div_any_temp)
		label variable div_`type' "Household grew `type'"
		drop div_any_temp
	}
	
	// assert raincrops were categorized and no overcounting
	// for given dataset (b/c code is conditional on country)
	egen temp_total_types = rowtotal(c_div_*) // 5 types
	egen temp_total_crops = rownonmiss(rcropname*), strok // 10 crop vars
	*assert temp_total_types == temp_total_crops
	drop temp_total*
	
	if "$ph" == "bl" {
		gen c_div_dry = 0 	
		replace c_div_dry = 1 if dcrop1 != . 	
		bysort hhid: egen div_dry = max(c_div_dry) 	
		label variable div_dry "Household grew in dry season"
	}			
	
	drop c_*
	keep hhid div_*
	duplicates drop hhid div_*, force 
	isid hhid 
	
	
	save	"${intermediate_${phase}}/crop_types", replace
	
	
********************************************************************************
***5. Crop type counts BENEFICIARY ONLY

use	"${intermediate_${phase}}/main_plotlist_long.dta", clear 


	// merge in benef
	merge m:1 hhid using "${constructed_${phase}}/demographics", keepusing(benef_pos chef_pos) gen(_mBenPos)
	tostring benef_pos, replace	
	tostring chef_pos, replace	
	drop if _mBenPos == 2
	drop _mBenPos

	// ignore plots not owned or managed by anyone in the HH
	drop if plot_owner == "0" & plot_man == "0" // no observations
	
	gen n_ownman_plot = 0 
	replace plot_owner = " " + plot_owner + " "
	replace plot_man = " " + plot_man + " "
	gen plot_ownmanage = plot_owner + plot_man 
	gen uniq_ownman = ""
	
	// count number of owners/managers for each plot
	forval i = 1/`=_N' { 
		local all
		local all  `"`=plot_ownmanage[`i']'"'
		dis "`all'"
		local unique_ownman : list uniq all
		dis "`unique_ownman'"
		replace uniq_ownman = "`unique_ownman'" in `i'
		replace n_ownman_plot = `: list sizeof unique_ownman' in `i'
		local all 
	}
	drop plot_ownmanage

	// tag plot if benef is among owners/managers
	replace uniq_ownman = " " + uniq_ownman + " "
	replace benef_pos = " " + benef_pos + " "
	gen benef_is_plotownman = .
	replace benef_is_plotownman = 1 if strpos(uniq_ownman, benef_pos)

	
	//1,717 benefs own/manage their plots
	order benef_is_plotownman, after (benef_pos)
	// keep number of owners/managers only for beneficiary owned plots
	replace n_ownman_plot = . if benef_is_plotownman != 1 
	label variable n_ownman_plot "number of owners/managers of a plot if beneficiary is among them"

	// generate ownership dummy
	gen ben_owner_dum = benef_is_plotownman
	replace ben_owner_dum = 0 if missing(ben_owner_dum)

	
	** keeping only plots managed by beneficiary
	keep if ben_owner_dum == 1


		local veg "bissap"	"hibiscus" "nana" "plante" "Pomme de cajou"	///
				  "Tomate"	"choux" "Oignon" "feuilledementhe"	///
				  "feuilledepatates"  "menthe" "Gombo" "gombo" "goumbo" "Aubergine"	///
				  "Banane" "Pastèque/Melon" "Pastèque/melon" "oseille" "kandia" "kandje" ///
				  "salade" "Chou/Salade" "piment" "bisap" "courge" "couge" "aubegineamere"	///
				  "pasteque" "concombre" "concombres" "citronnelle" "carrot" ///
				  "Carotte" "Courgette, concombre"  "yomb" "Mangue" ///
				  "nbigue" "lkoz" // temporarily placed here /!\
				  
		local tuber "Manioc" "Patate douce" "patatedouce" "Patates douces" "Ignames"
		local pulse "Arachide" "arachide" "Haricot/Niébé" "Niébé/ Haricots secs" ///
					"Haricot-vert" "arico" "navet" "gnebe" "niebe"
		local cereal "Blé" "Mil" "Sorgho" "Maïs" "Riz" "Riz paddy" "boroboro" "Sésame" ///
					"Orge" "Petit mil (matri)"
		local cash "canne" "aloevera" "basilique"
		
		/* uncat (temporarily in vege category): 
			nbigue 
			lkoz
		*/



	foreach type in tuber pulse cereal veg cash { // loop over categories
	
		gen c_div_`type' = 0 
// 		dis "type: ``type''"
		local n: word count "``type''"
		display "n = `n'"
		
		forvalues i = 1/`n' { // loop over crop types in name variables
			local v1 : word `i' of "``type''"
// 			dis "``type''"
			qui ds rcropname? rcropname?? 
			local crops: word count `r(varlist)'
			if "`v1'" != "" { // if there is a crop in this category
				forvalues p = 1/`crops' { // loop over cropname variables
					qui replace rcropname`p' = "" if rcropname`p' == "."
					replace c_div_`type' = c_div_`type' + 1 if rcropname`p' == "`v1'"
				}
			}
		}	
		
		gen div_any_temp = c_div_`type' > 0
		byso hhid: egen div_ben_`type' = max(div_any_temp)
		label variable div_ben_`type' "Household grew `type'"
		drop div_any_temp
	}
	
	// assert raincrops were categorized and no overcounting
	// for given dataset (b/c code is conditional on country)
	egen temp_total_types = rowtotal(c_div_*) // 5 types
	egen temp_total_crops = rownonmiss(rcropname*), strok // 10 crop vars
	*assert temp_total_types == temp_total_crops
	drop temp_total*
	
		
	drop c_*
	keep hhid div_ben_*
	duplicates drop hhid div_ben_*, force 
	isid hhid 
	
	
	save	"${intermediate_${phase}}/crop_types_ben", replace
	
********************************************************************************
*** 6. Agreggated crop statuses
do "${do_folder}/02_cleaning/16c_clean_ag_cropstatus.do" 

********************************************************************************
*** 7. Harvest value 
do "${do_folder}/02_cleaning/16d_clean_ag_value.do" 
 
********************************************************************************
*** 8. Inputs 
do "${do_folder}/02_cleaning/16e_clean_ag_inputs.do" 

********************************************************************************
*** 9. Merge 

use "${intermediate_${phase}}/temp_agric_plots", clear 

if "$ph" == "bl" local end_vars ag_d_grew
if "$ph" == "fu" local end_vars ag_r_grew
foreach var of varlist  ag_any - `end_vars' { 
	assert !missing(`var')
} 
		

merge 1:1 hhid using "${intermediate_${phase}}/temp_agric_valueandstatus", gen(_m2)

if "$ph" == "bl" local end_vars ag_d_comm
if "$ph" == "fu" local end_vars ag_r_comm
foreach var of varlist ag_r_hrv_xof_imp - `end_vars' { 
	recode `var' (.=0) 
}

// commercialization conditional on harvesting 
					replace ag_r_comm = . if ag_r_hrv_xof_imp == 0 | missing(ag_r_hrv_xof_imp) 
if "$ph" == "bl" 	replace ag_d_comm = . if ag_d_hrv_xof_imp == 0 | missing(ag_d_hrv_xof_imp)  

if "$ph" == "bl" local extra div_dry_n
if "$ph" == "bl" local end_vars ag_d_harv
if "$ph" == "fu" local end_vars ag_r_harv
foreach var of varlist `end_vars' - ag_r_sold div_rain_n `extra' { 
	recode `var' (.=0) 
}
 
 
merge 1:1 hhid using "${intermediate_${phase}}/temp_agric_inputs", gen(_m3)

foreach var of varlist ag_r_hhh_days - ag_r_income_xof { 
	recode `var' (.=0) 
} 


merge 1:1 hhid using "${intermediate_${phase}}/crop_types", gen(_m4) 

foreach var of varlist div_* { 
	recode `var' (.=0) 
} 

if "$ph" == "bl" local extra div_dry
egen div_crop_types = rsum(div_tuber div_pulse div_cereal div_veg div_cash `extra') 
label variable div_crop_types "B.3.2 Crop types grown (1-5): cereals, pulses, tubers, vegetables/fruits, other cash"



merge 1:1 hhid using "${intermediate_${phase}}/crop_types_ben", gen(_m5) 

foreach var of varlist div_ben* { 
	recode `var' (.=0) 
} 


egen div_crop_types_ben = rsum(div_ben_tuber div_ben_pulse div_ben_cereal div_ben_veg div_ben_cash) 
label variable div_crop_types_ben "B.3.2 Crop types grown (1-5) Beneficiary: cereals, pulses, tubers, vegetables/fruits, other cash"


drop _* 



********************************************************************************
** Assertions 

assert ag_any == 1 if ag_plot_n > 0 
assert ag_any == 0 if ag_plot_n == 0
assert ag_plot_ha >= ag_plot_own_ha 

assert ag_plot_n >= ag_r_plot_cult_n
if "$ph" == "bl" assert ag_plot_n >= ag_d_plot_cult_n


assert ag_any == 1 if ag_irrig == 1 

if "$ph" == "bl" local extra d 
foreach s in r `extra' { 
	assert ag_`s'_plot_cult_n != 0 if ag_`s'_grew == 1 
} 

					assert ag_r_plot_cult_n != 0 if div_rain_n != 0 
if "$ph" == "bl" 	assert ag_d_plot_cult_n != 0 if div_dry_n  != 0

if "$ph" == "bl" {
	gen test = 0 
	ds ag_r_hrv_*_imp_xof
	local count : word count(`r(varlist)') 
	forvalues i = 1/`count' { 
		replace test = test + ag_r_hrv_`i'_imp_xof if !missing(ag_r_hrv_`i'_imp_xof) 
	}

	assert round(ag_r_hrv_xof_imp_98,1) == round(test,1)  if !missing(ag_r_hrv_xof_imp_98) 
				 
	drop test 

	gen test = 0 
	ds ag_d_hrv_*_imp_xof
	local count : word count(`r(varlist)') 
	forvalues i = 1/`count' { 
		replace test = test + ag_d_hrv_`i'_imp_xof if !missing(ag_d_hrv_`i'_imp_xof) 
	}

	assert round(ag_d_hrv_xof_imp_98,1) == round(test,1)  if !missing(ag_d_hrv_xof_imp_98) 

	drop test 
}


					assert ag_r_comm == . if ag_r_hrv_xof_imp_98 == 0 
if "$ph" == "bl" 	assert ag_d_comm == . if ag_d_hrv_xof_imp_98 == 0 


if "$ph" == "bl" {
	foreach s in r d { 	
		display "`s' - 1"	
		*assert ag_`s'_plot_cult_n !=0  if  ag_`s'_control == 1 	
		*assert ag_`s'_plot_cult_n !=0 if ag_`s'_harv == 1 	
			
		display "`s' - 2"	
		assert ag_`s'_plot_cult_n !=0  if  ag_`s'_partial == 1 	
		assert ag_`s'_plot_cult_n !=0 if ag_`s'_lost == 1 	
			
		display "`s' - 3"	
		assert ag_`s'_plot_cult_n !=0 if ag_`s'_field == 1 	
		assert ag_`s'_harv == 1 if ag_`s'_sold == 1 // only sold if harvested	
			
		display "`s' - 4"	
		assert ag_`s'_comm == . if ag_`s'_harv == 0 	
		assert (ag_`s'_comm == . | ag_`s'_comm == 0) if ag_`s'_sold == 0 	
	} 
}


					assert div_rain_n == 0 if ag_r_harv == 0
if "$ph" == "bl" 	assert div_dry_n == 0  if ag_d_harv == 0


drop had* 

********************************************************************************
*** 10. Final outcomes 

if "$ph" == "fu" {
	local crops
	ds ag_r_*_imp_xof 


	/*
	foreach var in `r(varlist)' {
		local stub = substr("`var'", 7, strlen("`var'")-7+1)	
		local stub = substr("`stub'", 1, strlen("`stub'")-16)	

		local crops : list crops | stub
		local crops : list uniq crops
	}
	*/ 


	foreach i in `crops' {
		// if that crop DNE, generate an empty variable for the summation later
		capture confirm var ag_r_c`i'_imp_xof
		if (_rc != 0) gen 	ag_r_c`i'_imp_xof = 0


		egen ag_c`i'_imp_xof = rowtotal(ag_r_c`i'_imp_xof)
		label var ag_c`i'_imp_xof "imputed harvest, crop `i' on plots own/mngd by ben/chef, both seasons"
	}	
}

/*
{

	// order crop-specific harvest values by crop id
	// fetch largest crop number from crop list
	ds ag_r_hrv_*_imp_xof
	local mylist `r(varlist)'

	local max_num 0 // initiate max_num to collect max crop num
	local remove ag_cother_hrv_imp_xof
	local mylist : list mylist - remove
	
	
	foreach var in `mylist' {
		local stub = substr("`var'", 5, strlen("`var'")-5+1)	
		local num = substr("`stub'", 1, strlen("`stub'")-16)
		dis "`num'"
		if (`num' > `max_num') local max_num `num' // collect max num
	}
	
	dis "`max_num'"

	// create sorted list
	forval j = 1/`max_num' { 
		capture confirm var ag_c`j'_hrv_imp_xof
		if (_rc == 0) local neworder `neworder' ag_c`j'_hrv_imp_xof
	}
	dis "`neworder'"
	local neworder `neworder' ag_cother_hrv_imp_xof
	order `neworder', before(ag_r_sale_xof)
}
*/ 



// sum values across seasons (method 1)
if "$ph" == "bl" 	egen ag_hrv_12_xof_imp = rowtotal(ag_r_hrv_xof_imp ag_d_hrv_xof_imp)
if "$ph" == "fu" 	egen ag_hrv_12_xof_imp = rowtotal(ag_r_hrv_xof_imp)
label var ag_hrv_12_xof_imp "imputed harvest, plots owned or managed by beneficiary or household head, both seasons"

foreach p in 95 98 99 {
	if "$ph" == "bl" 	egen ag_hrv_12_xof_imp_`p' = rowtotal(ag_r_hrv_xof_imp_`p' ag_d_hrv_xof_imp_`p')
	if "$ph" == "fu" 	egen ag_hrv_12_xof_imp_`p' = rowtotal(ag_r_hrv_xof_imp_`p')
	label var ag_hrv_12_xof_imp_`p' "wins(`p') & imputed harvest, plots owned or managed by beneficiary or household head, both seasons"
}

if "$ph" == "bl"	egen ag_hrv_12_ben_xof_imp = rowtotal(ag_r_hrv_ben_xof_imp_98 ag_d_hrv_ben_xof_imp_98)
if "$ph" == "fu" 	egen ag_hrv_12_ben_xof_imp = rowtotal(ag_r_hrv_ben_xof_imp_98)
label var ag_hrv_12_ben_xof_imp "imputed harvest, plots owned or managed by beneficiary, both seasons (98 p wins.)"


	*** hh less benef ***
	gen ag_hrv_12_hhlb_xof_imp = ag_hrv_12_xof_imp_98 - ag_hrv_12_ben_xof_imp
	label var ag_hrv_12_hhlb_xof_imp "imputed harvest, plots owned or managed by all but benef., both seasons (98 p wins.)"
	*** hh less benef ***
	
	*** benef over hh ***
	gen ag_hrv_12_bohh_xof_imp = ag_hrv_12_ben_xof_imp / ag_hrv_12_xof_imp_98
	label var ag_hrv_12_bohh_xof_imp "imputed harvest, benef./hh share, both seasons (98 p wins.)"
	*** benef over hh ***
	
// sum values across seasons (method 2)
if "$ph" == "bl" 	egen ag_hrv_12_xof = rowtotal(ag_r_hrv_xof ag_d_hrv_xof)
if "$ph" == "fu"	egen ag_hrv_12_xof = rowtotal(ag_r_hrv_xof)
label var ag_hrv_12_xof "harvest (method 2), plots owned or managed by beneficiary or household head, both seasons"

foreach p in 95 98 99 {
	if "$ph" == "bl"	egen ag_hrv_12_xof_`p' = rowtotal(ag_r_hrv_xof_`p' ag_d_hrv_xof_`p')
	if "$ph" == "fu"	egen ag_hrv_12_xof_`p' = rowtotal(ag_r_hrv_xof_`p')
	label var ag_hrv_12_xof_`p' "wins(`p') harvest (method 2), plots owned or managed by beneficiary or household head, both seasons"
}



// confirm benef value is always <= total hh value
assert ag_hrv_12_ben_xof_imp > 0 | !missing(ag_hrv_12_ben_xof_imp) if ben_owns_d == 1
assert ben_owns_d == 1 if ag_hrv_12_ben_xof_imp > 0 & !missing(ag_hrv_12_ben_xof_imp)

if "$ph" == "bl" egen ag_sale_xof_imp = rowtotal(ag_r_sale_imp_xof ag_d_sale_imp_xof)
if "$ph" == "fu" egen ag_sale_xof_imp = rowtotal(ag_r_sale_imp_xof)
label var ag_sale_xof_imp "imputed sale value, plots owned or managed by beneficiary or household head, both seasons"


foreach p in 95 98 99 {
	if "$ph" == "bl" egen ag_sale_xof_imp_`p' = rowtotal(ag_r_sale_imp_xof_`p' ag_d_sale_imp_xof_`p')
	if "$ph" == "fu" egen ag_sale_xof_imp_`p' = rowtotal(ag_r_sale_imp_xof_`p')
	label var ag_sale_xof_imp_`p' "imputed sale value, plots owned or managed by beneficiary or household head (wins. `p'p), both seasons"
}

** yield
// some denominators DNE because of the area trim.
// These areas are also trimmed when computing beneficiary share of crop harvest value
gen yield_12_xof = (ag_hrv_12_xof_imp) / ag_plot_ha 
label var yield_12_xof "harvest value per hectare"

recode div_ag_n (. = 0)

if "$ph" == "bl" local extra ag_r_comm ag_d_comm
if "$ph" == "fu" local extra ag_r_comm
ds div_ag_n hhid `extra', not
foreach var in `r(varlist)' {
	replace `var' = 0 if `var' == . & div_ag_n == 0
}


** inputs index
merge 1:1 hhid using "${constructed_${phase}}/identification", gen(_mtreat) keepusing(treatment_status pm_treatment)
assert _mtreat == 3
drop _mtreat

local inputdummies ag_r_seeds_d ag_r_fert_d ag_r_pest_d ag_r_paidlab_d 
zindex `inputdummies', gen(ag_input_index) condition(pm_treatment == 0)
label variable ag_input_index "Agricultural inputs index"



* Converting monetary variables to 1000 FCFA
********************************************************************************
ds *xof* // run through all variables with FCFA units
local xof_vars `r(varlist)'
local omit ag_hrv_12_bohh_xof_imp
local xof_vars : list xof_vars - omit

// scale up currency vars
foreach var in `xof_vars' {
	replace `var' = `var' / 1000 	// replace old
	local this_lab : variable label `var'
	label var `var' "(1000 FCFA) `this_lab'"
}



********************************************************************************
// save
so hhid
isid hhid 

// don't compress
save "${constructed_${phase}}/agriculture", replace



********************************************************************************
// explore wins.
/*
foreach var in ag_hrv_12_xof_imp ag_hrv_12_xof_imp_95 ///
				ag_hrv_12_xof_imp_98 ag_hrv_12_xof_imp_99 ///
				ag_hrv_12_xof ag_hrv_12_xof_95 ///
				ag_hrv_12_xof_98 ag_hrv_12_xof_99 {
	qui sum `var'
	qui loc round_mean : di %15.2fc `r(mean)'
	qui loc round_sd : di %15.2fc `r(sd)'

	dis "`var'* `round_mean'* `round_sd'"
}
*/
********************************************************************************
*** 11 agriculture chef

do "${do_folder}/02_cleaning/16f_clean_agriculture_chef.do" 

use "${constructed_${phase}}/agriculture", clear 
merge 1:1 hhid using "${constructed_${phase}}/agriculture_chef", gen(_mChef)
assert _mChef != 2 

// replace missing by true zeros
if "$ph" == "bl" local end_vars ag_hrv_12_chef_xof_99
if "$ph" == "fu" local end_vars chef_owns_d
foreach var of varlist  Sésame_d - `end_vars' { 
	replace `var' = 0 if `var' == . & _mChef == 1 
} 

drop _mChef

save "${constructed_${phase}}/agriculture", replace