**** GET HARVEST VALUE DATA :: MAKE A BUNCH OF PROGRAMS THEN PUT IT ALL TOGETHER 
********************************************************************************
/*** FIRST, rain crops, then, dry crops ***/ 


********************************************************************************
*** PROGRAM: scale_ben_share  
********************************************************************************

capture prog drop scale_ben_share 
prog define scale_ben_share
		syntax, season(string) 

		if "`season'" == "r" {
			local s r
			local season_full rain
		}
		else if "`season'" == "d" {
			local s d
			local season_full dry
		}
		
	
	use "${intermediate_${phase}}/`season_full'crops_2_long", clear

	merge m:1 hhid using "${constructed_${phase}}/demographics", keepusing(benef_pos) gen(_mBenPos)
	drop if _mBenPos == 2
	drop _mBenPos

	tempfile `season_full'crops_2
	save ``season_full'crops_2'

********************************************************************************
*** Diverge to adjust crop harvest values by number of owners 
********************************************************************************

	use "${intermediate_${phase}}/main_plotlist_long", clear
	order hhid plot_pos plot_rain_harv 
	keep if plot_is`season_full'  // drop off season plots
	
	// merge in benef
	merge m:1 hhid using "${constructed_${phase}}/demographics", keepusing(benef_pos chef_pos) gen(_mBenPos)
	tostring benef_pos, replace	
	tostring chef_pos, replace	
	drop if _mBenPos == 2
	drop _mBenPos
	
	** ------| A. create list of plot sizes within each HH
	// tempfile: plotSizeList
	preserve
		keep hhid plot_pos plot_size plot_size_u
		sort hhid plot_pos 
		
		// trim plot sizes
		/** ag_plot_ha **/
		merge m:1 hhid using "${intermediate_${phase}}/chad_main_${phase_yr}.dta", keepus(consent hasplots) gen(_m)
		keep if _m == 3 // 
		assert consent == 1
		gen plot_hectares = plot_size
		replace plot_hectares = 0 if hasplots == 0

		// convert sq. meters to hectares
		replace plot_hectares = plot_size * (1/10000) if plot_size_u == 2


		// cleaning: set plot_hectares = . if plot_size < 50 sq meters or > 6 hectares
		replace plot_hectares = .m if (plot_size < 50 & plot_size_u == 2)
		replace plot_hectares = .m if (plot_size > 6 & plot_size_u == 1)
		
		keep plot_hectares hhid plot_pos
		reshape wide plot_hectares, i(hhid) j(plot_pos)

		// bring all into one var
		gen plot_sizelist = ""
		ds hhid plot_sizelist, not
		foreach var in `r(varlist)'{
			replace plot_sizelist = plot_sizelist + " " + string(`var')
		}
		label var plot_sizelist "List of plot sizes for beneficiary owned/managed plots"
		keep hhid plot_sizelist 
		
		tempfile  plotSizeList
		save 	 `plotSizeList'
	restore

	
	** ------| B. Count number of owners/managers per plot (beneficiary plots only)
	// tempfile: plot_ownmanage
	
	// ignore plots not owned or managed by anyone in the HH
	drop if plot_owner == "0" & plot_man == "0" // no observations
	
	gen n_ownman_plot = 0 
	replace plot_owner = " " + plot_owner + " "
	replace plot_man = " " + plot_man + " "
	gen plot_ownmanage = plot_owner + plot_man 
	gen uniq_ownman = ""
	
	// count number of owners/managers for each plot
	forval i = 1/`=_N' { 
		local all
		local all  `"`=plot_ownmanage[`i']'"'
		dis "`all'"
		local unique_ownman : list uniq all
		dis "`unique_ownman'"
		replace uniq_ownman = "`unique_ownman'" in `i'
		replace n_ownman_plot = `: list sizeof unique_ownman' in `i'
		local all 
	}
	drop plot_ownmanage

	// tag plot if benef is among owners/managers
	replace uniq_ownman = " " + uniq_ownman + " "
	replace benef_pos = " " + benef_pos + " "
	gen benef_is_plotownman = .
	replace benef_is_plotownman = 1 if strpos(uniq_ownman, benef_pos)

	
	//1,717 benefs own/manage their plots
	order benef_is_plotownman, after (benef_pos)
	// keep number of owners/managers only for beneficiary owned plots
	replace n_ownman_plot = . if benef_is_plotownman != 1 
	label variable n_ownman_plot "number of owners/managers of a plot if beneficiary is among them"

	// generate ownership dummy
	gen ben_owner_dum = benef_is_plotownman
	replace ben_owner_dum = 0 if missing(ben_owner_dum)
	byso hhid : egen `s'_ben_ownman_d  = max(ben_owner_dum)
	label var `s'_ben_ownman_d "Crop is owned/managed by beneficiary (HH-level)"

	// find if chef owns/manages the plot
	replace chef_pos = " " + chef_pos + " "
	gen chef_is_plotownman = .
	replace chef_is_plotownman = 1 if strpos(uniq_ownman, chef_pos)
	
	
	// find hhs where only chef owns all plots
	gen cnotb_ownman_d = chef_is_plotownman == 1 & benef_is_plotownman != 1
	byso hhid : egen `s'_cnotb_ownman_d = max(cnotb_ownman_d)
	replace `s'_cnotb_ownman_d = 0 if `s'_ben_ownman_d // cnotb not 1 if beneficiary owns diff plot in hh

	preserve
		keep hhid `s'_ben_ownman_d `s'_cnotb_ownman_d
		duplicates drop
		sort hhid

		save "${intermediate_${phase}}/temp_agric_`s'_ben_owns", replace
	restore

		

	count if benef_is_plotownman == 1	
	
	preserve
		keep if benef_is_plotownman == 1
		keep hhid
		duplicates drop
		dis _N // 1,112 unique HHs have plots owned/managed by a beneficiary
	restore
	
	
	// keep needed into n_ownman per plot
	keep hhid plot_pos n_ownman_plot
	sort hhid plot_pos 
	reshape wide n_ownman_plot, i(hhid) j(plot_pos)

	// bring all into one vara
	gen plot_ownermanager = ""
	ds hhid plot_ownermanager, not
	foreach var in `r(varlist)'{
		replace plot_ownermanager = plot_ownermanager + " " + string(`var')
		*format `var' %9.3fc
		*tostring `var', gen(`var'_str) format("%9.4f")
	}
	label var plot_ownermanager "List of no. of owners in beneficiary owned/managed plots"
	keep hhid plot_ownermanager 

	tempfile plot_ownmanage
	save `plot_ownmanage'

	
	** ------| C. Merge plot size and plot owner lists into crop-level dataset
	// (keep benef-owned plots only)
	use ``season_full'crops_2', clear
	merge m:1 hhid using `plot_ownmanage', gen(_mown) // beneficiary-owned plots
	merge m:1 hhid using `plotSizeList', gen(_msize) // all plots
	keep if _mown == 3 // keep only beneficiary owned/managed plots	
		
	
	** ------| D. Split list variables
	// D.1 split plot owners list
	split plot_ownermanager, parse(" ")
	drop plot_ownermanager  // drop old variable
	ds plot_ownermanager*
	foreach var in `r(varlist)' {
		destring `var', replace
	}
	
	// D.2 split plot sizes list
	gen plot_size_ = plot_sizelist
	split plot_size_, parse(" ")
	drop plot_size_
	ds plot_size_*
	foreach var in `r(varlist)' {
		destring `var', replace
	}

	// D.3 split and sort plot position list
	replace plot_no = " " + plot_no + " " 
	ds plot_size_*
	local n_plots : word count `r(varlist)'
	forval i = 1/`n_plots' {
		gen     plot_no_`i' = `i' if strpos(plot_no, " `i' ") > 0 
	}
	
	// assert owner, size, and position lists include all plots
	ds plot_ownermanager*
	local plot_own_max : word count `r(varlist)'
	ds plot_size_*
	local plot_size_max : word count `r(varlist)'
	ds plot_no_*
	local plot_no_max : word count `r(varlist)'
	
	// all must be equal
	assert `plot_own_max' == `plot_size_max'
	assert `plot_own_max' == `plot_no_max'
	assert `plot_no_max'  == `plot_size_max'
		
		
	** ------| E. Divide harvest evenly among owners/managers and proportionate to plot sizes		
	
	* E.1 prepare ratios to scale down harvest value by ownership and plot size
	// replace plot_ownmanager with . if plot doesn't exist
	ds plot_ownermanager*
	local vars `r(varlist)'
	local all : list sizeof vars
	forval i = 1/`all' {
		replace plot_ownermanager`i' = . if plot_no_`i' == .
		assert plot_ownermanager`i' == . if plot_no_`i' == .
		
		// take reciprocal to compute benficiary's share
		gen plot_own_ratio_`i' = 1/plot_ownermanager`i' 
		label var plot_own_ratio_`i' "Beneficiary ownership ratio for plot `i'"
	}
	egen crop_owner_count   = rownonmiss(plot_ownermanager*) // count no. of owners on that crop

	// replace plot_sizes with . if plot doesn't exist
	ds plot_size_*
	local vars `r(varlist)'
	local all : list sizeof vars
	forval i = 1/`all' {
		replace plot_size_`i' = . if plot_no_`i' == .
		assert plot_size_`i' == . if plot_no_`i' == .
	}

	// loop over plots again
	egen plot_tot_size = rowtotal(plot_size_*)			// total plot area on which crop is grown
	
	forval i = 1/`all' {
		// ratio of each plot's size to total size
		// ignores .m sizes
		gen plot_size_ratio_`i' = plot_size_`i' / plot_tot_size 
		assert plot_size_ratio_`i' <= 1 | missing(plot_size_ratio_`i')
	}

	// prepare aggregate ratio across all plots (within a crop/observation)
	// loop over plots once more
	forval i = 1/`all' {
		gen ben_share_`i' = plot_own_ratio_`i' * plot_size_ratio_`i'
		assert ben_share_`i' <= 1 | missing(ben_share_`i')
	}
	
	// logic test for ratios
	egen ben_share_crop = rowtotal(ben_share_*)
	label var ben_share_crop "Beneficiary's share of crop given plot size and ownership"
	replace ben_share_crop = 1 if ben_share_crop > 1 & ben_share_crop < 1.001
	assert ben_share_crop <= 1

	
	* E.2 adjust harvest value based on ownership
	// confirm calculation scales down not up before replacing actual harvest value
	// not using this scaled raw harvest value anywhere except to check calculation later
	// I used the same scaling below after outliers and problematic crops are removed 
	gen `s'crop_harv_ben = `s'crop_harv * ben_share_crop
	
	assert `s'crop_harv_ben <= `s'crop_harv  if !missing(`s'crop_harv_ben) /*	*/
	count if `s'crop_harv_ben == . & `s'crop_harv != . // 918 crops which the beneficiary owns none of
	
	// count no of HHs with no beneficiary owned crops with harvest values
	preserve
		byso hhid : egen tot_`s'crop_harv_ben = total(`s'crop_harv_ben)
		keep hhid tot_`s'crop_harv_ben 
		duplicates drop
		count if tot_`s'crop_harv_ben == 0 // 10 HHs where beneficiary owns no rain plots
	restore 

	keep hhid crop_pos ben_share_crop
	duplicates drop
	isid hhid crop_pos
	sort hhid crop_pos
	
	save "${intermediate_${phase}}/temp_agric_`s'_ben_shares", replace

end



********************************************************************************
*** PROGRAM: recode_crops 
********************************************************************************


capture prog drop recode_crops 
prog define recode_crops
		syntax, season(string) 

	if 		("`season'" == "r") local season_full rain
	else if ("`season'" == "d") local season_full dry

	
	use "${intermediate_${phase}}/`season_full'crops_2_long", clear
	
	merge m:1 hhid using "${constructed_${phase}}/identification.dta", keepus(hhid consent ${locations})
	drop _merge 
	drop if `season'crop_harv == .
	/***
	merge m:1 hhid using "${constructed_${phase}_${cty}}/temp_agric_outcomes_1", keepusing(ag_any ag_plot_n)
	drop _merge
	merge m:1 hhid using "${constructed_${phase}_${cty}}/temp_agric_outcomes_1b", keepusing(harv_all harv_rain)
	recode harv_rain (. =0 ) 
	recode harv_all (.=0)
	***/ 
	/***
	* drop _merge // some don't have crops 
	assert consent == 1

	order hhid consent ${locations} crop_pos ag_any ag_plot_n harv_all harv_rain, first
	sort hhid crop_pos 
	recode crop_pos (. = 0) // no crops 
	assert harv_rain == 0 if crop_pos == 0 
	****/ 

	replace `season_full'codeorother = trim(itrim(lower(`season_full'codeorother)))
	gen `season_full'codeorother_recode = `season_full'codeorother, after(`season_full'codeorother)

	*Recode missing - shouldnt have used these 
		replace `season'crop_harv = .d if `season'crop_harv == 888 
		replace `season'crop_harv = .r if `season'crop_harv == 999
		replace `season'crop_sold = .d if `season'crop_sold == 888
		replace `season'crop_sold = .r if `season'crop_sold == 999
		replace `season'crop_rev  = .d if `season'crop_rev == 888
		replace `season'crop_rev  = .r if `season'crop_rev == 999

	
	// `s'codeorother_recode at FU	
	
	if "$ph" == "bl" {
		if "`season_full'" == "rain" {	
			replace raincodeorother_recode = "1" if raincodeorother == "mil"	
			replace raincodeorother_recode = "4" if raincodeorother == "mais"	
			replace raincodeorother_recode = "8" if raincodeorother == "niebe"	
			replace raincodeorother_recode = "10" if raincodeorother == "arachide"	
			replace raincodeorother_recode = "10" if raincodeorother == "arachides"	
			replace raincodeorother_recode = "35" if raincodeorother == "courge"	
			replace raincodeorother_recode = "11" if raincodeorother == "gombo"	
			replace raincodeorother_recode = "37" if raincodeorother == "haricot"	
			replace raincodeorother_recode = "31" if raincodeorother == "jaxatu"	
			replace raincodeorother_recode = "25" if raincodeorother == "melon"	
			replace raincodeorother_recode = "20" if raincodeorother == "nana"	
			replace raincodeorother_recode = "5" if raincodeorother == "bisap"	
			replace raincodeorother_recode = "5" if raincodeorother == "bissab"	
			replace raincodeorother_recode = "5" if raincodeorother == "bissap"	
			replace raincodeorother_recode = "5" if raincodeorother == "feuilledebisabe"	
			// jan 2020	
			replace raincodeorother_recode = "31" if raincodeorother == "likwaz"	
			replace raincodeorother_recode = "31" if raincodeorother == "lekwaz"	
			replace raincodeorother_recode = "32" if raincodeorother == "jujube"	
			replace raincodeorother_recode = "other" if raincodeorother == "diakhtiene"	
			replace raincodeorother_recode = "other" if raincodeorother == "diayedje"	
		}	
		if  "`season_full'" == "dry" {	
			replace drycodeorother_recode = "10" if drycodeorother == "arachide"	
			replace drycodeorother_recode = "10" if drycodeorother == "arachides"	
			replace drycodeorother_recode = "30" if drycodeorother == "carrote"	
			replace drycodeorother_recode = "11" if drycodeorother == "gombo"	
			replace drycodeorother_recode = "20" if drycodeorother == "mente"	
			replace drycodeorother_recode = "20" if drycodeorother == "menthe"	
			replace drycodeorother_recode = "20" if drycodeorother == "nana"	
			replace drycodeorother_recode = "40" if drycodeorother == "nave"	
			replace drycodeorother_recode = "40" if drycodeorother == "navet"	
			replace drycodeorother_recode = "17" if drycodeorother == "poivron"	
			replace drycodeorother_recode = "27" if drycodeorother == "salade"	
			replace drycodeorother_recode = "other" if drycodeorother == "milforcer" // jan 2020	
		}		
	}
	else if "$ph" == "fu" {
			if "`season_full'" == "rain" {
				replace raincodeorother_recode = "other" if raincodeorother == "bissap"
				replace raincodeorother_recode = "other" if raincodeorother == "couge"
				replace raincodeorother_recode = "other" if raincodeorother == "gombo"
				replace raincodeorother_recode = "other" if raincodeorother == "goumbo"	
				replace raincodeorother_recode = "other" if raincodeorother == "kandje"
				replace raincodeorother_recode = "other" if raincodeorother == "lkoz"
				replace raincodeorother_recode = "other" if raincodeorother == "nbigue"	
				replace raincodeorother_recode = "other" if raincodeorother == "yomb"	
			}
	}

			
		


	// assert all items were recoded
	gen real = real(`season_full'codeorother_recode)
	replace real = 999 if `season_full'codeorother_recode == "other"
	*assert real != .
	drop real		
		
	** 2. Add unit labels `season'crop_harv_u
	order `season'crop_harv_u_o, after(`season'crop_harv_u)
	replace `season'crop_harv_u_o = trim(itrim(lower(`season'crop_harv_u_o)))
	label copy `season'crop_harv_u `season'crop_harv_u_extend

	// crop_harv_u_extend at BL
	
	if "$ph" == "bl" {
			#delimit;
			label define `season'crop_harv_u_extend
			11 "Moudes"
			, add;
			#delimit cr		
	}
	else if "$ph" == "fu" {
			#delimit;
			label define `season'crop_harv_u_extend
			11 "charette"
			12 "moud"
			13 "pièces"
			, replace;
			#delimit cr		
	}


		
	
	** 3. Recoding of units 
	gen `season'crop_harv_u_recode = `season'crop_harv_u, after(`season'crop_harv_u_o)
	label values `season'crop_harv_u_recode `season'crop_harv_u_extend

		if "$ph" == "bl" {
			if "`season'" == "r" { 
				** A. Already existing units

				** B. New units
				replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "moudes"

				** C. Convert quantities
				gen converted_harv = 0, after(rcrop_harv_u_recode)
				label variable converted_harv "rcrop_harv_u converted because rcrop_harv_u_recode uses convertible unit"

				gen converted_sold = 0, after(rcrop_sold)

			} 

			
			if  "`season'" == "d" { 
			// A. Already existing units
				// B. New units
				// C. Convert quantities
				gen converted_harv = 0
				gen converted_sold = 0

				// D. Set to missing if dcrop_harv_u_o = "Rien recolte"
				replace dcrop_harv = .m if dcrop_harv_u_o == "rien recolte"
				replace dcrop_sold = .m if dcrop_harv_u_o == "rien recolte"
				replace dcrop_rev = .m if dcrop_harv_u_o == "rien recolte"

				replace dcrop_harv = .m if dcrop_harv_u_o == "rien récolte"
				replace dcrop_sold = .m if dcrop_harv_u_o == "rien récolte"
				replace dcrop_rev = .m if dcrop_harv_u_o == "rien récolte"

			} 			
		}
		else if "$ph" == "fu" {
			if "`season'" == "r" {
				replace rcrop_harv_u_recode = 21  if rcrop_harv_u_o == "charette"
				replace rcrop_harv_u_recode = 21  if rcrop_harv_u_o == "moud"
				replace rcrop_harv_u_recode = 21  if rcrop_harv_u_o == "pièces"
			}
			if "`season'" == "d" {
			// 	replace dcrop_harv_u_recode = 21  if dcrop_harv_u_o == "plan"
			}			
		}
			
			
	// confirm all recoded successfully
	if "`season'" == "r" assert rcrop_harv_u_recode != . if rcrop_harv_u == .o 
	if "`season'" == "d" assert dcrop_harv_u_recode != . if dcrop_harv_u == .o
	
end 


********************************************************************************
*** PROGRAM: qty_outliers  
********************************************************************************


capture program drop qty_outliers 
program define qty_outliers 
	syntax, season(string)  factor(integer) 
		
		if "`season'" == "r" {
			local season_full rain
			}
			
		if "`season'" == "d" {
			local season_full dry
			}
	
	rename `season_full'* *
	rename `season'* * 
	capture confirm variable egion 
	if _rc== 0 {
		rename egion region
	}
	capture confirm variable epartment
	if _rc== 0 {
		rename epartment department
	}
		
	// harvest quantities 
	byso codeorother_recode crop_harv_u_recode : egen p75_harv = pctile(crop_harv) if !missing(crop_harv) , p(75)
	byso codeorother_recode crop_harv_u_recode : egen p25_harv = pctile(crop_harv) if !missing(crop_harv), p(25)
	byso codeorother_recode crop_harv_u_recode : egen iqr_harv = iqr(crop_harv) if !missing(crop_harv)

	gen outlier_harv = .
	replace outlier_harv = 1 if crop_harv > (p75_harv + (`factor'*iqr_harv)) & !missing(crop_harv)
	replace outlier_harv = 1 if crop_harv < (p25_harv - (`factor'*iqr_harv)) & !missing(crop_harv)


	// sold quantities 
	byso codeorother_recode crop_harv_u_recode : egen p75_sold = pctile(crop_sold) if !missing(crop_sold), p(75)
	byso codeorother_recode crop_harv_u_recode : egen p25_sold = pctile(crop_sold) if !missing(crop_sold), p(25)
	byso codeorother_recode crop_harv_u_recode : egen iqr_sold = iqr(crop_sold) if !missing(crop_sold)

	gen outlier_sold = .
	replace outlier_sold = 1 if crop_sold > (p75_sold + (`factor'*iqr_sold)) & !missing(crop_sold)
	replace outlier_sold = 1 if crop_sold < (p25_sold - (`factor'*iqr_sold)) & !missing(crop_sold)


end
 


********************************************************************************
*** PROGRAM: median_sale_price   
********************************************************************************


capture program drop median_sale_price 
program define median_sale_price 
	syntax, season(string) 
	preserve
		if "`season'" == "r" {
			local season_full rain
		}
			
		if "`season'" == "d" {
			local season_full dry
		}

		** Create median sale price
		gen sale_price = crop_rev / crop_sold

		** obtain median sale price at each localiy,  village, commune, department, region
		foreach type in $locations { 
			display "`type'"
			
			byso `type' codeorother_recode crop_harv_u_recode : egen mp_`type' = median(sale_price)
			label var mp_`type' "median sale price for this crop-unit at the `type'-level"
		}

		** overall median unit price
		byso codeorother_recode crop_harv_u_recode: egen mp_country = median(sale_price)
		label var mp_country "median price for this crop-unit"

		*** PRICE DATASET
		keep ${locations} mp_* codeorother_recode crop_harv_u_recode
		so ${locations} codeorother_recode crop_harv_u_recode
		duplicates drop

		ren mp* mp*_harv
		gen mp_country = mp_country_harv
		gen mp_p_village = mp_p_village_harv
		gen mp_p_region = mp_p_region_harv
		gen mp_p_canton = mp_p_canton_harv
		gen mp_p_sousprefecture = mp_p_sousprefecture_harv
		drop if mp_country_harv == . 
		gen country = 1 

		tempfile price_dataset_harv_`season'
		save 	`price_dataset_harv_`season''
	
	restore


	** merge on harvested crop and unit

	gen country = 1 
	foreach t in country $locations { 
		preserve
			use `price_dataset_harv_`season'', clear
			keep `t' codeorother_recode crop_harv_u_recode mp_`t'
			duplicates drop
			tempfile tempfile
			save `tempfile'
		restore
	
		merge m:1 codeorother_recode crop_harv_u_recode `t' using `tempfile', keepus(mp_`t')
		tab _merge
		drop if _merge == 2
		drop _merge
	}

end
 


********************************************************************************
*** PROGRAM: crop_importance   
********************************************************************************


capture program drop crop_importance 
program define crop_importance 
	syntax, season(string)

		if "`season'" == "r" {
			local season_full rain
		}
			
		if "`season'" == "d" {
			local season_full dry
		}

		** Imputed harvest values -- multiply harvest quantity and median sale price
		gen harvest_value_imp = .

		foreach t in $locations country { 
			display "`t'"
			replace harvest_value_imp = crop_harv * mp_`t' if missing(harvest_value_imp)
		}


		**set problem crops to missing while understanding importance of crops
		replace harvest_value_imp = .p if prob_crop != 0



		********************************************************************************
		* CROP  IMPORTANCE															   *
		********************************************************************************
		/*** if eat value is missing, if the crop is a minor crop (i.e. makes up less than 10% consum ption
		in 90% of households, we set harvest_value to zero. Otherwise, set harvest_value to missing ***/


		*** don't include households with problem foods in calculations
		byso hhid : egen has_prob = total(prob_crop)
		replace has_prob = 1 if has_prob >= 1 & !missing(has_prob)


		byso hhid : egen total_value = total(harvest_value_imp)
		gen share_within_hh = harvest_value_imp / total_value

		// major crop for household
		gen major_within_hh = (share_within_hh > 0.1)

		// don't include HHS with problematic foods in the calculation
		replace major_within_hh = . if has_prob == 1
		

		// count number of HHs without problem crops (no outliers, no missing prices)
		count if has_prob == 0  & tag_hhid == 1 
		local total `r(N)' 
		
		gen share_major = . 
		levelsof codeorother_recode, local(crops)
		foreach crop in `crops' {
			// Within each crop type, count number of HHs without problem crops & harvest values ^ 10%
			count if major_within_hh == 1 & has_prob == 0  & codeorother_recode == "`crop'"
			local count_major `r(N)' 
			// compute share HHs growing major crops by crop type
			replace share_major = `count_major' / `total' if codeorother_recode== "`crop'"
		} 
		label var share_major "Share of HHs for which this crop type is a major (non-problematic) crop"

		// create dummy for major crop types
		gen is_major = 0 
		replace is_major = 1 if share_major > .1 
		label var is_major "Dummy for major (non-problematic) crop type"

		

		** HH has a problem with a major crop
		gen major_prob = (prob_crop != 0 & is_major == 1) 
		label var major_prob "Crop level dummy for HH having a problem with crop that's a major crop for 90% of HHs"
		byso hhid  :egen has_major_prob = total(major_prob)
		replace has_major_prob = 1 if has_major_prob >= 1
		label var has_major_prob "Same dummy at HH level"

		gen minor_prob = (prob_crop != 0 & is_major == 0)
		label var minor_prob "Crop level dummy for HH having a problem with crop that's NOT a major crop for 90% of HHs"
		byso hhid  :egen has_minor_prob = total(minor_prob)
		replace has_minor_prob = 1 if has_minor_prob >= 1
		label var has_minor_prob "Same dummy at HH level"

		drop total_value

end 		
	

********************************************************************************
*** PROGRAM: make_totals   
********************************************************************************


capture program drop make_totals
program define make_totals 
syntax, season(name)

		if "`season'" == "r" {
			local s r
			local season_full rain
			}
			
		if "`season'" == "d" {
			local s d
			local season_full dry
			}

		capture rename `season'crop_harv 	crop_harv 
		capture rename `season'crop_rev 	crop_rev
		capture rename `season'crop_sold 	crop_sold

		*Adjustments: if major problem, later set to missing; if minor problem, set to 0s  here 

		drop harvest_value_imp // from above crop_importance 

		
		**** RECENT ADDITIONS: by MAIN CROPS AND CROP TYPES: 
		* creating crop types dummies
		if "$ph" == "fu" {
			* vegetable = 1
			gen crop_type = .
			replace crop_type = 1 if crop2name ==  "Tomate" | crop2name == "tomate" | crop2name == "tomates" | crop2name == "Oignon" | crop2name == "oignons" | crop2name ==  "oignon" | crop2name == "Gombo"  | crop2name == "gombo" | crop2name == "Aubergine" | crop2name == "hobergine"	| crop2name == "Pastèque" | crop2name == "melon" | crop2name == "comcombre"  | crop2name == "concombre" | crop2name == "Piment" | crop2name == "berebere" |  crop2name == "oseille" |  crop2name == "osielle"


			* tuber = 2
			replace crop_type = 2 if crop2name == "Manioc" | crop2name == "Igname/Taro" | crop2name == "Pâtate" | crop2name == "patates" 
			
			* pulse = 3 
			replace crop_type = 3 if crop2name == "Arachide" | crop2name == "Haricot"  | crop2name == "Haricot-vert" | crop2name == "Poids de terre"
			
			* cereal = 4 
			replace crop_type = 4 if crop2name == "Mil" | crop2name == "penicilere"   | crop2name == "penicillaire"  | crop2name == "penicillere"  |   crop2name == "Sorgho" | crop2name == "Maïs" | crop2name ==  "Riz" | crop2name == "Sésame"
			
			* cash = 5
			replace crop_type = 5 if crop2name == "Coton" | crop2name == "coton" |  crop2name == "Maraîchage" | crop2name == "canneasucre"
			
			label define crop_type 		///
						 1 "vegetable"	///
						 2 "tuber"		///
						 3 "pulse"		///
						 4 "cereal"		///
						 5 "cash"
			
			label values crop_type crop_type
			
			
			* cultivated crop TYPE dummy: 
			forvalues i = 1/5 {
			gen crop_type`i' = 0
			replace crop_type`i' = 1 if crop_type == `i'
			bysort hhid: egen crop_type`i'_d = max(crop_type`i')
			}
			
			* sold crop TYPE dummy
			forvalues i = 1/5 {
			gen  crop_type`i'_sold = 0
			replace  crop_type`i'_sold = 1 if crop_type == `i' & crop_sold != . & crop_sold > 0
			bysort hhid: egen crop_type`i'_sold_d = max( crop_type`i'_sold)
			}
			
			
			* cultivated crop dummy: 
			foreach crop in Sésame Arachide Mil Sorgho {
			gen `crop'_dummy = 0
			replace `crop'_dummy  = 1 if crop2name == "`crop'"
			bysort hhid: egen `crop'_d = max(`crop'_dummy)
			}
			
			
			* sold crop dummy
			foreach crop in Sésame Arachide Mil Sorgho {
			gen `crop'_sold = 0
			replace `crop'_sold = 1 if crop2name == "`crop'" & crop_sold != . & crop_sold > 0
			bysort hhid: egen `crop'_sold_d = max(`crop'_sold)
			}			
		}

		

		****************************************************************************
		** Approach 1: Imputed harvest values (quantity harvested * median price)
		
		** generating ag_*_hrv_xof_imp
		gen harvest_value_imp = .

		sort hhid crop_pos
		foreach t in $locations country { 
			display "`t'"
			replace harvest_value_imp = crop_harv * mp_`t' if missing(harvest_value_imp)
		}

		// replace harvest values based on dummies created above minor_prob major_prob
		replace harvest_value_imp = .p if (prob_crop != 0 & is_major == 0) // set to 0 if minor crop 
		replace harvest_value_imp = .m if (prob_crop != 0 & is_major == 1) // set to missing if major, and fix below
		replace harvest_value_imp = .l if harvest_value_imp == 0 // assume lost, shouldnt even have made it to this section

		
		// compute HH totals (we show the 98 p winsorization in our results)
		byso hhid : egen ag_`season'_hrv_xof_imp = total(harvest_value_imp ), m
		label variable ag_`season'_hrv_xof_imp "Harvest value using prices, `season_full' season" 
		replace ag_`season'_hrv_xof_imp = .m if has_major_prob == 1 

		// winsorize harvest and sale values within each recoded crop type
		if "$ph" == "bl" {
			sort hhid crop_pos	
			levelsof codeorother_recode, local (crop_type)
		}
		else if "$ph" == "fu"{
			sort hhid crop_type
			levelsof crop_type, local (crop_type)			
		}

		foreach p in 95 98 99 {
			gen harvest_value_imp_`p' = harvest_value_imp // prepare var to wins
			
			foreach type in `crop_type' {
				count if codeorother_recode == "`type'" & !missing(harvest_value_imp)
				if `r(N)' == 0 { // if there are no non-missing observations, do nothing
					dis "can't winsorize"
				}
				else if `r(N)' > 0 { // otherwise, winsorize
					_pctile harvest_value_imp_`p' if codeorother_recode == "`type'" & !missing(harvest_value_imp_`p') , p(`p')
					replace harvest_value_imp_`p' = `r(r1)' if codeorother_recode == "`type'" & ///
														   harvest_value_imp_`p' > `r(r1)' & ///
														   !missing(harvest_value_imp_`p') 
				}
			}
			
			// compute HH totals
			byso hhid : egen ag_`season'_hrv_xof_imp_`p' = total(harvest_value_imp_`p'), m
			label variable ag_`season'_hrv_xof_imp_`p' "Harvest value using prices, `season_full' season" 
			replace ag_`season'_hrv_xof_imp_`p' = .m if has_major_prob == 1 			
		    } 
		
			
			// calculate beneficiary's share of harvest value (98 p wins.)
			merge 1:1 hhid crop_pos using "${intermediate_${phase}}/temp_agric_`s'_ben_shares", gen(_mBenShares)
			drop if _mBenShares == 2 // drop 84 crops with beneficiary share but no harvest value
			
			
			foreach p in 95 98 99 {
			// scale imputed harvest value by plot and owner count
			gen harvest_value_ben_imp_`p' = harvest_value_imp_`p' * ben_share_crop // ignores non-beneficiary crops
			
			assert harvest_value_ben_imp_`p' <= harvest_value_imp_`p' if !missing(harvest_value_ben_imp_`p') /*	*/
			assert missing( harvest_value_ben_imp_`p') if missing(harvest_value_imp_`p')
			count if harvest_value_ben_imp_`p' == . & harvest_value_imp_`p' != .
			
			// compute HH totals for beneficiary plots
			byso hhid : egen ag_`s'_hrv_ben_xof_imp_`p' = total(harvest_value_ben_imp_`p'), m
			label variable ag_`s'_hrv_ben_xof_imp_`p' "Beneficiary harvest value using prices, `season_full' season (`p' p wins.)" 
			replace ag_`s'_hrv_ben_xof_imp_`p' = .m if has_major_prob == 1 
			
			}
		
		// compute number of crops within HH
		byso hhid : egen ag_`s'_hrv_n = count(harvest_value_imp)
			

			
		****************************************************************************
		** Approach 2: harvest values (1st: quantity harvested * unit   price where revenues are reported)
		**							  (2nd: quantity harvested * median price where revenues NOT reported)
		
		** generating ag_*_hrv_xof
		gen harvest_value = (crop_harv * crop_rev) / crop_sold
		
		sort hhid crop_pos
		foreach t in $locations country { 
			display "`t'"
			replace harvest_value = crop_harv * mp_`t' if missing(harvest_value)
		}

		replace harvest_value = .p if prob_crop != 0 & is_major == 0 // set to 0 if minor crop 
		replace harvest_value = .m if prob_crop != 0 & is_major == 1 // set to missing if major, and fix below
		replace harvest_value = .l if harvest_value == 0 // assume lost, shouldn't even have made it to this section
		
		if "$ph" == "fu" {
			foreach crop in Sésame Arachide Mil Sorgho {
				gen harvest_`crop' = harvest_value if crop2name == "`crop'"
				bysort hhid: egen harvest_value_`crop' = total(harvest_`crop'), m
				label var  harvest_value_`crop' "Harvest value `crop'"
				replace   harvest_value_`crop' = .m if has_major_prob == 1 
			}			
		}

		
		// compute hh totals
		byso hhid : egen ag_`season'_hrv_xof = total(harvest_value), m
		label var ag_`season'_hrv_xof "Harvest value (key plots) (reported) `season_full' season"
		replace   ag_`season'_hrv_xof = .m if has_major_prob == 1 

		// winsorize harvest and sale values with each recoded crop type
		sort hhid crop_pos
		levelsof codeorother_recode, local (crop_type)
		
		if "$ph" == "fu" merge 1:1 hhid crop_pos using "${intermediate_${phase}}/temp_agric_r_ben_shares.dta", gen(_mben)
		
		
		foreach p in 95 98 99 {
			gen harvest_value_`p' = harvest_value // prepare var to wins
			
			foreach type in `crop_type' {
				count if codeorother_recode == "`type'" & !missing(harvest_value)
				if `r(N)' == 0 { // if there are no non-missing observations, do nothing
					dis "can't winsorize"
				}
				else if `r(N)' > 0 { // otherwise, winsorize
					_pctile harvest_value_`p' if codeorother_recode == "`type'" & !missing(harvest_value_`p') , p(`p')
					replace harvest_value_`p' = `r(r1)' if codeorother_recode == "`type'" & ///
														   harvest_value_`p' > `r(r1)' & ///
														   !missing(harvest_value_`p') 
				}
			}
			
			// compute HH totals
			byso hhid : egen ag_`season'_hrv_xof_`p' = total(harvest_value_`p'), m
			label variable ag_`season'_hrv_xof_`p' "Harvest value using prices, `season_full' season" 
			replace ag_`season'_hrv_xof_`p' = .m if has_major_prob == 1 			
		

		
		// calculate beneficiary's share of harvest value
		if "$ph" == "bl" {
			gen harvest_value_ben_`p' = harvest_value_`p' * ben_share_crop
				
			assert harvest_value_ben_`p' <= harvest_value_`p' if !missing(harvest_value_ben_`p') /*	*/
			assert missing(harvest_value_ben_`p') if missing(harvest_value_`p')
			count if harvest_value_ben_`p' == . & harvest_value_`p' != .

				byso hhid : egen ag_`s'_hrv_ben_xof_`p' = total(harvest_value_ben_`p'), m
				label variable ag_`s'_hrv_ben_xof_`p' "Beneficiary harvest value (key plots) (reported) `season_full' season" 
				replace ag_`s'_hrv_ben_xof_`p' = .m if has_major_prob == 1 				
		}
		else if "$ph" == "fu" {
				gen harvest_value_ben_`p' = harvest_value_`p' * ben_share_crop
				
				assert harvest_value_ben_`p' <= harvest_value_`p' if !missing(harvest_value_ben_`p') /*	*/
				assert missing(harvest_value_ben_`p') if missing(harvest_value_`p')
				count if harvest_value_ben_`p' == . & harvest_value_`p' != .

				byso hhid : egen ag_`s'_hrv_ben_xof_`p' = total(harvest_value_ben_`p'), m
				label variable ag_`s'_hrv_ben_xof_`p' "Beneficiary harvest value (key plots) (reported) `season_full' season" 
				replace ag_`s'_hrv_ben_xof_`p' = .m if has_major_prob == 1 	
				
				
			foreach crop in Sésame Arachide Mil Sorgho {
			gen harvest_`crop'_`p' = harvest_value_`p' if crop2name == "`crop'"
			bysort hhid: egen harvest_value_`crop'_`p' = total(harvest_`crop'_`p'), m
			label var  harvest_value_`crop'_`p' "Harvest value `crop' _`p' wins"
			replace   harvest_value_`crop'_`p' = .m if has_major_prob == 1 
			
			
				// calculate beneficiary's share of harvest value
				gen harvest_ben_`crop'_`p' = harvest_`crop'_`p' * ben_share_crop
				assert harvest_ben_`crop'_`p' <= harvest_`crop'_`p' if !missing(harvest_ben_`crop'_`p') /*	*/
				assert missing(harvest_ben_`crop'_`p') if missing(harvest_`crop'_`p')
				count if harvest_ben_`crop'_`p' == . & harvest_`crop'_`p' != .

				byso hhid : egen harvest_ben_`crop'_xof_`p' = total(harvest_ben_`crop'_`p'), m
				label variable harvest_ben_`crop'_xof_`p' "Beneficiary harvest value `crop' at `p' wins." 
				replace harvest_ben_`crop'_xof_`p' = .m if has_major_prob == 1 	
			}			
		}

		
		/*			
		forvalues i = 1/5 {
		gen harvest_type`i'_`p' = harvest_value_`p' if crop_type == `i'
		bysort hhid: egen harvest_value_type`i'_`p' = total(harvest_type`i'_`p'), m
		label var harvest_value_type`i'_`p' "Harvest value `crop' _`p' wins"
		replace   harvest_value_type`i'_`p' = .m if has_major_prob == 1 
		
		
			// calculate beneficiary's share of harvest value
			gen harvest_ben_`i'_`p' = harvest_type`i'_`p' * ben_share_crop
			assert harvest_ben_`i'_`p' <= harvest_type`i'_`p' if !missing(harvest_ben_`i'_`p') /*	*/
			assert missing(harvest_ben_`i'_`p') if missing(harvest_type`i'_`p')
			count if harvest_ben_`i'_`p' == . & harvest_type`i'_`p' != .

			byso hhid : egen harvest_ben_`i'_xof_`p' = total(harvest_ben_`i'_`p'), m
			label variable harvest_ben_`i'_xof_`p' "Beneficiary harvest value crop type `i' at `p' wins." 
			replace harvest_ben_`i'_xof_`p' = .m if has_major_prob == 1 	
		}
		*/ 
		
				
		}
			
		****************************************************************************
		** crop harvest value, for diversification measure (approach 1 only)
		if "$ph" == "bl" {
			sort hhid crop_pos	
			levelsof crop_pos, local(crop_no)
		}
		else if "$ph" == "fu" {
			sort hhid crop_type
			levelsof crop_type, local(crop_no)			
		}

		foreach cno in `crop_no' {
			// Imputed only 
			if "$ph" == "bl" gen t_ag_hrv_`cno'_imp_xof = harvest_value_imp_98 if crop_pos == `cno'
			if "$ph" == "fu" gen t_ag_hrv_`cno'_imp_xof = harvest_value_98 if crop_type == `cno'
			recode t_ag_hrv_`cno'_imp_xof (. = -999)
			bysort hhid (t_ag_hrv_`cno'_imp_xof) : gen  ag_`season'_hrv_`cno'_imp_xof = t_ag_hrv_`cno'_imp_xof[_N] 
			drop t_ag_hrv_`cno'_imp_xof
			
			label var ag_`season'_hrv_`cno'_imp_xof "Crop `cno' imputed harvest value, `season_full' season (98 p wins.)"
			recode ag_`season'_hrv_`cno'_imp_xof (-999 = 0)
		}
		
		** crop harvest value (crop level)
		if "$ph" == "bl" {
			sort hhid crop_pos	
			levelsof codeorother_recode, local(crop_types)
		}
		else if "$ph" == "fu" {
			sort hhid crop_type
			levelsof crop_type, local(crop_types)
		}
		foreach ctype in `crop_types' {
			dis "`ctype'"
			if "$ph" == "bl" gen c_ag_`ctype'_imp_xof = harvest_value_imp_98 if codeorother_recode == "`ctype'"
			if "$ph" == "fu" gen c_ag_`ctype'_imp_xof = harvest_value_98 if crop_type == `ctype'
			recode c_ag_`ctype'_imp_xof (. = -999)
			bysort hhid (c_ag_`ctype'_imp_xof) : gen ag_`season'_c`ctype'_imp_xof = c_ag_`ctype'_imp_xof[_N] 
			drop c_ag_`ctype'_imp_xof
			
			label var ag_`season'_c`ctype'_imp_xof "Crop `ctype' imputed harvest value, `season_full' season (98 p wins.)"
			recode ag_`season'_c`ctype'_imp_xof (-999 = 0)
		}
		
		
		
		****************************************************************************
		** crop sale value
		
		
		// drop problematic sales and revenues
		foreach var in crop_rev crop_sold {
			replace `var' = .p if prob_crop != 0 & is_major == 0 // set to 0 if minor crop 
			replace `var' = .m if prob_crop != 0 & is_major == 1 // set to missing if major, and fix below
		}


		** Approach 1: ag_r_sale_imp_xof (using median prices)
		sort hhid crop_pos
		gen harvest_sales_imp = . 
	
		foreach t in $locations country { 
			display "`t'"
			replace harvest_sales_imp = mp_`t' * crop_sold if missing(harvest_sales_imp)
		}
		
		
		// calculate hh totals
		byso hhid : egen ag_`season'_sale_imp_xof = total(harvest_sales_imp), m
		label var ag_`season'_sale_imp_xof "Total sale value, imputed (key plots), `season_full' season" 	

		
		** Approach 2: ag_*_sale_xof (using reported revenues)
		byso hhid : egen ag_`season'_sale_xof = total(crop_rev), m
		label var ag_`season'_sale_xof "Total sale value, reported (key plots), `season_full' season" // wtf check: checked. Used same method as harvest_value
		
		// winsorize
		if "$ph" == "bl" sort hhid crop_pos 
		if "$ph" == "fu" sort hhid crop_type
		levelsof codeorother_recode, local (crop_type)
		foreach p in 95 98 99 {
			gen harvest_sales_imp_`p' = harvest_sales_imp // prepare var to wins
			
			foreach type in `crop_type' {
				count if codeorother_recode == "`type'" & !missing(harvest_sales_imp)
				if `r(N)' == 0 { // if there are no non-missing observations, do nothing
					dis "can't winsorize"
				}
				else if `r(N)' > 0 { // otherwise, winsorize
					_pctile harvest_sales_imp_`p' if codeorother_recode == "`type'" & !missing(harvest_sales_imp_`p') , p(`p')
					replace harvest_sales_imp_`p' = `r(r1)' if codeorother_recode == "`type'" & ///
														   harvest_sales_imp_`p' > `r(r1)' & ///
														   !missing(harvest_sales_imp_`p') 
				}
			}
			
			
			
			// compute HH totals
			byso hhid : egen ag_`season'_sale_imp_xof_`p' = total(harvest_sales_imp_`p'), m
			label variable ag_`season'_sale_imp_xof_`p' "Total sale value, imputed wins. at `p'p(key plots), `season_full' season"  
			replace ag_`season'_sale_imp_xof_`p' = .m if has_major_prob == 1 			
		
		if "$ph" == "fu" {
			foreach crop in Sésame Arachide Mil Sorgho {
				gen harvest_sales_imp_`crop'_`p' = harvest_sales_imp_`p' if crop2name == "`crop'"
				byso hhid : egen sale_`crop'_imp_xof_`p' = total(harvest_sales_imp_`crop'_`p'), m
				replace sale_`crop'_imp_xof_`p' = .m if has_major_prob == 1 			
			}
			
			forvalues i = 1/5 {
				gen harvest_sales_imp_`i'_`p' = harvest_sales_imp_`p' if crop_type == `i'
				byso hhid : egen sale_`i'_imp_xof_`p' = total(harvest_sales_imp_`i'_`p'), m
				replace sale_`i'_imp_xof_`p' = .m if has_major_prob == 1 			
			}			
		}

		
		}
		
end 




*******/ 


********************************************************************************
********************************************************************************
********************************************************************************




********************************************************************************
*** PUT IT ALL TOGETHER 
********************************************************************************


*** Define problem crop types - to be determined if major or minor

#delimit ;
label define prob_crop
1 "undefined harvest quantity - don't know, refused"
2 "very unlikely, impossible harvest quantity"
3 "unlikely, impossible sold quantity"
4 "undefined harvest unit" 
5 "unconvertible harvest unit";
#delimit cr







******************
if "$ph" == "bl" local extra d
foreach s in r `extra' { 
					
					
					// 0. create tempfile `ben_shares'		
					scale_ben_share, season(`s')



					recode_crops, season(`s') 
						** A. some manual issues 


				
						gen prob_crop = 0
						

						replace `s'crop_harv = .r if `s'crop_harv == 888
						replace `s'crop_sold = .r if `s'crop_sold == 888
						replace `s'crop_rev  = .r if `s'crop_rev == 888

						replace prob_crop = 1 if missing(`s'crop_harv) & `s'crop_harv != .
	
			
						** B. assert harvest quantity >= sold quantity, which wasnt required in some surveys 
						*assert rcrop_harv >= rcrop_sold if !missing(rcrop_sold), rc0

						replace prob_crop = 2 if `s'crop_harv < `s'crop_sold & !missing(`s'crop_sold)  // unnlikely harvest quantity 
						
						replace prob_crop = 4 if missing(`s'crop_harv_u_recode) & `s'crop_harv_u_recode != .

		
					******************
				  
					qty_outliers, season(`s') factor(10) 

						** set as prob_crop = 3 if outlier sold quantity
						replace prob_crop = 3 if outlier_sold == 1 // unlikely sold quantity 
						** set as prob_crop = 2 if outlier harvested quantity
						replace prob_crop = 2 if outlier_harv == 1 // unlikely harvest quantity 

				******************

					median_sale_price, season(`s') 
					
					
			
					
						replace prob_crop = 5 if mp_country == . & !missing(crop_harv) // no price for this harvest unit/crop combination  
						// prob_crop == 1 DNE in the data yet


						// prob_crop and has_prob_ are defined at crop level 
						// while has_prob is dummy for prob_crop at HH level
						levelsof prob_crop, local(levels)
						foreach level in `levels' {
							gen has_prob_`level' = (prob_crop == `level')
						}
						// replaced this with tab, gen because that command doesn't see that there is no "1" in prob_crop
						capture confirm var has_prob_0
						if (_rc == 0) drop has_prob_0

						
						egen tag_hhid = tag(hhid) 
					
					******************
					crop_importance, season(`s') // excludes households with problem crops

					******************
				 
				
					
					
					make_totals, season(`s')
					

					
			*-------------------------------*
			*--- Parenthesis: CROP TYPES ---*
			*-------------------------------*	
			
		if "$ph" == "fu"{
			preserve
			 ** parenthesis BY CROP 
			 
			  keep hhid Sésame_d Arachide_d Mil_d Sorgho_d Sésame_sold_d Arachide_sold_d Mil_sold_d Sorgho_sold_d ///
				harvest_value_Sésame_98 harvest_value_Arachide_98 harvest_value_Mil_98 harvest_value_Sorgho_98 ///
				harvest_ben_Sésame_xof_98 harvest_ben_Arachide_xof_98 harvest_ben_Mil_xof_98 harvest_ben_Sorgho_xof_98 ///
				sale_Sésame_imp_xof_98 sale_Arachide_imp_xof_98 sale_Mil_imp_xof_98 sale_Sorgho_imp_xof_98 
				
				duplicates drop
				
				
				foreach v in harvest_value_Sésame_98 harvest_value_Arachide_98 harvest_value_Mil_98 harvest_value_Sorgho_98 ///
				harvest_ben_Sésame_xof_98 harvest_ben_Arachide_xof_98 harvest_ben_Mil_xof_98 harvest_ben_Sorgho_xof_98 ///
				sale_Sésame_imp_xof_98 sale_Arachide_imp_xof_98 sale_Mil_imp_xof_98 sale_Sorgho_imp_xof_98 {
				replace `v' = `v'/1000
				replace `v' = 0 if `v' == .
				}
				
				
				drop if Sésame_d == .
				isid hhid
				tempfile chad_crops
				save `chad_crops'
				
				
				use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear
				keep hhid
				
				merge 1:1 hhid using `chad_crops', gen(m1)
				drop m1
			
				foreach v in Sésame_d Arachide_d Mil_d Sorgho_d Sésame_sold_d Arachide_sold_d Mil_sold_d Sorgho_sold_d harvest_value_Sésame_98 harvest_ben_Sésame_xof_98 harvest_value_Arachide_98 harvest_ben_Arachide_xof_98 harvest_value_Mil_98 harvest_ben_Mil_xof_98 harvest_value_Sorgho_98 harvest_ben_Sorgho_xof_98 sale_Sésame_imp_xof_98 sale_Arachide_imp_xof_98 sale_Mil_imp_xof_98 sale_Sorgho_imp_xof_98 {
				replace `v' = 0 if `v' == .
				}
			
			tempfile chad_crops1
			save `chad_crops1'
			
			restore 

			
			preserve
			  keep hhid crop_type1_d crop_type2_d crop_type3_d crop_type4_d crop_type5_d 												///
				   crop_type1_sold_d crop_type2_sold_d crop_type3_sold_d crop_type4_sold_d crop_type5_sold_d 							///
				   ag_r_hrv_1_imp_xof ag_r_hrv_2_imp_xof ag_r_hrv_3_imp_xof ag_r_hrv_4_imp_xof ag_r_hrv_5_imp_xof	///
				   sale_1_imp_xof_98 sale_2_imp_xof_98 sale_3_imp_xof_98 sale_4_imp_xof_98 sale_5_imp_xof_98
				   
				   
				  duplicates drop
				  drop if crop_type1_d == .
				  
				  isid hhid
				  
				  foreach v in  ag_r_hrv_1_imp_xof ag_r_hrv_2_imp_xof ag_r_hrv_3_imp_xof ag_r_hrv_4_imp_xof ag_r_hrv_5_imp_xof sale_1_imp_xof_98 sale_2_imp_xof_98 sale_3_imp_xof_98 sale_4_imp_xof_98 sale_5_imp_xof_98 {
				replace `v' = `v'/1000
				replace `v' = 0 if `v' == .
				}
				
				isid hhid
				tempfile chad_crop_types
				save `chad_crop_types'
				
				
				use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear
				keep hhid
				
				merge 1:1 hhid using `chad_crop_types', gen(m2)
				drop m2
				
				foreach v in crop_type1_d crop_type2_d crop_type3_d crop_type4_d crop_type5_d crop_type1_sold_d crop_type2_sold_d crop_type3_sold_d crop_type4_sold_d crop_type5_sold_d ag_r_hrv_1_imp_xof ag_r_hrv_2_imp_xof ag_r_hrv_3_imp_xof ag_r_hrv_4_imp_xof ag_r_hrv_5_imp_xof sale_1_imp_xof_98 sale_2_imp_xof_98 sale_3_imp_xof_98 sale_4_imp_xof_98 sale_5_imp_xof_98 {
		
				replace `v' = 0 if `v' == . 
				}
				
			
				merge 1:1 hhid using `chad_crops1', gen(_m)
				
				
				save "${constructed_${phase}}/chad_crops.dta", replace
				
				
				restore 			
		}

			*-------------------------------*
			*------ End of Parenthesis -----*
			*-------------------------------*	
					

					local seeds 
					
					if "`s'" == "r" { // rainy season only 
					/** ag_r_seeds_d **/
							
							// raincrops_2_long.dta (other input vars, inp*, are in `main'.dta)
							byso hhid : egen ag_r_seeds_d = max(crop_seedbot) // crop_seedbot: dummy for seed purchase
							label var ag_r_seeds_d "purchased seeds"
							local seeds ag_r_seeds_d 

							// we don't have purchased value of seeds
					} 
					
					
					
					** ag_*_comm
					gen ag_`s'_comm = ag_`s'_sale_imp_xof_98 / ag_`s'_hrv_xof_imp_98
					replace ag_`s'_comm = 1 if ag_`s'_comm > 1 & ag_`s'_comm !=. 
					label var ag_`s'_comm "Commericialisation % of crops (key plots), `s' season "

					
					** generate extensive margins by crop type for hh shares table
					ds ag_`s'_c*_imp_xof
					foreach var in `r(varlist)' {
						gen `var'_tp = (`var' > 0 & !missing(`var')) // crop level dummy 
						byso hhid codeorother_recode : egen `var'_d = max(`var'_tp) // hh level dummy
						drop `var'_tp
					}

					rename ag_`s'_c*_imp_xof_d ag_`s'_c*_d
					

					keep hhid ag_`s'_hrv_xof_imp ///
							  ag_`s'_hrv_xof_imp_9? ///
							  ag_`s'_hrv_ben_xof_imp_9? ///
							  ag_`s'_hrv_xof ///
							  ag_`s'_hrv_xof_9? ///
							  ag_`s'_hrv_ben_xof_9? ///
							  ag_`s'_hrv_*_imp_xof /// crop no.
							  ag_`s'_*_imp_xof /// crop type
							  ag_`s'_sale_xof ///
							  ag_`s'_sale_imp_xof ///
							  ag_`s'_sale_imp_xof_9? ///
							  ag_`s'_comm `seeds' ///
							  ag_`s'_c*_d // dummy vars (ext. mgns.)

					 duplicates drop 
					 
					 if "$ph" == "fu" {
						 duplicates tag hhid, gen(dup)
						 drop if ag_r_hrv_xof_imp == . & dup == 1
						 drop dup				 	
					 }

					 isid hhid  

					 tempfile `s'_value
					 save ``s'_value', replace 
					 
				

} 

use `r_value', clear 
if "$ph" == "bl" merge 1:1 hhid using `d_value', gen(_mseason) 


// diverge to extract beneficiary and hh-head ownership of plots
preserve

	use "${intermediate_${phase}}/temp_agric_r_ben_owns", clear
	
	if "$ph" == "bl" {
		merge 1:1 hhid using "${intermediate_${phase}}/temp_agric_d_ben_owns"	
		gen ben_owns_d   = (r_ben_ownman_d == 1   | d_ben_ownman_d == 1)	
		gen cnotb_owns_d = (r_cnotb_ownman_d == 1 | d_cnotb_ownman_d == 1)		
	}
	else if "$ph" == "fu" {
		gen ben_owns_d   = (r_ben_ownman_d == 1)
		gen cnotb_owns_d = (r_cnotb_ownman_d == 1)		
	}

	keep hhid ben_owns_d cnotb_owns_d
	isid hhid
	
	tempfile temp_agric_ben_owns
	save 	`temp_agric_ben_owns'

restore


merge 1:1 hhid using `temp_agric_ben_owns', gen (_mbenowns)
drop if _mbenowns == 2 
drop _mbenowns


merge 1:1 hhid using "${intermediate_${phase}}/temp_agric_cropstatuses"

if "$ph" == "bl" 	assert ag_d_harv == 0 if _merge == 2 
					assert ag_r_harv == 0 if _merge == 2 



*********************************************************************************
**** assign 0 harvests : missing from only one season or no harvests at all 
if "$ph" == "bl" {
	foreach var of varlist ag_r_hrv_xof_imp - ag_r_sale_imp_xof ag_d_hrv_xof_imp - ag_d_sale_imp_xof ///	
																	ag_?_hrv_xof_imp_9? ag_?_hrv_xof_9? {	
		replace `var' = 0 if `var' == . // not m, which are missing bc can't compute	
	}
}	
else if "$ph" == "fu" {
	foreach var of varlist ag_r_hrv_xof_imp - ag_r_sale_imp_xof ag_?_hrv_xof_imp_9? ag_?_hrv_xof_9? { 
		replace `var' = 0 if `var' == . // not m, which are missing bc can't compute
	} 	
}	
	


if "$ph" == "bl" {
	assert ag_d_hrv_xof_imp == 0 if ag_d_harv == 0	
	assert ag_d_hrv_xof_imp_95 == 0 if ag_d_harv == 0
}	
assert ag_r_hrv_xof_imp == 0 if ag_r_harv == 0
assert ag_r_hrv_xof_imp_95 == 0 if ag_r_harv == 0


*** deal later 
*** said harvested, but 0 reported, assumed lost, so  must fix crop statuses 
if "$ph" == "bl" local extra d
foreach s in r `extra'  { 
		
		gen had_lost_wrongplace_`s' = 0 
		gen had_big_prob_`s' = 0 
		gen had_min_prob_`s' = 0 
		gen had_harv_`s' = 0 
		
		ds ag_`s'_hrv_*_imp_xof 
		local count : word count(`r(varlist)') 
		forvalues i = 1/`count' { 	
			display "here `count'" 
			 * lost counted in wrong place  
			replace had_lost_wrongplace_`s' = 1 if ag_`s'_hrv_`i'_imp_xof == .l 
			replace had_big_prob_`s' = 1 		if ag_`s'_hrv_`i'_imp_xof == .m 
			replace had_min_prob_`s' = 1 		if ag_`s'_hrv_`i'_imp_xof == .p	
			replace had_harv_`s' = 1 			if ag_`s'_hrv_`i'_imp_xof == .m | ///
												   ag_`s'_hrv_`i'_imp_xof == .p | ///
												  (ag_`s'_hrv_`i'_imp_xof > 0 & ag_`s'_hrv_`i'_imp_xof != .l)
		}
	} 


replace ag_r_lost = 1 if had_lost_wrongplace_r == 1
replace ag_r_harv = 0 if had_harv_r == 0 
replace ag_r_sold = 0 if had_harv_r == 0 // if not harvested, then also not sold
drop had_harv_r 

if "$ph" == "bl" {
	replace ag_d_lost = 1 if had_lost_wrongplace_d == 1	
	replace ag_d_harv = 0 if had_harv_d == 0	
	replace ag_d_sold = 0 if had_harv_d == 0 // if not harvested, then also not sold	
	drop had_harv_d
}

					assert ag_r_hrv_xof_imp != 0 if ag_r_harv == 1 & had_min_prob_r != 1 
if "$ph" == "bl" 	assert ag_d_hrv_xof_imp != 0 if ag_d_harv == 1 & had_min_prob_d != 1 
************************ number of harvested crops 

gen div_rain_n = 0 
label variable div_rain_n "number of rain crops harvested" // includes minor and major problems

ds ag_r_hrv_*_imp_xof
local count : word count(`r(varlist)') 
forvalues i = 1/`count' { 	
	replace div_rain_n = div_rain_n + 1 if ag_r_hrv_`i'_imp_xof > 0 & (ag_r_hrv_`i'_imp_xof != . & ag_r_hrv_`i'_imp_xof != .l)
} 

if "$ph" == "bl" {
	gen div_dry_n = 0	
	label variable div_dry_n "number of dry crops harvested"	
	ds ag_d_hrv_*_imp_xof	
	local count : word count(`r(varlist)')	
	forvalues i = 1/`count' {	
		replace div_dry_n = div_dry_n + 1 if ag_d_hrv_`i'_imp_xof > 0 & (ag_d_hrv_`i'_imp_xof != . & ag_d_hrv_`i'_imp_xof != .l )	
	}
}

gen div_ag_n = 0 
if "$ph" == "bl" replace div_ag_n = div_dry_n + div_rain_n
if "$ph" == "fu" replace div_ag_n = div_rain_n 
label variable div_ag_n  "Total crop types harvested (key plots), 12 months" 



save "${intermediate_${phase}}/temp_agric_valueandstatus", replace




