	***************************************************************************
	*																		  *
	*		    		TRANSFERS CLEANING CHAD ASP IE 			  			  *
	*																		  *
	***************************************************************************
	
    /*			
	** PURPOSE: 	Cleaning transfers data
    */

	if "$ph" == "bl" {
		** Merge chef/beneficiary roster position with programs dataset	
		use 		"${intermediate_${phase}}/members_long", clear	
		byso 		hhid : egen has_chef = total(is_chef)	
		replace 	is_chef = 1 if has_chef == 0 & p_relation == 1	
		gen 		chef_pos = mem_pos if is_chef == 1	
		gen 		benef_pos = mem_pos if is_benef == 1	
		keep 		hhid chef_pos benef_pos	
		so 			hhid chef_pos	
		by 			hhid : carryforward chef_pos, replace	
		so 			hhid benef_pos	
		by 			hhid : carryforward benef_pos, replace	
		duplicates  drop	
		merge 1:m 	hhid using "${intermediate_${phase}}/transfers_long"	
		drop 		_merge	
		tostring 	chef_pos, replace	
		tostring 	benef_pos, replace	
		gen 		same_cb = (chef_pos == benef_pos)	
		foreach var in chef_pos benef_pos {	
			replace `var' = " " + `var' + " "	
		}
	}
	else if "$ph" == "fu" {
		use "${constructed_${phase}}/demographics", clear
		keep hhid chef_pos benef_pos same_cb
		merge 1:m hhid using "${intermediate_${phase}}/transfers_long"
		drop _merge 
		tostring chef_pos, replace
		tostring benef_pos, replace		
	}


	********************************************************************************
	**** Secondary B.6.5 Gross inter-household transfers 
	***** --------------| IN 
	
	*** convert remmitance amount (trans_amt) to yearly amount
	gen trans_in_xof = trans_amt
	// replace trans_in_xof = 0 if trans_amt == .
	fix_continuous trans_in_xof 

	// annual remittance for frequencies less than one year
	replace trans_in_xof = trans_in_xof * 12 if trans_freq == 1 // monthly 
	replace trans_in_xof = trans_in_xof * 4 if trans_freq == 2 // trimester
	replace trans_in_xof = trans_in_xof * 2 if trans_freq == 3 // semester 
	replace trans_in_xof = trans_in_xof * 1 if trans_freq == 4 // yearly
	replace trans_in_xof = trans_in_xof * 2 if trans_freq == 5 // irregular, assume 2x year
	

	** remit_12_xof
	if "$ph" == "bl" {
		** remit_12_xof
		
		// winsorize at 1st/99th percentile
		_pctile trans_in_xof , p(98)
		gen trans_in_xof_w = trans_in_xof 
		replace trans_in_xof_w  = `r(r1)' if !missing(trans_in_xof_w ) & trans_in_xof_w  > `r(r1)'
		
		// hh totals
		byso hhid : egen tot_trans_in_xof = total(trans_in_xof_w) // missings automatically go to zero
		replace tot_trans_in_xof = tot_trans_in_xof / 1000
		label var tot_trans_in_xof "Remittances received in last 12 months wins. (1000 FCFA)"
		
		// dummy for whether household received transfer: 
		gen 	trans_in_dum = 0 
		replace trans_in_dum = 1 if tot_trans_in_xof > 0
		
		bysort hhid: egen trans_in_d = max(trans_in_dum)
	
		keep 		hhid tot_trans_in_xof trans_in_d
		duplicates  drop
		isid hhid 
	}
	else if "$ph" == "fu" {
		// winsorize at 1st/99th percentile
		_pctile trans_in_xof , p(98)
		gen trans_in_xof_w = trans_in_xof 
		replace trans_in_xof_w  = `r(r1)' if !missing(trans_in_xof_w ) & trans_in_xof_w  > `r(r1)'

		// hh totals
		byso hhid : egen tot_trans_in_xof = total(trans_in_xof_w) // missings automatically go to zero
		replace tot_trans_in_xof = tot_trans_in_xof / 1000
		label var tot_trans_in_xof "Remittances received in last 12 months wins. (1000 FCFA)"

		// dummy for whether household received transfer: 
		gen 	trans_in_d = 0 
		replace trans_in_d = 1 if tot_trans_in_xof > 0
		
		// dummies for whether hh  received transfer from within the village:
		bysort hhid : egen trans_invill_d = total(trans_invill)
		replace trans_invill_d = 1 if trans_invill_d > 0
		
		// amount received from within-village transfers:
		gen trans_invill_xof = trans_in_xof_w if trans_invill_d == 1
		replace trans_invill_xof = 0 if trans_invill_xof == . 
		bysort hhid : egen tot_trans_invill_xof = total(trans_invill_xof)
		replace tot_trans_invill_xof = tot_trans_invill_xof / 1000
		label var tot_trans_invill_xof "Within-Village Remittances received in last 12 months wins. (1000 FCFA)"

		// transfer received by beneficiary(ies) 	
		replace trans_who = " " + trans_who + " "
		replace benef_pos = " " + benef_pos + " "
		gen ben_in_recipient = strpos(trans_who, benef_pos) > 0 & trans_who != "  " & benef_pos != "  "
		replace ben_in_recipient = 0 if ben_in_recipient == .
			
		* creating dummy
		bysort hhid : egen trans_in_ben_d = total(ben_in_recipient)
		replace trans_in_ben_d = 1 if trans_in_ben_d > 0
			
		// beneficiry totals
		gen trans_in_ben_xof_w = trans_in_xof_w if ben_in_recipient == 1
		byso hhid: egen tot_trans_in_ben_xof = total(trans_in_ben_xof_w)
		replace tot_trans_in_ben_xof = tot_trans_in_ben_xof / 1000
		label var tot_trans_in_ben_xof "Remittances received by beneficiary in last 12 months wins. (1000 FCFA)"

		* creating dummy: ben received transfer within village 
		gen ben_invill_recipient = 0
		replace ben_invill_recipient  = 1 if ben_in_recipient == 1 & trans_invill == 1
		
		bysort hhid : egen trans_invill_ben_d = total(ben_invill_recipient)
		replace trans_invill_ben_d = 1 if trans_invill_ben_d > 0
		
		* within-village transfer amount received by beneficiaries 
		gen trans_invill_ben_xof = trans_in_xof_w if ben_invill_recipient == 1
		replace trans_invill_ben_xof = 0 if trans_invill_ben_xof == . 
		bysort hhid : egen tot_trans_invill_ben_xof = total(trans_invill_ben_xof)
		replace tot_trans_invill_ben_xof = tot_trans_invill_ben_xof / 1000
		label var tot_trans_invill_ben_xof "Within-Village Remittances received by Benef. in last 12 months wins. (1000 FCFA)"
	
		keep hhid trans_in_d tot_trans_in_xof tot_trans_in_ben_xof trans_invill_d tot_trans_invill_xof ///
			 trans_in_ben_d tot_trans_in_ben_xof trans_invill_ben_d tot_trans_invill_ben_xof			

		duplicates drop
		isid hhid 
		tempfile trans_in
		save 	`trans_in'
	}

***** --------------| OUT 

// transfers_sent_long.dta not at BL
if "$ph" == "fu" {
	** transfers out

	use "${constructed_${phase}}/demographics", clear
	keep hhid chef_pos benef_pos same_cb
	merge 1:m hhid using "${intermediate_${phase}}/transfers_sent_long"
	assert _merge == 3
	drop _merge 
	tostring chef_pos, replace
	tostring benef_pos, replace

	gen trans_out_xof = trans_amt_send 
	// scale for currency if currency var exists. Var seems to be misnamed
	capture confirm var trans_amt_cur
	if _rc == 0 { // if currency var exists 
		scale_cur trans_out_xof trans_amt_cur 
	}

	replace trans_out_xof = trans_out_xof*12 if trans_freq_send ==  1  // month 
	replace trans_out_xof = trans_out_xof*4  if trans_freq_send ==  2  // trimestre 
	replace trans_out_xof = trans_out_xof*2  if trans_freq_send ==  3  // semestre 
	replace trans_out_xof = trans_out_xof*1  if trans_freq_send ==  4  // année
	replace trans_out_xof = trans_out_xof*2  if trans_freq_send ==  5  // irrégulier , assume 2x year 
	
	// winsorize at 2nd/98th percentile
	_pctile trans_out_xof , p(98)
	gen trans_out_xof_w = trans_out_xof 
	dis "`r(r1)'"
	replace trans_out_xof_w  = `r(r1)' if !missing(trans_out_xof_w ) & trans_out_xof_w  > `r(r1)'

	// compute hh total
	bysort hhid : egen tot_trans_out_xof =  total(trans_out_xof_w)
	replace tot_trans_out_xof = tot_trans_out_xof / 1000
	label var tot_trans_out_xof "Remittances sent out in last 12 months wins. (1000 FCFA)"

	// dummies for whether transfer was sent: bysort hhid : egen trans_out_d = 
	gen  trans_out_d = tot_trans_out_xof > 0
	
	// dummies for whether hh transfer was sent to benef in the village
	bysort hhid : egen trans_outvill_d = total(trans_send_invill)
	replace trans_outvill_d = 1 if trans_outvill_d > 0
	
	// amount transfered to beneficiaries in village 
	gen trans_outvill_xof = trans_out_xof_w if trans_outvill_d == 1
	replace trans_outvill_xof = 0 if trans_outvill_xof == . 
	bysort hhid : egen tot_trans_outvill_xof = total(trans_outvill_xof)
	replace tot_trans_outvill_xof = tot_trans_outvill_xof / 1000
	label var tot_trans_outvill_xof "Within-Village Remittances sent out in last 12 months wins. (1000 FCFA)"

	// dummies for whether beneficiary sent transfer
	replace trans_who_send = " " + trans_who_send + " "
	replace benef_pos = " " + benef_pos + " "
	gen ben_out_sender = strpos(trans_who_send, benef_pos) > 0 & trans_who_send != "  " & benef_pos != "  "
	replace ben_out_sender = 0 if ben_out_sender == .
	
	* creating dummy
	bysort hhid : egen trans_out_ben_d = total(ben_out_sender)
	replace trans_out_ben_d = 1 if trans_out_ben_d > 0
	
	// transfer amount sent by benef: 
	gen trans_out_ben_xof = trans_out_xof_w if ben_out_sender == 1
	replace trans_out_ben_xof = 0 if trans_out_ben_xof == . 
	bysort hhid : egen tot_trans_out_ben_xof = total(trans_out_ben_xof)
	replace tot_trans_out_ben_xof = tot_trans_out_ben_xof / 1000
	label var tot_trans_out_ben_xof "Remittances sent out by Benef. in last 12 months wins. (1000 FCFA)"

	* creating dummy: ben send transfer within village 
	gen ben_outvill_sender = 0
	replace ben_outvill_sender  = 1 if ben_out_sender == 1 & trans_send_invill == 1
	
	bysort hhid : egen trans_outvill_ben_d = total(ben_outvill_sender)
	replace trans_outvill_ben_d = 1 if trans_outvill_ben_d > 0
	
	* within-village transfer amount sent by beneficiaries 
	gen trans_outvill_ben_xof = trans_out_xof_w if ben_outvill_sender == 1
	replace trans_outvill_ben_xof = 0 if trans_outvill_ben_xof == . 
	bysort hhid : egen tot_trans_outvill_ben_xof = total(trans_outvill_ben_xof)
	replace tot_trans_outvill_ben_xof = tot_trans_outvill_ben_xof / 1000
	label var tot_trans_outvill_ben_xof "Within-Village Remittances sent out by Benef. in last 12 months wins. (1000 FCFA)"

	keep hhid trans_out_d tot_trans_out_xof trans_outvill_d tot_trans_outvill_xof ///
			  trans_out_ben_d tot_trans_out_ben_xof trans_outvill_ben_d tot_trans_outvill_ben_xof 
			  
	duplicates drop 
	compress 
	tempfile trans_out
	save 	`trans_out'
}
	
if "$ph" == "fu" {	
	use `trans_out'
	merge 1:1 hhid using `trans_in', gen(_m_transin)
	
	// compute gross transfers
	egen gross_trans_xof = rsum(tot_trans_in_xof tot_trans_out_xof)
	label var gross_trans_xof "B.6.5 sum of remittances going in and out, winsorized separately (1000 FCFA)"

	
	// whether hh recieved any transfer
	local trans_dummies trans_fam trans_fam_send
	merge 1:1 hhid using "${intermediate_${phase}}/chad_main_2021.dta", ///
		keepusing(`trans_dummies' consent) // trans_fam_send not available everywhere

	drop if consent != 1
	drop consent _merge

	label variable trans_fam        "hh received private money"
	capture label variable trans_fam_send   "hh sent private money"
}

	** saving dataset
	compress
	save "${constructed_${phase}}/transfers", replace
