	***************************************************************************
	*																		  *
	*			  		LABOR PARTICIPATION CHAD ASP IE 				      *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning labor participation (time spent on activities) data
					from FU survey
    */



********************************************************************************
* D3 Beneficiary Labor Participation										   *
********************************************************************************

***----------| D.3.1 Beneficiary days spent in household business
//sum of days across businesses, top coded at 30 

use "${intermediate_${phase}}/business_long", clear
merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos chef_pos) 

if "$ph" == "bl" {
		rename bus2_own2 bus2_own	
	rename __key__ bus_pos	
	keep hhid  chef_pos benef_pos bus2_own  bus2_workers actdays*	
	order hhid chef_pos benef_pos bus2_own  bus2_workers actdays*	
	gen all_workers = bus2_own + " " + " " + bus2_workers, after(bus2_workers)
}
else if "$ph" == "fu" {
	keep hhid  chef_pos benef_pos bus2_own bus2_manage bus2_workers actdays*
	order hhid chef_pos benef_pos bus2_own bus2_manage bus2_workers actdays* 

	gen all_workers = bus2_own + " " + bus2_manage + " " + bus2_workers, after(bus2_workers)
}

// count number of owners/managers for each business
gen uniq_workers = all_workers, after(all_workers)
gen ben_worker = "", after(uniq_workers) 
gen chef_worker = "", after(uniq_workers) 

forval i = 1/`=_N' { 
 	local all
	local all  `"`=all_workers[`i']'"' // collect all workers
	local uniq_all : list uniq all     // collect unique ones only
// 	dis "`i': `all' --> `uniq_all'"	  
	qui replace uniq_workers = "`uniq_all'" in `i' // replace uniq ones in each obs

	local ben_i `"`=benef_pos[`i']'"'  // list benef in HH
	local chef_i `"`=chef_pos[`i']'"'  // list benef in HH
// 	dis "`i': `benef_pos'"				
	local working_benef : list ben_i & uniq_all // collect overlap between workers and benef in HH
	local working_chef : list chef_i & uniq_all // collect overlap between workers and benef in HH
// 	dis "`i': `working_benef'"
	qui replace ben_worker = "`working_benef'" in `i'
	qui replace chef_worker = "`working_chef'" in `i'
}
replace ben_worker = " " + ben_worker + " " // need spaces to properly identify i in strpos
replace chef_worker = " " + chef_worker + " " // need spaces to properly identify i in strpos

if "$ph" == "bl" drop bus2_own bus2_workers all_workers
if "$ph" == "fu" drop bus2_own bus2_manage bus2_workers all_workers

ds actdays_mem*
local act_vars `r(varlist)'
local mems_n : word count `act_vars'

// calculate for everyone
forval i = 1/`mems_n' {
	qui byso hhid : egen tot_mm`i'_bus_days = total(actdays_mem`i')
	qui replace tot_mm`i'_bus_days = 30 if tot_mm`i'_bus_days > 30 // cap at 30 to avoid overcounting businesses	
	label var tot_mm`i'_bus_days "Days spent by hh mem `i' in any business in last 30 days"
}

// calcalate for benef and chef
foreach mem in chef ben{
	gen `mem'_days = ., after(`mem'_worker)

	forval i = 1/`mems_n' {
		qui replace `mem'_days  = actdays_mem`i' if strpos(`mem'_worker,  " `i' ") > 0
	}
	label var `mem'_days  "Days spent by `mem' in given business in last 30 days"
	// capped at 30 because individual entries capped at 30
	
	qui byso hhid : egen tot_`mem'_bus_days = total(`mem'_days)
	qui replace tot_`mem'_bus_days = 30 if tot_`mem'_bus_days > 30 // cap at 30 to avoid overcounting businesses
	label var tot_`mem'_bus_days "D.3.1 Days spent by `mem' in any business in last 30 days"
	// note chef and benef can be the same person
} 

ds tot_mm*
egen tot_hh_bus_days = rowtotal(`r(varlist)')
label var tot_hh_bus_days "D.3.1 Days spent by entire hh in given business in last 30 days"
// individual contributions capped at 30

gen tot_hhlb_bus_days = tot_hh_bus_days - tot_ben_bus_days
assert tot_hhlb_bus_days >= 0
label var tot_hhlb_bus_days "D.3.1 Days spent by non-benef hh members in any business in last 30 days"

gen tot_bohh_bus_days = tot_ben_bus_days / tot_hh_bus_days 
assert inrange(tot_bohh_bus_days , 0, 1) | tot_bohh_bus_days == .
label var tot_bohh_bus_days "D.3.1 Share of days spent by benef in any household business in last 30 days"

keep hhid tot_*_bus_days
drop tot_mm*
duplicates drop 
isid hhid
tempfile d_3_1
save 	`d_3_1'


*** ----------| D.3.4 Beneficiary days spent in agriculture

use "${intermediate_${phase}}/main_plotlist_long", clear
merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos chef_pos) nogen
tostring benef_pos, replace	
tostring chef_pos, replace	
sort hhid plot_pos

// add leading + trailing space
ds plot_man plot_owner plot_worked
foreach var in `r(varlist)' {
	replace `var' = trim(itrim(`var'))
	replace `var' = " "+`var'+" "
}

// benef and chef shares of land
gen plot_ownmanage = plot_man + plot_owner
gen uniq_ownman = ""
gen n_ownman_plot = 0 
forval i = 1/`=_N' { 
	local all
	local all  `"`=plot_ownmanage[`i']'"'
	local unique_ownman : list uniq all
	replace uniq_ownman = "`unique_ownman'" in `i'
	replace n_ownman_plot = `: list sizeof unique_ownman' in `i'
}

// generate ownership dummies
replace uniq_ownman = " " + uniq_ownman + " "
gen benef_is_plotownman = .
replace benef_is_plotownman = strpos(uniq_ownman, benef_pos) > 0
gen chef_is_plotownman = .
replace chef_is_plotownman  = strpos(uniq_ownman, chef_pos) > 0

keep  hhid benef_pos chef_pos plot_man plot_owner plot_worked days_mem* benef_is_plotownman chef_is_plotownman
order hhid benef_pos chef_pos plot_man plot_owner plot_worked days_mem* benef_is_plotownman chef_is_plotownman

gen all_workers = plot_owner + " " + plot_man + " " + plot_worked, after(plot_worked)

// count number of owners/managers for each business
gen uniq_workers = all_workers, after(all_workers)
gen ben_worker = "", after(uniq_workers) 
gen chef_worker = "", after(uniq_workers) 
										  
forval i = 1/`=_N' { 
 	local all
	local all  `"`=all_workers[`i']'"' // collect all workers
	local uniq_all : list uniq all     // collect unique ones only
// 	dis "`i': `all' --> `uniq_all'"	  
	qui replace uniq_workers = "`uniq_all'" in `i' // replace uniq ones in each obs

	local ben_i `"`=benef_pos[`i']'"'  // collect benef in HH
	local chef_i `"`=chef_pos[`i']'"'  // collect chef in HH
// 	dis "`i': `benef_pos'"				
	local working_benef : list ben_i & uniq_all // collect overlap between workers and benef in HH
// 	dis "`i': `chef_pos'"	
	local working_chef : list chef_i & uniq_all // collect overlap between workers and benef in HH
// 	dis "`i': `working_benef'"
	qui replace ben_worker = "`working_benef'" in `i'
// 	dis "`i': `working_chef'"
	qui replace chef_worker = "`working_chef'" in `i'
}
replace ben_worker = " " + ben_worker + " " // need spaces to properly identify i in strpos
replace chef_worker = " " + chef_worker + " " // need spaces to properly identify i in strpos

drop plot_man plot_owner plot_worked all_workers

gen ben_days = ., after(ben_worker)
label var ben_days "Days spent by beneficiary on plot in last 30 days"

gen chef_days = ., after(ben_worker)
label var chef_days "Days spent by hh head on plot in last 30 days"

gen ben_days_omben = ., after(ben_worker)
label var ben_days_omben "Days spent by beneficiary on plot owned by him"

gen chef_days_omchef = ., after(ben_worker)
label var chef_days_omchef "Days spent by hh head on plot in owned by him"

ds days_mem*
local mems_n : word count `r(varlist)'
forval i = 1/`mems_n' {
		// ben - all plots 
		qui replace ben_days = days_mem`i' if strpos(ben_worker, " `i' ") > 0	
		
		// ben - ben plots 
		qui replace ben_days_omben = days_mem`i' if strpos(ben_worker, " `i' ") > 0 & benef_is_plotownman == 1 
		
		// chef - all plots
		qui replace chef_days = days_mem`i' if strpos(chef_worker, " `i' ") > 0
		
		// chef - chef plots 
		qui replace chef_days_omchef = days_mem`i' if strpos(chef_worker, " `i' ") > 0 & chef_is_plotownman == 1
		
		// everyone - all plots 
		qui byso hhid : egen tot_mm`i'_ag_days = total(days_mem`i')
		qui replace tot_mm`i'_ag_days = 120 if tot_mm`i'_ag_days > 120 // cap at 120 to avoid overcounting plots
		label var tot_mm`i'_ag_days "D.3.4 Days spent by  hh mem `i'  on agriculture in last season"	
		
		// everyone - ben plots
		qui gen mm`i'_days_omben  = days_mem`i' if benef_is_plotownman == 1
		qui byso hhid : egen tot_mm`i'_ag_days_omben = total(mm`i'_days_omben)
		qui replace tot_mm`i'_ag_days_omben = 120 if tot_mm`i'_ag_days_omben > 120 // cap at 120 to avoid overcounting plots
		label var tot_mm`i'_ag_days_omben "D.3.4 Days spent by  hh mem `i'  on plots owned by ben in last season"			
		
		// everyone - chef plots
		qui gen mm`i'_days_omchef = days_mem`i' if chef_is_plotownman == 1
		qui byso hhid : egen tot_mm`i'_ag_days_omchef = total(mm`i'_days_omchef)
		qui replace tot_mm`i'_ag_days_omchef = 120 if tot_mm`i'_ag_days_omchef > 120 // cap at 120 to avoid overcounting plots
		label var tot_mm`i'_ag_days_omchef "D.3.4 Days spent by  hh mem `i'  on plots owned by chef in last season"			
} 

// hh total - all plots
ds tot_mm*_ag_days
egen tot_hh_ag_days = rowtotal(`r(varlist)')
label var tot_hh_ag_days "D.3.4 Days spent by entire hh on agriculture in last season"

// hh total - ben plots
ds tot_mm*_ag_days_omben
egen tot_hh_ag_days_omben = rowtotal(`r(varlist)')
label var tot_hh_ag_days_omben "D.3.4 Days spent by entire hh on plots owned by ben in last season"

// hh total - chef plots
ds tot_mm*_ag_days_omchef
egen tot_hh_ag_days_omchef = rowtotal(`r(varlist)')
label var tot_hh_ag_days_omchef "D.3.4 Days spent by entire hh on plots owned by chef in last season"

// ben total - all plots
byso hhid : egen tot_ben_ag_days = total(ben_days)
replace tot_ben_ag_days = 120 if tot_ben_ag_days > 120
label var tot_ben_ag_days "D.3.4 Days spent by beneficiary on agriculture in last season"

// ben total - ben plots
byso hhid : egen tot_ben_ag_days_omben = total(ben_days_omben)
replace tot_ben_ag_days_omben = 120 if tot_ben_ag_days_omben > 120
label var tot_ben_ag_days_omben "D.3.4 Days spent by beneficiary on plots owned by ben in last season"

// ben total -> all plots - ben plots
gen tot_ben_nom_ag_days = tot_ben_ag_days - tot_ben_ag_days_omben

// chef total - all plots
byso hhid : egen tot_chef_ag_days = total(chef_days)
replace tot_chef_ag_days = 120 if tot_chef_ag_days > 120
label var tot_chef_ag_days "D.3.4 Days spent by hh head on agriculture in last season"

// chef total - chef plots
byso hhid : egen tot_chef_ag_days_omchef = total(chef_days_omchef)
replace tot_chef_ag_days_omchef = 120 if tot_chef_ag_days_omchef > 120
label var tot_chef_ag_days_omchef "D.3.4 Days spent by chefeficiary on plots owned by chef in last season"

// ben total -> all plots - ben plots
gen tot_chef_nom_ag_days = tot_chef_ag_days - tot_chef_ag_days_omchef

// hhlb - all plots
gen tot_hhlb_ag_days = tot_hh_ag_days - tot_ben_ag_days
assert tot_hhlb_ag_days >= 0
label var tot_hhlb_ag_days "D.3.1 Days spent by non-benef hh members on agriculture in last season"

// hhlb - ben plots
gen tot_hhlb_ag_days_omben = tot_hh_ag_days_omben - tot_ben_ag_days_omben
assert tot_hhlb_ag_days_omben >= 0
label var tot_hhlb_ag_days_omben "D.3.1 Days spent by non-benef hh members on plots owned by ben in last season"

// hhlc - all plots
gen tot_hhlc_ag_days = tot_hh_ag_days - tot_chef_ag_days
assert tot_hhlc_ag_days >= 0
label var tot_hhlc_ag_days "D.3.1 Days spent by non-chef hh members on agriculture in last season"

// hhlc - chef plots
gen tot_hhlc_ag_days_omchef = tot_hh_ag_days_omchef - tot_chef_ag_days_omchef
assert tot_hhlc_ag_days_omchef >= 0
label var tot_hhlc_ag_days_omchef "D.3.1 Days spent by non-chef hh members on plots owned by chef in last season"

// bohh - all plots
gen tot_bohh_ag_days = tot_ben_ag_days / tot_hh_ag_days 
assert inrange(tot_bohh_ag_days, 0, 1) | tot_bohh_ag_days == .
label var tot_bohh_ag_days "D.3.1 Share of days spent by benef in any on agricultural plot in last season"

keep hhid tot_*_ag_days tot_*_ag_days_omben tot_*_ag_days_omchef
duplicates drop 
isid hhid
tempfile d_3_2
save 	`d_3_2'


*** ----------| D.3.3 Days in last month of paid employment (Beneficiary and chef)

use "${intermediate_${phase}}/salary_long.dta", clear
drop if empl_type == .
// compute monthly average using yearly info for benef
if "$ph" == "bl" {
	gen days_per_year_ben = empl_days * empl_wks * empl_mos if key2 == 1 // max at 336 days	
	drop if key2 == 2
}
else if "$ph" == "fu" {
	gen days_per_year_ben = empl_days * empl_wks * empl_mos // max at 336 days
}
assert days_per_year_ben <= 365

gen days_per_mon_ben = days_per_year_ben / 12 // max 28 days
assert days_per_mon_ben <= 30

keep hhid empl_pos days_per_mon_ben 
reshape wide days_per_mon_ben, j(empl_pos) i(hhid)
isid hhid

preserve
	if "$ph" == "bl" {
		use "${intermediate_${phase}}/salary_long.dta", clear
		
		// compute monthly average using yearly info for chef
		gen days_per_year_chef = empl_days * empl_wks * empl_mos if key2 == 2 // max at 336 days
		drop if key2 == 1
		assert days_per_year_chef <= 365
		gen days_per_mon_chef = days_per_year_chef / 12 // max 28 days
		keep hhid empl_pos days_per_mon_chef
		reshape wide days_per_mon_chef , j(empl_pos) i(hhid)
	}
	else if "$ph" == "fu" {
		use "${intermediate_${phase}}/salary_long_chef.dta", clear
		rename key2 empl_pos_chef
		drop if empl_type_chef == .
		
		// compute monthly average using yearly info for chef
		gen days_per_year_chef = empl_days_chef * empl_wks_chef * empl_mos_chef // max at 336 days
		assert days_per_year_chef <= 365
		gen days_per_mon_chef = days_per_year_chef / 12 // max 28 days
		keep hhid empl_pos_chef days_per_mon_chef
		reshape wide days_per_mon_chef , j(empl_pos_chef) i(hhid)		
	}
	tempfile chef
	save 	`chef'
restore

merge 1:1 hhid using `chef', gen(_mchefsal)
merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos chef_pos)

keep if _merge == 3
sort _mchefsal
gen same = benef_pos == chef_pos
sort same _mchefsal hhid

foreach var of varlist days_per_mon_chef* { 
	// drop chef days if benef == chef & days exist for both
	replace `var' = . if same == 1 & _mchefsal == 3
}

drop _mchefsal _merge same *_pos
rename days_per_mon_ben* days*_1  // ben as 1
rename days_per_mon_chef* days*_2 // chef as 2

foreach pos in 1 2 { // for each of ben and chef
	preserve
		keep hhid days*_`pos'
		rename days*_`pos' days*
		// reshape --> hhid, status, days
		reshape long days, i(hhid) j(bus_pos)
		tempfile bus`pos'
		save 	`bus`pos''
	restore
}

use `bus1', clear
append using `bus2', gen(pos)
sort hhid pos bus_pos
label define pos 0 "benef" 1 "chef"
label values pos pos

// ben + chef = entire hh
byso hhid : egen tot_benchef_emp_days = total(days)
label var tot_benchef_emp_days "D.3.3 Days in last month of paid employment (Beneficiary and chef)"

// ben only
gen days_ben = days if pos == 0 // benef only
byso hhid : egen tot_ben_emp_days = total(days_ben)
label var tot_ben_emp_days "D.3.3 Days in last month of paid employment (Beneficiary only)"

// chef only
gen days_chef = days if pos == 1 // benef only
byso hhid : egen tot_chef_emp_days = total(days_chef)
label var tot_chef_emp_days "D.3.3 Days in last month of paid employment (HH Head only)"

// hhlb
gen tot_hhlb_emp_days = tot_benchef_emp_days - tot_ben_emp_days
assert tot_hhlb_emp_days >= 0
label var tot_hhlb_emp_days "D.3.3 Days in last month of paid employment (non-benef hh members only)"

// bohh
gen tot_bohh_emp_days = tot_ben_emp_days / tot_benchef_emp_days 
assert inrange(tot_bohh_emp_days, 0, 1) | tot_bohh_emp_days == .
label var tot_bohh_emp_days "D.3.3 Share of days spent by benef in last month of paid employment"

keep hhid tot_*_emp_days
duplicates drop
isid hhid
tempfile d_3_3
save 	`d_3_3'


*** ----------| D.3.2 Beneficiary days spent on livestock (only exsists at FU)
if "$ph" == "fu" {
	use "${intermediate_${phase}}/livestock_mem_wrk_long", clear
	order liv_mm_pos, after(hhid)
	sort hhid liv_mm_pos

	merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos chef_pos)
	// identify beneficiaries
	gen is_ben = 1 if benef_pos == liv_mm_pos 
	
	// identify chef 
	gen is_chef = 1 if chef_pos == liv_mm_pos

	// excluding chef who are also beneficiaries
	replace is_chef = 0 if chef_pos == benef_pos
	drop benef_pos liv_mm_pos

	rename betail_heures liv_mins // averages number of mins per day
	rename betail_jours  liv_days // average number of days per month
	rename betail_mois   liv_months // number of months in the last year

	gen liv_hours 	  = liv_mins / 60
	replace liv_days = (liv_days*liv_months)/12 // average number of days per year
	
	gen liv_hours_ben = liv_mins / 60 if is_ben == 1
	gen liv_days_ben  = liv_days if is_ben == 1
	
	gen liv_hours_chef = liv_mins / 60 if is_chef == 1
	gen liv_days_chef  = liv_days if is_chef == 1
	
	foreach time in hours days {
		// everyone
		byso hhid : egen tot_hh_liv_`time' = total(liv_`time')
		label var tot_hh_liv_`time' "D.3.2 Daily average no. of `time' spent working with livestock in last year"
		
		// beneficiary only
		byso hhid : egen tot_ben_liv_`time' = total(liv_`time'_ben)
		label var tot_ben_liv_`time' "D.3.2 Daily average no. of `time' BENEF spent working with livestock in last year"		
		// chef only
		byso hhid : egen tot_chef_liv_`time' = total(liv_`time'_chef)
		label var tot_chef_liv_`time' "D.3.2 Daily average no. of `time' HH HEAD spent working with livestock in last year"
	}
	
	// hhlb
	gen tot_hhlb_liv_days = tot_hh_liv_days - tot_ben_liv_days
	assert tot_hhlb_liv_days >= 0
	label var tot_hhlb_liv_days "D.3.1 Days spent by non-benef hh members on agriculture in last season"

	// bohh
	gen tot_bohh_liv_days = tot_ben_liv_days / tot_hh_liv_days 
	assert inrange(tot_bohh_liv_days, 0, 1) | tot_bohh_liv_days == .
	label var tot_bohh_liv_days "D.3.1 Share of days spent by benef in any on agricultural plot in last season"
		
	keep hhid tot_*_liv_days
	duplicates drop // zero obs dropped. 3,200 HHs FU1, 2,771 HHs FU2
	
	tempfile d_3_4
	save 	`d_3_4'
}


*** ----------| conclude
use hhid using "${constructed_${phase}}/demographics.dta", clear
					merge 1:1 hhid using `d_3_1', gen(_mben_lab1)
					merge 1:1 hhid using `d_3_2', gen(_mben_lab2)
					merge 1:1 hhid using `d_3_3', gen(_mben_lab3)
if "$ph" == "fu"	merge 1:1 hhid using `d_3_4', gen(_mben_lab4)

// because every HH has a beneficiary and a chef
foreach var of varlist tot_*_emp_days {
	capture confirm var `var'
	if _rc == 0 { // if var exists
		replace `var' = 0 if missing(`var') // make unconditional like totbus and totag
	}
}

drop _mben_lab*
compress
save "${constructed_${phase}}/labor_participation.dta", replace
