	***************************************************************************
	*																		  *
	*		   		 WOMEN EMPOWERMENT CLEANING CHAD ASP IE 				  *
	*																		  *
	***************************************************************************
	
    /*		
	** PURPOSE: 	Cleaning women empowerment data from follow-up survey
    */

********************************************************************************
* WOMEN'S EMPOWERMENT														   *
********************************************************************************

use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear
drop if consent != 1
	
// bring in treatment status to condition indexes on control group stats
merge 1:1 hhid using "${constructed_${phase}}/identification.dta", ///
		gen(_mtreat) keepusing(pm_treatment)

if "$ph" == "bl" {
	// temporary measure	
	merge 1:1 hhid using "${constructed_${phase}}/demographics.dta", ///	
	gen(_mdem) keepusing(benef_pos)	
	capture rename resp_ben_relations resp_relation // SEN at FU	
	gen same_rb = resp_relation == benef_pos	
	// bring in mariage status and relation to HH head	
	rename benef_pos mem_pos	
	merge 1:1 hhid mem_pos using "${intermediate_${phase}}/members_long.dta", ///	
	gen(_mrel) keepusing(marital relation)	
	keep if _mrel == 3
}

	
********************************************************************************
**** Decision weight index
* Z-score index of 10 components

label define dec_pow 1 "Does not matter at all" 2 "Matters a little" 3 "Matters a lot", modify
label values dec_pow* dec_pow 

// collect variables of interest
if "$ph" == "bl" {
		local decision_weight_vars 	dec_pow_earn 	/// 1	
									dec_pow_spend   /// 3	
									dec_pow_large  	/// 4	
									dec_pow_fert  	/// 5	
									dec_pow_edu 	/// 7	
									dec_pow_ag  	/// 8	
									dec_pow_liv 	/// 9	
									dec_pow_bus 	// 10
}
else if "$ph" == "fu" {
		local decision_weight_vars dec_pow_earn 	 /// 1
								   dec_pow_his_earn  /// 2
								   dec_pow_spend   	 /// 3
								   dec_pow_large     /// 4
								   dec_pow_fert  	 /// 5
								   dec_pow_care 	 /// 6
								   dec_pow_edu 	 	 /// 7
								   dec_pow_ag  	 	 /// 8
								   dec_pow_liv 	 	 /// 9
								   dec_pow_bus 	 	 // 10
}

{
* Approach 1
// compute z-score for 10 components
zindex `decision_weight_vars', gen(dec_weight_index) condition(pm_treatment == 0) 
if "$ph" == "bl" label variable dec_weight_index "Dcsn wght Z-index (8 vars)"
if "$ph" == "fu" label variable dec_weight_index "Dcsn wght Z-index (10 vars)"
}


********************************************************************************
****  decision possibility index 
* Z-score index of 5 components

// collect variables of interest
if "$ph" == "bl" {
local decision_poss_vars dec_could_earn    	/// 1
						 dec_could_spend  	/// 2
						 dec_could_large 	/// 3
						 dec_could_fert 	// 4
}
else if "$ph" == "fu" {
	local decision_poss_vars dec_could_earn /// 1
						 dec_could_spend  	/// 2
						 dec_could_large 	/// 3
						 dec_could_fert 	/// 4
						 dec_could_care 	// 5
}

foreach var in `decision_poss_vars' {
	recode `var' (0=1)(1=2)(2=3)
}
label define dec_could 1 "Not at all" 2 "A little" 3 " Completely", modify
label values dec_could* dec_could

// compute z-score for 10 components
zindex `decision_poss_vars', gen(dec_psblty_index) condition(pm_treatment == 0) 
label variable dec_psblty_index "Decision Possibility Z-index"

keep  hhid dec_weight_index dec_psblty_index `decision_poss_vars' `decision_weight_vars' 
tempfile 10_1and2
save    `10_1and2', replace


********************************************************************************
**** Relationship Quality 
* Z-score index of 3 components

********************************************************************************
	* Factor z-score index of 6 components

	*  Household has not prevented from working outside the home 
	use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear 
	drop if consent == 0
	merge 1:1 hhid using "${constructed_${phase}}/identification.dta", ///
		gen(_mtreat) keepusing(pm_treatment)
			
	if "$ph" == "bl" {
		capture confirm var free_work  // DNE at FU	
		if _rc == 0 {	
			// temporary measure	
			merge 1:1 hhid using "${constructed_${phase}}/demographics.dta", ///	
			gen(_mdem) keepusing(benef_pos)	
			drop if benef_pos == . // removing absent beneficiaries for now although responses exist for someone else in the HH	
			qui count if benef_pos != .	
			assert `r(N)' == _N // assert all HHs have benefs	
		}
	}	
	
	// note that free_work == 1 when beneficiary is not free to work... need reverse
	keep hhid free_work pm_treatment
	**	emp_work
	gen 	emp_work = (free_work - 1)
	replace emp_work = abs(emp_work)
	label var	emp_work	"B.10.3 (1) HH has not prevented from working outside the home"
	drop free_work
	tempfile 10_3_1
	save    `10_3_1', replace
		
	local prod_agency_vars emp_work // 8.06 from main dataset
		
	*  Beneficiary controls any revenue from sale of a crop (rcrop_controlrev dcrop_controlrev)
	use "${intermediate_${phase}}/raincrops_1_long.dta", clear //rain crops
	sort hhid
	order hhid rcrop_controlrev
	keep hhid rcrop_controlrev

	merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos) gen(_mergBEN)
	drop if _mergBEN == 2
	drop _mergBEN 
		
	// temporary measure
	drop if benef_pos == . // removing absent beneficiaries for now although responses exist for someone else in the HH
	qui count if benef_pos != .
	assert `r(N)' == _N // assert all HHs have benefs

	order benef_pos, after (hhid)
	tostring benef_pos, replace
	replace benef_pos = " " + benef_pos + " "
	replace rcrop_controlrev = " " + rcrop_controlrev + " "

	// create dummy variable for each rain crop if beneficiary controls revenue
	gen rcrop_ctrl_dum = strpos(rcrop_controlrev, benef_pos) > 0
	byso hhid : egen rcrop_ctrl_dum_hh = max(rcrop_ctrl_dum)
	drop rcrop_ctrl_dum
	rename rcrop_ctrl_dum_hh rcrop_ctrl_dum
		
	keep hhid rcrop_ctrl_dum 
	duplicates drop // 407 hh == 1 at BL
	tempfile 10_3_2rain
	save    `10_3_2rain', replace

	if "$ph" == "bl" {
			** drycrops	
		use "${intermediate_${phase}}/drycrops_1_long.dta", clear	
		sort hhid	
		order hhid dcrop_controlrev	
		keep hhid dcrop_controlrev plot_no crop_no	
		merge m:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos) gen(_mergBEN)	
		drop if _mergBEN == 2	
		drop _mergBEN	
		order benef_pos, after (hhid)	
		tostring benef_pos, replace	
		replace benef_pos = " " + benef_pos + " "	
		replace dcrop_controlrev = " " + dcrop_controlrev + " "	
		// create dummy variable for each rain crop if beneficiary controls revenue	
		gen dcrop_ctrl_dum = strpos(dcrop_controlrev, benef_pos) > 0	
		byso hhid : egen dcrop_ctrl_dum_hh = max(dcrop_ctrl_dum)	
		drop dcrop_ctrl_dum	
		rename dcrop_ctrl_dum_hh dcrop_ctrl_dum	
		keep hhid dcrop_ctrl_dum	
		duplicates drop // 41 out of 172 unique HHs	(other HHs have true zeros)	
		tempfile 10_3_2dry	
		save    `10_3_2dry', replace
	}

	//all crops	
	use `10_3_2rain', replace
	if "$ph" == "bl" {
		merge 1:1 hhid using `10_3_2dry'	
		drop _merge	
		gen crop_ctrl_dum = (rcrop_ctrl_dum == 1 | dcrop_ctrl_dum == 1) // general crop dummy		
	}
	else if "$ph" == "fu" {
		// very low match rate because only 199 households with dry crops. 191 have rain as well as dry crops
		gen crop_ctrl_dum = (rcrop_ctrl_dum == 1) // general crop dummy		
	}

	keep hhid crop_ctrl_dum
	label var crop_ctrl_dum "(2) Benef controls crop sale revenue"

	// capture all HHs, not just ones in repeat group (demographics includes all consenting HHs)
	merge 1:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(benef_pos) 
	replace crop_ctrl_dum = 0 if crop_ctrl_dum == .
		
	// trim beneficiary livestock value since some HHs still don't have benefs 06112020
	assert crop_ctrl_dum == 0 if benef_pos == .
	replace crop_ctrl_dum = .m if benef_pos == .
	drop benef_pos _merge
	tempfile 10_3_2
	save `10_3_2', replace
	
	local var_10_3_2 crop_ctrl_dum	
	local prod_agency_vars : list prod_agency_vars | var_10_3_2


	* 10.3.3 Beneficiary owns or manages a non-agricultural business (bus2_own bus2_manage)
	use "${constructed_${phase}}/business", clear
	keep hhid bus2_ben_dum
	duplicates drop
	isid hhid
	tempfile 10_3_3
	save    `10_3_3', replace

	local var_10_3_3 bus2_ben_dum 	
	local prod_agency_vars : list prod_agency_vars | var_10_3_3


	* 10.3.4 Beneficiary owns livestock (ani_count)
	if "$ph" == "fu" {
		use "${constructed_${phase}}/livestock", clear

		preserve
			keep hhid ani_ben_dum ani_sole_dum ani_chef_dum // keep livestock ownership dummy
			duplicates drop
			isid hhid
			// Some HHs don't exist in this dataset because has_livestock == 0 in main dta
			tempfile 10_3_4
			save    `10_3_4', replace

		restore
			// add var to list
			local var_10_3_4 ani_ben_dum
			local prod_agency_vars : list prod_agency_vars | var_10_3_4
	}
	
	*  Beneficiary controls revenue from the sale of livestock (ani_control*)
	if "$ph" == "fu" {
		preserve
			keep hhid ani_contr_ben_dum ani_contr_chef_dum
			duplicates drop 
			tempfile 10_3_5
			save    `10_3_5', replace
		restore
			
		// add var to list
		local var_10_3_5 ani_contr_ben_dum ani_contr_chef_dum
		local prod_agency_vars : list prod_agency_vars | var_10_3_5
	}	

	* Beneficiary stayed a night outside the village for a productive purpose, past 12 months
	use "${intermediate_${phase}}/members_long.dta", clear
	keep hhid *sleep* mem_pos

	rename sleep_why sleep_why_list
	split sleep_why_list, parse(" ")
	destring sleep_why_list*, replace 
	drop sleep_why_list
	
	qui ds sleep_why_list*
	local sleep_vars `r(varlist)'
	
	foreach var of varlist `sleep_vars' { 
		assert `var' == . if sleep == 0
	}

	gen sleep_productive = 0 if sleep == 1 // initiate productive overnight travel dummy
	foreach var of varlist `sleep_vars' {
		// sleep_why select_one options list has not changed across surveys
		replace sleep_productive = 1 if inlist(`var', 1, 4, 5, 6, 7, 8, 9) & /// productive purpose
										sleep_productive == 0 // and unchanged as of current loop
	}

	replace sleep_why_o = trim(itrim(strlower(sleep_why_o)))
	replace sleep_why_o = subinstr(sleep_why_o,"é", "e", .)
	replace sleep_why_o = subinstr(sleep_why_o,"ê", "e", .)
	replace sleep_why_o = subinstr(sleep_why_o,"è", "e", .)
	replace sleep_why_o = subinstr(sleep_why_o,"à", "a", .)
	replace sleep_why_o = subinstr(sleep_why_o,"ç", "c", .)

	// list productive sleep strings from "other" responses in local r(responses_prod)
	list sleep
	foreach response in `r(responses_prod)' {
		replace sleep_productive = 1 if sleep_why_o == `"`response'"' & ///
										sleep_productive == 0 // only if unchanged as of current loop
	}

	// bring in beneficiary position for each hh
	merge m:1 hhid using "${constructed_${phase}}/demographics.dta", ///
		keepusing(benef_pos) gen(_mergBEN)
	drop _mergBEN 
	order benef_pos, after (mem_pos)

	// generate dummy for when productive sleeper was the beneficiary
	gen sleep_productive_ben = (sleep_productive == 1 & (mem_pos == benef_pos))
	order sleep_productive_ben, after (sleep_productive)

	byso hhid : egen sleep_prod_dum = max(sleep_productive_ben)
	label var sleep_prod_dum "B.10.3 (6) Benef stayed productive night away last 12 mnths"

	order sleep_prod_dum, after (sleep_productive)
	assert inlist(sleep_prod_dum, 0, 1) // ensure sleep var is binary
	keep hhid sleep_prod_dum // keep livestock ownership count
	duplicates drop

	// add var to10 list
	local var_10_3_6 sleep_prod_dum
	local prod_agency_vars : list prod_agency_vars | var_10_3_6
	
	tempfile 10_3_6
	save    `10_3_6', replace

	// Bring all vars together and compute z index

					  use `10_3_1', clear
					  merge 1:1 hhid using `10_3_2', gen(_mCrops)
					  merge 1:1 hhid using `10_3_3', gen(_mNonAgBus)
	if "$ph" == "fu"  merge 1:1 hhid using `10_3_4', gen(_mOwnAni)
	if "$ph" == "fu"  merge 1:1 hhid using `10_3_5', gen(_mCtrlAni)
					  merge 1:1 hhid using `10_3_6', gen(_mSleepProd)

	dis "`prod_agency_vars'"

	//jump back to BL households to pull treatment variable. Use in z-scoring steps in PAP code
	merge 1:1 hhid using "${constructed_${phase}}/identification.dta", keepusing(pm_treatment)  gen(_mTreat)
	drop if _mTreat == 2 
	drop _mTreat

	// compute z-score index of 6 components above
	zindex `prod_agency_vars', gen(prod_agency_index) condition(pm_treatment == 0)  // not _trim since it exactly matches FU var (no missing components)
	label variable prod_agency_index "Productive Agency Z-index at $ph"

	keep hhid prod_agency_index `prod_agency_vars'
	tempfile 10_3_prod_agency
	save 	`10_3_prod_agency'

********************************************************************************
**** merge all sections
use `10_1and2', clear
merge 1:1 hhid using `10_3_prod_agency', nogen
isid hhid // confirm HH sample size

********************************************************************************
**** Create new indices

merge 1:1 hhid using "${constructed_${phase}}/identification.dta", ///
		gen(_mtreat) keepusing(pm_treatment)

********************************************************************************
** Control over earnings and activity and productive agency (B.10.5)

if "$ph" == "bl" {
local ctrl_earn_vars dec_pow_earn dec_pow_ag dec_pow_liv dec_pow_bus 			///
					 dec_could_earn emp_work crop_ctrl_dum bus2_ben_dum  		///
					 sleep_prod_dum	
}
else if "$ph" == "fu" {
	local ctrl_earn_vars dec_pow_earn dec_pow_ag dec_pow_liv dec_pow_bus 		///
						 dec_could_earn emp_work crop_ctrl_dum bus2_ben_dum 	///
						 ani_ben_dum ani_contr_ben_dum sleep_prod_dum
}

local omit emp_work
local ctrl_earn_vars : list ctrl_earn_vars - omit

zindex `ctrl_earn_vars', gen(ctrl_earn_index) condition(pm_treatment == 0)  // not _trim since it exactly matches FU var (no missing components)
label variable ctrl_earn_index "Control Earnings Z-index"

********************************************************************************
** Control over household resources

if "$ph" == "bl" {
	local ctrl_hh_vars 	dec_pow_spend dec_pow_large dec_pow_fert  dec_pow_edu 	///
						dec_could_spend dec_could_large dec_could_fert 	
}
else if "$ph" == "fu" {
	local ctrl_hh_vars 	dec_pow_spend dec_pow_large dec_pow_fert dec_pow_care 	///
						dec_pow_his_earn dec_pow_edu dec_could_spend 			///
						dec_could_large dec_could_fert dec_could_care
}

local ctrl_hh_vars : list ctrl_hh_vars - omit

zindex `ctrl_hh_vars' , gen(ctrl_hh_index) condition(pm_treatment == 0)  // not _trim since it exactly matches FU var (no missing components)
label variable ctrl_hh_index "Control HH Z-index"

// generate extensive margins for components
if "$ph" == "bl" {
	foreach var in dec_pow_earn  dec_pow_spend dec_pow_large 						///			  
				   dec_pow_fert  dec_pow_edu dec_pow_ag dec_pow_liv dec_pow_bus  	///     
				   dec_could_earn dec_could_spend dec_could_large dec_could_fert  	///
				   emp_work crop_ctrl_dum bus2_ben_dum  sleep_prod_dum {
		capture confirm var `var' // 
			gen `var'_d = !missing(`var')
		}	
}
else if "$ph" == "fu" {
	foreach var in dec_pow_earn dec_pow_his_earn dec_pow_spend dec_pow_large 					///			  
				   dec_pow_fert dec_pow_care dec_pow_edu dec_pow_ag dec_pow_liv dec_pow_bus  	///     
				   dec_could_earn dec_could_spend dec_could_large dec_could_fert dec_could_care ///
				   emp_work crop_ctrl_dum bus2_ben_dum ani_ben_dum ani_contr_ben_dum sleep_prod_dum {
		capture confirm var `var' // 
			gen `var'_d = !missing(`var')
		}	
}

local indices dec_weight_index dec_psblty_index prod_agency_index ctrl_earn_index ctrl_hh_index

foreach var in `indices' {
	gen `var'_d = !missing(`var')
	local lab : var label `var' // dep var label	
	label var `var'_d "Non-missing: `lab'"
}

********************************************************************************
** Export 

compress
save "${constructed_${phase}}/women_empowerment", replace
