/*Title: clean_miscellaneous_joint.do
  Purpose: preparing miscellaneous data for all hase  
  NOTE: Must be run after all other cleaning files are run
*/

	use "${constructed_${phase}}/demographics.dta", clear 
	keep hhid 
	merge 1:1 hhid using "${constructed_${phase}}/business.dta" 				, gen(_mBus)
	merge 1:1 hhid using "${constructed_${phase}}/livestock.dta" 				, gen(_mLiv)
	merge 1:1 hhid using "${constructed_${phase}}/agriculture.dta" 				, gen(_mAgr)
	
	merge 1:1 hhid using "${constructed_${phase}}/employment.dta" 				, gen(_mEmp1) 
	merge 1:1 hhid using "${constructed_${phase}}/ag_nonag_employment"			, gen(_mEmp2) 

	merge 1:1 hhid using "${constructed_${phase}}/activities.dta" 				, gen(_mAct)
	merge 1:1 hhid using "${constructed_${phase}}/labor_participation.dta" 		, gen(_mDay)
	
	gen 			__Gross_Income__= "Household Total income all activities"
	
	** div_inc_s
	egen 			div_inc_s = rowtotal(div_n_sal_12 div_n_na_12 div_ani div_ag_n) // 
	label var 		div_inc_s "Number of income sources"

	** tot_rev12_hh_xof
	/*
	* sum of: 
	1. Household Employment Revenues: tot_empl_rev12_hh_xof
	2. Household Business Revenues: tot_hh_rev12_98
	3. Household Agricultural Revenues: ag_hrv_12_xof_imp_98 
	4. Household Livestock Salue Value: tot_ani_hh_contr_98
	*/ 
	
	if "$ph" == "bl" local var 
	else             local var tot_ani_hh_contr_98
	
	egen 			tot_rev12_hh_xof = rowtotal(tot_empl_rev12_hh_xof tot_hh_rev12_98 ag_hrv_12_xof_imp_98 `var')
	label var 		tot_rev12_hh_xof "Total Household Revenues (1000 FCFA), 12 months"
	 
	** tot_rev12_ben_xof
	/*
	* sum of: 
	1. Beneficiary Employment Revenues: tot_empl_rev12_ben_xof
	2. Beneficiary Business Revenues: tot_ben_rev12_98
	3. Beneficiary Agricultural Revenues: ag_hrv_12_ben_xof_imp 
	4. Beneficiary Livestock Salue Value::tot_ani_ben_contr_98
	
	*/ 
	
	if "$ph" == "bl" local var 
	else             local var tot_ani_ben_contr_98
	
	egen 			tot_rev12_ben_xof = rowtotal(tot_empl_rev12_ben_xof tot_ben_rev12_98 ag_hrv_12_ben_xof_imp `var')
	label var 		tot_rev12_ben_xof "Total Beneficiary Revenues (1000 FCFA), 12 months"
	 
	** beneficiary share of total household revenues (%)
	gen 			share_ben_revenues = (tot_rev12_ben_xof/tot_rev12_hh_xof)*100
	label var 		share_ben_revenues "Individual Beneficiary Share of Total Household Revenues (%)"
	replace 		share_ben_revenues = 0 if share_ben_revenues == .
	
	** harvest value per day worked
	gen ag_r_hrv_day_ben_xof_imp  = ag_r_hrv_ben_xof_imp_98  / tot_ben_ag_days if tot_ben_ag_days > 0 
	replace ag_r_hrv_day_ben_xof_imp = 0 if tot_ben_ag_days == 0
	gen ag_r_hrv_day_chef_xof_imp = ag_r_hrv_chef_xof_imp_98 / tot_chef_ag_days if tot_chef_ag_days > 0
	replace ag_r_hrv_day_chef_xof_imp = 0 if tot_chef_ag_days == 0
	
	keep hhid div_inc_s tot_rev12_hh_xof tot_rev12_ben_xof share_ben_revenues ///
	          ag_r_hrv_day_ben_xof_imp ag_r_hrv_day_chef_xof_imp
	isid hhid 
	
	compress 
	save "${constructed_${phase}}/miscelleaneous.dta", replace 
	