	***************************************************************************
	*																		  *
	*			    PERCEPTION CASH TRANSFERS CHAD ASP IE 			  	      *
	*																		  *
	***************************************************************************

	use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear
 
	* selection process
	forvalues i = 1/6 {
		gen perc_whynotselect`i' = 0
		replace perc_whynotselect`i' = 1 if perc_whynotselect == `i'
	}
	
	* selection steps 
  
	* before program began 
	forvalues i = 1/3 {
		if `i' == 1 local add_name "poorer"
		if `i' == 2 local add_name "richer"
		if `i' == 3 local add_name "none"
		gen perc_hhdiff_`add_name' = 0
		replace perc_hhdiff_`add_name' = 1 if perc_hhdiff == `i'
	}
	
	* fair selection process 
	label value perc_equi
  
	* intra hh tension 
	forvalues i = 0/3 {
		gen perc_intrahh_tensions`i' = 0
		replace perc_intrahh_tensions`i' = 1 if perc_intrahh_tensions == `i'
	}
	
	* affected community relations 
	forvalues i = 0/2 {
		if `i' == 0 local add_name "improved"
		if `i' == 1 local add_name "deteriorated"
		if `i' == 2 local add_name "notaffected"
		gen perc_tensions_`add_name' = 0
		replace perc_tensions_`add_name' = 1 if perc_tensions == `i'
	}
	
	* deterioration still persists 
	label value perc_tens_per
 
	foreach var in 	perc_confiance 	/// trust
					perc_soutien 	/// support
					perc_engagement /// community involvement
					perc_proximite	/// community proximity 
					{
						forvalues i = 0/2 {
							gen `var'`i' = 0 
							replace `var'`i' = 1 if `var' == mod(`i' + 2, 3)
						}						
					}
					
	* went down, up or no change
	
	foreach var in 	per_price_aff_a /// food 
					per_price_aff_b /// non-food items
					per_price_aff_c /// livestock
					per_price_aff_d	/// ag inputs  
					per_price_aff_e	/// non-ag inputs  
					per_price_aff_f	/// ag_products 
					{
						forvalues i = 0/2 {
							gen `var'`i' = 0 
							replace `var'`i' = 1 if `var' == `i' + 1
						}	
					}
 
	* price increase impacted negatively 
	foreach var in 	per_price_aff2_a /// food 
					per_price_aff2_b /// non-food items
					per_price_aff2_c /// livestock
					per_price_aff2_d /// ag inputs  
					per_price_aff2_e /// non-ag inputs  
					per_price_aff2_f /// ag_products 
					{
						label value `var'
					}

	* Export dataset
	keep hhid 	perc_whynotselect perc_whynotselect? perc_select_steps_?		///
				perc_hhdiff_poorer perc_hhdiff_richer perc_hhdiff_none 			///
				perc_equi perc_intrahh_tensions? perc_tensions_improved 		///
				perc_tensions_deteriorated perc_tensions_notaffected 			///
				perc_tens_per perc_confiance? perc_soutien? perc_engagement? 	///
				perc_proximite? per_price_aff_* per_price_aff2_* perc_hhdiff    //
	
	compress 
	save "${constructed_${phase}}/perceptions_ct.dta", replace
  
	
  
  
  
  
  

  
  
  
  
  
  
  
  
  
  
