/*******************************************************************************
Title: 03_construct.do
This do file 
- merges all constructed datasets to create the final outcomes dataset
Input: all datasets in ${constructed}
Output: phase_country_outcomes.dta
*******************************************************************************/

	local files : dir "${constructed_${phase}}" files "*.dta"
	local omit1 
	local omit2 
	local omit3 

	local files : list files - omit1 // in case it's already created
	local files : list files - omit2 // in case it's already created
	local files : list files - omit3 // This dataset is not ID'd on the HH-level see reg_tables_other   
   

	/*
	* -----------------------  1. Master Dataset ----------------------------- *
	
	use  			"${preparation}/ctpam_soc", clear
	keep if	 		consent == 
	keep 			hhid consent  ben_i_FINAL treatHH_PAM_FINAL    soc_*
	gen 			__COHESION__="SOCIAL COHESION"
	order 			soc_reunion-soc_conflit2, last
	*/ 

	* Identification 		
	use "${constructed_${phase}}/identification.dta", clear
	order hhid, first
	capture drop language* 
	gen _IDENTIFICATION_ = "IDENTIFICATION", after(hhid)

* -----------------------------------------------------------------------------*
*							3. Demographics 										
* -----------------------------------------------------------------------------*

	* Demographics								   
	local this_file demographics.dta
	if `: list this_file in files' {
		gen _DEMOGRAPHICS_ = "DEMOGRAPHICS"
		mmerge hhid using "${constructed_${phase}}/demographics.dta", _merge(_mDEMOG) ///
			type(n:1) missing(nomatch) 
		assert _mDEMOG == 3
		drop _mDEMOG
	}

* -----------------------------------------------------------------------------*
*							4. Activities 										
* -----------------------------------------------------------------------------*

	* Activities 
	local this_file activities.dta
	if `: list this_file in files' {
		gen _ACTIVITIES = "ACTIVITIES"
		mmerge hhid using "${constructed_${phase}}/activities.dta", _merge(_mACTIV) /// 
			type(n:1) missing(nomatch) 
		assert _mACTIV == 3
		drop _mACTIV
	} 

* -----------------------------------------------------------------------------*
*							5. Employment 										
* -----------------------------------------------------------------------------*

	local this_file employment.dta
	if `: list this_file in files' {
		gen _EMPLOYMENT_ = "EMPLOYMENT"
		mmerge hhid using "${constructed_${phase}}/employment.dta", _merge(_mEMPL) ///
			type(n:1) missing(nomatch) 
		assert _mEMPL == 3
		drop _mEMPL
	}
	
	local this_file ag_nonag_employment.dta
	if `: list this_file in files' {
		gen _AG_NONAG_EMPLOYMENT = "AG NON-AG EMPLOYMENT"
		mmerge hhid using "${constructed_${phase}}/ag_nonag_employment.dta", _merge(_mAG_EMPL) ///
			type(n:1) missing(nomatch) 
		assert _mAG_EMPL == 3
		drop   _mAG_EMPL
	}
		
* -----------------------------------------------------------------------------*
*							6. Business 										
* -----------------------------------------------------------------------------*

	local this_file business.dta
	if `: list this_file in files' {
		gen _BUSINESS_ = "BUSINESS"
		mmerge hhid using "${constructed_${phase}}/business.dta", _merge(_mBUS1) ///
			type(n:1) missing(nomatch) 
		assert _mBUS1 == 3	
		drop   _mBUS1		
	}

* -----------------------------------------------------------------------------*
*								7. Finance									   *
* -----------------------------------------------------------------------------*

	local this_file finance.dta
	if `: list this_file in files' {
		gen _FINANCE_ = "FINANCE"
		mmerge hhid using "${constructed_${phase}}/finance.dta", _merge(_mFIN1) ///
			type(n:1) missing(nomatch)
		assert _mFIN1 == 3
		drop   _mFIN1 		
	}

* -----------------------------------------------------------------------------*
*								 8. Housing									   *
* -----------------------------------------------------------------------------*

	local this_file housing.dta
	if `: list this_file in files' {
		gen _HOUSING_ = "HOUSING"
		mmerge hhid using "${constructed_${phase}}/housing.dta", _merge(_mHOU) ///
			type(n:1) missing(nomatch)
		assert _mHOU == 3
		drop _mHOU	
	}

* -----------------------------------------------------------------------------*	
*								9. Psychology/Mental						   *
* -----------------------------------------------------------------------------*

	local this_file psychology.dta
	if `: list this_file in files' {
		gen _PSYCHOLOGY_ = "PSYCHOLOGY"
		mmerge hhid using "${constructed_${phase}}/psychology.dta", _merge(_mPSYC) ///
			type(n:1) missing(nomatch)
		assert _mPSYC == 3
		drop _mPSYC
	}
	

* -----------------------------------------------------------------------------*	
*								11.SHOCKS								   *
* -----------------------------------------------------------------------------*

	local this_file shocks.dta
	if `: list this_file in files' {
		gen SHOCKS = "SHOCKS"
		mmerge hhid using "${constructed_${phase}}/shocks.dta", _merge(_mSHO1) ///
			type(n:1) missing(nomatch)
		assert _mSHO1 == 3
		drop _mSHO1	
	}
	
* -----------------------------------------------------------------------------*
*								 12. Consumption								   *
* -----------------------------------------------------------------------------*

	local this_file consumption.dta
	if `: list this_file in files' {
		gen _CONSUMPTION_ = "CONSUMPTION"
		mmerge hhid using "${constructed_${phase}}/consumption.dta", _merge(_mCONSUM) ///
			type(n:1) missing(nomatch)
		assert _mCONSUM == 3
		drop  _mCONSUM
	}
	
* -----------------------------------------------------------------------------*	
*								13.Food Security							   *
* -----------------------------------------------------------------------------*

	local this_file foodsecurity.dta
	if `: list this_file in files' {
		gen _FOODSEC_ = "FOODSECURITY"
		mmerge hhid using "${constructed_${phase}}/foodsecurity.dta", _merge(_mFSEC1) ///
			type(n:1) missing(nomatch)
		assert _mFSEC1 == 3
		drop _mFSEC1		
	}	
	
* -----------------------------------------------------------------------------*
*									14. Assets								   *
* -----------------------------------------------------------------------------*

	local this_file assets.dta
	if `: list this_file in files' {
		gen _ASSETS_ = "ASSETS"
		mmerge hhid using "${constructed_${phase}}/assets.dta", _merge(_mASSETS1) ///
			type(n:1) missing(nomatch)
		assert _mASSETS1 == 3
		drop _mASSETS1
	}
	
* -----------------------------------------------------------------------------*
*								 15. Livestock								   *
* -----------------------------------------------------------------------------*

	local this_file livestock.dta
	if `: list this_file in files' {
		gen _LIVESTOCK_ = "LIVESTOCK"
		mmerge hhid using "${constructed_${phase}}/livestock.dta", _merge(_mLIV) ///
			type(n:1) missing(nomatch)
		assert _mLIV == 3
		drop _mLIV
	}
	
* -----------------------------------------------------------------------------*
*								16. Agriculture								   *
* -----------------------------------------------------------------------------*

	local this_file agriculture.dta
	if `: list this_file in files' {
		gen _AGRICULTURE_ = "AGRICULTURE"
		mmerge hhid using "${constructed_${phase}}/agriculture.dta", _merge(_mAGRIC1) ///
			type(n:1) missing(nomatch)
		assert _mAGRIC1 == 3
		drop _mAGRIC1 
	}
	
* -----------------------------------------------------------------------------*
*							17. PROGRAMS									   *
* -----------------------------------------------------------------------------*

	local this_file programs.dta
	if `: list this_file in files' {
		gen _PROGRAMS_ = "PROGRAMS"
		mmerge hhid using "${constructed_${phase}}/programs.dta", _merge(_mPROG) ///
			type(n:1) missing(nomatch)
		assert _mPROG == 3
		drop _mPROG
	}
	
* -----------------------------------------------------------------------------*
*							18. Transfers/Remittances						   *
* -----------------------------------------------------------------------------*

	local this_file transfers.dta
	if `: list this_file in files' {
		gen _TRANSFERS_ = "TRANSFERS"
		mmerge hhid using "${constructed_${phase}}/transfers.dta", _merge(_mTRF) ///
			type(n:1) missing(nomatch)
		assert _mTRF == 3
		drop _mTRF
	}
	
* -----------------------------------------------------------------------------*
*							19. PREFERENCES									   *
* -----------------------------------------------------------------------------*

	local this_file preferences.dta
	if `: list this_file in files' {
		gen _PREFERENCES_ = "PREFERENCES"
		mmerge hhid using "${constructed_${phase}}/preferences.dta", _merge(_mPREF) ///
			type(n:1) missing(nomatch)
		assert _mPREF == 3
		drop _mPREF	
	}
	
* -----------------------------------------------------------------------------*
*							20. Labor Participation							   *
* -----------------------------------------------------------------------------*

	local this_file labor_participation.dta
	if `: list this_file in files' {
		gen _LABOR_PARTICIPATION = "LABOR PARTICIPATION"
		mmerge hhid using "${constructed_${phase}}/labor_participation.dta", _merge(_mLab) ///
			type(n:1) missing(nomatch)
		assert _mLab == 3
		drop _mLab
	}	
	
* -----------------------------------------------------------------------------*	
*								21. Women Empowerment						   *
* -----------------------------------------------------------------------------*

	local this_file women_empowerment.dta
	if `: list this_file in files' {
		gen _WOMEN_EMPOWERMENT = "WOMEN EMPOWERMENT"
		mmerge hhid using "${constructed_${phase}}/women_empowerment.dta", _merge(_mWEMP) ///
			type(n:1) missing(nomatch)
		assert _mWEMP == 3
		drop _mWEMP
	}
	
* -----------------------------------------------------------------------------*
*					22. SOCIAL WELLBEING   									   *
* -----------------------------------------------------------------------------*

	local this_file social_wellbeing.dta
	if `: list this_file in files' {
		gen _SOC_WELL_ = "SOCIAL WELL-BEING"
		mmerge hhid using "${constructed_${phase}}/social_wellbeing.dta", _merge(_mSOCW) ///
			type(n:1) missing(nomatch)
		assert _mSOCW == 3
		drop _mSOCW	
	}	

* -----------------------------------------------------------------------------*
*							23. MISCELLEANEOUS	 							   *
* -----------------------------------------------------------------------------*

	local this_file miscelleaneous.dta
	if `: list this_file in files' {
		gen _MISCELLEANEOUS_ = "MISCELLEANEOUS"
		mmerge hhid using "${constructed_${phase}}/miscelleaneous.dta", _merge(_mMISC) ///
			type(n:1) missing(nomatch)
		assert _mMISC == 3
		drop   _mMISC	
	}	
	
* -----------------------------------------------------------------------------*
*							24. CT PERCEPTIONS 							   *
* -----------------------------------------------------------------------------*

	local this_file perceptions_ct.dta
	if `: list this_file in files' {
		gen _CT_PERCEPTIONS_ = "CT PERCEPTIONS"
		mmerge hhid using "${constructed_${phase}}/perceptions_ct.dta", _merge(_mCTPERC) ///
			type(n:1) missing(nomatch)
		assert _mCTPERC == 3
		drop   _mCTPERC	
	}	
	
* -----------------------------------------------------------------------------*
*					25. MARITAL STATUS BEN 									   *
* -----------------------------------------------------------------------------*

	local this_file marital_status_ben.dta
	if `: list this_file in files' {
		gen _MAR_STATUS_ = "MARITAL STATUS"
		mmerge hhid using "${constructed_${phase}}/marital_status_ben.dta", _merge(_mMAR) ///
			type(n:1) missing(nomatch)
		assert _mMAR == 3
		drop _mMAR	
	}

* -----------------------------------------------------------------------------*
*					26. MEASURES	 									   	   *
* -----------------------------------------------------------------------------*

	local this_file measures.dta
	if `: list this_file in files' {
		gen _MEASURE_ = "MEASURE"
		mmerge hhid using "${constructed_${phase}}/measures.dta", _merge(_mMEASU) ///
			type(n:1) missing(nomatch)
		assert _mMEASU == 3
		drop _mMEASU	
	}
	
* -----------------------------------------------------------------------------*
*							SAVING CONSTRUCTED DATASET 						   *
* -----------------------------------------------------------------------------*
	
	isid hhid 
	compress
	save 		"${constructed_${phase}}/chad_outcomes_${ph}", replace