/*******************************************************************************
Title: 04_merge_phases.do
This do-file is about merging and assembling outcomes into final datasets 
(across phases)

Input:  phase_country_outcomes.dta
Output: phase_country_outcomes_with_bl.dta
*******************************************************************************/
		
    * ******************************************************************** *
    * Select Baseline Variables  
    * ******************************************************************** * 	
   
   	use "${constructed_Baseline}/chad_outcomes_bl", clear

	* consumption 
	local baseline_vars_1 	z_food_day_eq_xof z_nonfood_day_eq_xof 				///
							z_FIES_rvrs_raw  z_FCS_W z_diversity_score 			///
							food_index4 food_index5 food_index6 				///
							consum_day_eq_xof food_day_eq_xof 					///
							consum_day_pc_xof food_day_pc_xof					///
							consum_day_xof food_day_xof							///
							nonfood_day_eq_xof edu_day_eq_xof health_day_eq_xof	/// 
							nonfood_day_xof edu_day_xof health_day_xof			///
							nonfood_day_pc_xof edu_day_pc_xof health_day_pc_xof	///
							food_day_prod_eq_xof food_day_buy_eq_xof 			///
							food_day_gift_eq_xof								///					
							FIES_rvrs_raw diversity_score FCS
			
	* revenues 
	local baseline_vars_2   share_ben_revenues
	
	* days 
	local baseline_vars_3	tot_chef_bus_days tot_chef_ag_days 					/// tot_chef_liv_days tot_ben_liv_days
							tot_ben_bus_days tot_ben_ag_days 					///
							tot_hhlc_ag_days tot_hhlb_ag_days					///
							tot_chef_ag_days_omchef tot_ben_ag_days_omben		///	
							tot_hhlc_ag_days_omchef tot_hhlb_ag_days_omben
	* agriculture 
	local baseline_vars_4	hhh_ag_12 ag_hrv_12_chef_xof_imp_98   				///
							ag_plot_n_chef ag_plot_ha_chef 						///
							ctben_ag_12 ag_hrv_12_ben_xof_imp 	    			///
							ag_plot_n_benef ag_plot_ha_benef					///
							ag_plot_n ag_plot_ha ag_hrv_12_xof_imp_98 			///
							ag_input_index ag_r_paidlab_d						///
							ag_r_seeds_d ag_r_fert_d ag_r_pest_d				///
							Sésame_d Arachide_d Mil_d Sorgho_d Sésame_sold_d 	///
							Arachide_sold_d Mil_sold_d Sorgho_sold_d			///
							ag_r_hrv_ben_xof_imp_98	   							///
							ag_r_hrv_day_ben_xof_imp 							///
							ag_r_hrv_chef_xof_imp_98  							///
							ag_r_hrv_day_chef_xof_imp ag_r_hrv_xof_imp_98					
	* finance  
	local baseline_vars_6	saving_xof 											/// tot_bt_d tot_tontine_d tot_tontine_bt_d
							tot_cred_out_xof tot_cred_amt_xof total_has_rd 		///
							tot_cred_amt_d tot_cred_out_d 						///
							cred_amt_inf_d cred_amt_for_d
	* livestock 
	local baseline_vars_7	hhh_liv_12 ctben_liv_12 div_ani   					///  tot_ani_chef_contr_98 tot_ani_ben_contr_98 tot_ani_count_tlu_chef tot_ani_count_tlu_ben

	* business 
	local baseline_vars_8	hhh_na_12 tot_chef_rev12_98 tot_chef_pro12_98 		///
							na_bus2_op_wn_12_chef bus_assval_98_chef 			///
							tot_busmths_uniq_chef business_index_chef4 			/// input_regional_market_chef business_closure_chef
							ctben_na_12 tot_ben_rev12_98 tot_ben_pro12_98 		///
							na_bus2_op_wn_12_ben bus_assval_98_ben 				///
							tot_busmths_uniq_ben business_index_ben4 			/// input_regional_market_ben business_closure_ben
							bus2_dum na_bus2_op_wn_12 tot_hh_rev12_98 			///
							tot_hh_pro12_98 bus_assval_98 						///
							tot_busmths_uniq bus_activity_index2				///
							na_bus2_op_wn_12_joint_s
							
	* employment 
	local baseline_vars_9	sal_empl_ben tot_empl_time_month_ben 				///
							tot_empl_rev12_ben_xof ag_empl_ben 					///
							tot_ag_time_month_ben tot_ag_empl_rev12_ben_xof   	///
							nonag_empl_ben tot_nonag_time_month_ben 			///
							tot_nonag_empl_rev12_ben_xof sal_empl_chef 			///
							tot_empl_time_month_chef tot_empl_rev12_chef_xof 	///
							ag_empl_chef tot_ag_time_month_chef 				///
							tot_ag_empl_rev12_chef_xof nonag_empl_chef			/// 
							tot_nonag_time_month_chef 							///
							tot_nonag_empl_rev12_chef_xof
	
	* psychology 						
	local baseline_vars_16	soc_stand_index 	 								/// social_support_index fin_supp_index_2 soc_cohsn_index collective_action_index 
							ment_hlth_index gse_index future_expct_index		/// Psychological 		
							prod_agency_index ctrl_hh_index  					/// intrahh_vars_index
							less_depressed less_disability stair_satis_today 	/// 
							gse1 gse3 gse4 gse7 gse8 gse9 ros4 					/// 
							stair_status_future_new stair_satis_future_new 		/// 				   
							stair_respect_new stair_opinion_new 				/// 
							stair_status_today									/// 
							emp_work crop_ctrl_dum bus2_ben_dum sleep_prod_dum 	/// 
							dec_pow_spend dec_pow_large dec_pow_fert 			/// 
							dec_pow_edu dec_could_spend dec_could_large			///  
							dec_could_fert 										//							
											
	local extra 			same_cb hhh_fem trans_in_d tot_trans_in_xof 		///
							non_livestock_index mem_n equiv_n
				
	local baseline_vars_all `baseline_vars_1' 	///
							`baseline_vars_2'	///
							`baseline_vars_3'	///
							`baseline_vars_4'	///
							`baseline_vars_6'	///
							`baseline_vars_7'	///
							`baseline_vars_8'	///
							`baseline_vars_9'	///
							`baseline_vars_16'  ///
							`extra'
	
	**** renaming baseline vars 
	foreach v in `baseline_vars_all ' {
		rename `v' `v'_bl
	}
	
	capture ds *_bl
	keep hhid `r(varlist)' 
	
	tempfile baseline_controls
	save 	`baseline_controls'
	
	
    * ******************************************************************** *
    * Merge Baseline Variables  
    * ******************************************************************** * 	
	
	use "${constructed_Followup}/chad_outcomes_fu", clear 
	
	gen _CONTROLS_ = "CONTROLS"
	merge 1:1 hhid using `baseline_controls', gen(_mBL)
		
	* dropping households at baseline but not FU
	drop if _mBL == 2				
	drop _mBL 		
		
	/*
	Dealing with missing baseline values
	FU sample was larger than baseline
	We replace missing baseline values with the average value at baseline 
	among each of the 5 household treatment groups
	*/ 
		
	* renaming variables that are too long for for-loop below
	rename tot_nonag_empl_rev12_ben_xof_bl 		empl_na_rev12_ben_bl
	rename tot_nonag_empl_rev12_chef_xof_bl 	empl_na_rev12_chef_bl
	rename ag_hrv_12_chef_xof_imp_98_bl 		ag_harv_chef_bl

	capture ds *_bl
	local bl_controls `r(varlist)'
		
	foreach v in `bl_controls' {
		forval i = 1/5 {
			egen `v'_m`i' = mean(`v') 	if treatment_status == `i'
			replace `v' = `v'_m`i' 		if treatment_status == `i' & missing(`v')
			drop `v'_m`i'
		}
	}
		
	* rename back
	rename empl_na_rev12_ben_bl 	tot_nonag_empl_rev12_ben_xof_bl 
	rename empl_na_rev12_chef_bl 	tot_nonag_empl_rev12_chef_xof_bl 
	rename ag_harv_chef_bl 			ag_hrv_12_chef_xof_imp_98_bl 
	
	compress 
	save "${data_dir}/allrounds_CHAD_hh.dta", replace 
	
	
    * ******************************************************************** *
    * Add attrition to baseline dataset 
    * ******************************************************************** * 
   
	foreach rd in bl fu {
		if "`rd'" == "bl" {
			use "${constructed_Baseline}/chad_outcomes_bl", clear
		}
		else { 
			// Add fu only for attrition section in balance table 
			use "${data_dir}/allrounds_CHAD_hh.dta", clear
			keep hhid consent 
		}
		
		assert consent != 0
		gen survey_`rd' = 1
		
		* Attrition 
		preserve 
			use "${ed}/sample_`rd'", clear 
			drop pm_treatment
			
			* PM Treatment Dummy
			gen pm_treatment = . 
			replace pm_treatment = 0 if treatment_status == 4
			replace pm_treatment = 1 if treatment_status == 1
			
			* Pooled Spillover Dummy
			gen ct_spillover_dummy = . 
			replace ct_spillover_dummy = 0 if treatment_status == 4
			replace ct_spillover_dummy = 1 if treatment_status == 2
			
			* CT Spillover Dummy
			gen non_ct_spillover_dummy = . 
			replace non_ct_spillover_dummy = 0 if treatment_status == 5
			replace non_ct_spillover_dummy = 1 if treatment_status == 3
			
			* Non-CT Spillover Dummy
			gen both_spillover_dummy = . 
			replace both_spillover_dummy = 0 if treatment_status == 4 | treatment_status == 5
			replace both_spillover_dummy = 1 if treatment_status == 2 | treatment_status == 3
			
			tempfile attrition_`rd'
			save 	`attrition_`rd''
		restore 
		
		merge 1:1 hhid using `attrition_`rd'', nogen 
		gen attrition_`rd' = (survey_`rd' == 1) if sampled_`rd' == 1
		
		tempfile data_attrition_`rd'
		save 	`data_attrition_`rd''
	}
	
	use `data_attrition_bl', clear 
	append using `data_attrition_fu', gen(_fu_only_for_attrition)
	
	// attrition rate at fu of surveyed HH at BL
	bysort hhid: egen survey_fu_all = total(survey_fu)
	gen attrition_blfu = (survey_fu_all == 1) if survey_bl == 1 
	drop survey_fu_all 
	
	* Label 
	label define treat_1 0 "Control" ///
						 1 "Treatment", modify
	label values pm_treatment treat_1

	label define treat_2 0 "Control" ///
						 1 "Pooled Spillover", modify
	label values both_spillover_dummy treat_2

	label define treat_3 0 "Control" ///
						 1 "CT Spillover", modify
	label values ct_spillover_dummy treat_3

	label define treat_4 0 "Control" ///
						 1 "Non-CT Spillover", modify
	label values non_ct_spillover_dummy treat_4
		
	compress 
	save "${data_dir}/baseline_CHAD_hh.dta", replace
		
		
	* ******************************************************************** *
	* Add sample weights (followup based) (in levels)
	* ******************************************************************** * 
   
	use "${ed}/sample_pop", clear 
   
	* weights for G2 for pooled spillover 
	// such as share of G2 in G2 + G3 is equivalent to share of G4 in G4 + G5 
    // use effective FU sample
	merge 1:1 hhid using "${data_dir}/allrounds_CHAD_hh.dta", keepus(hhid) gen(fu_eff)
	count if fu_eff == 3 & sampled_fu == 1 & inlist(treatment_status, 2)
	local ct_g2    = `r(N)'
	count if fu_eff == 3 & sampled_fu == 1 & inlist(treatment_status, 3)
	local ct_g3    = `r(N)'	
	count if fu_eff == 3 & sampled_fu == 1 & inlist(treatment_status, 4)
	local ct_g4    = `r(N)'
	count if fu_eff == 3 & sampled_fu == 1 & inlist(treatment_status, 4, 5)
	local ct_g4_g5 = `r(N)'	
	local shr = `ct_g4' / `ct_g4_g5'
	gen weight_g2 = 1
	replace weight_g2 = (`shr' / (1 - `shr')) * (`ct_g3' / `ct_g2') if treatment_status == 2
   
	* weights for each treatment group: overall
	bysort treatment_status: gen trtgrp_pop_n = _N 
	bysort treatment_status: egen trtgrp_samfu_n = total(sampled_fu)
	gen prob_samfu_ovrl = trtgrp_samfu_n / trtgrp_pop_n
	gen weight_ovrl = 1 / prob_samfu_ovrl
	
	* weights for each treatment group: village
	bysort treatment_status p_village: gen  trtgrp_pop_vil_n = _N 
	bysort treatment_status p_village: egen trtgrp_samfu_vil_n = total(sampled_fu)
	gen prob_samfu_vil = trtgrp_samfu_vil_n / trtgrp_pop_vil_n
	gen weight_vil = 1 / prob_samfu_vil

	* check weight distribution (not done overall for weight_ovrl - only 5 values)
	keep if sampled_fu == 1
	gen unit_vil_trt = p_village + treatment_status * 1000
	duplicates drop unit_vil_trt, force
	qui tab weight_vil  // some outliers 
	
	* trimming outliers weight > p75 + 5 * IQR
	egen p75_ppp = pctile(weight_vil), p(75)
	egen iqr_ppp = iqr(weight_vil)
	gen outl = 1 if weight_vil > p75_ppp + 5 * iqr_ppp
	qui sum weight_vil if outl != 1 
	replace weight_vil = `r(max)' if outl == 1 
	
	keep p_village treatment_status weight_ovrl weight_vil weight_g2
	tempfile weight 
	save 	`weight'
	
	* save weights 
	use "${data_dir}/allrounds_CHAD_hh.dta", clear
	merge m:1 p_village treatment_status using `weight', nogen 
	save "${data_dir}/allrounds_CHAD_hh.dta", replace 
	
	use "${data_dir}/baseline_CHAD_hh.dta", clear
	merge m:1 p_village treatment_status using `weight', nogen 
	save "${data_dir}/baseline_CHAD_hh.dta", replace 
	