/*******************************************************************************
Title: MASTER_CHAD.do
This do-file is the master do-file for the project.

Stata Version 15
*******************************************************************************/

	clear
	set more off
	clear matrix
	clear mata
	local version_number 15.0
	version `version_number'
	set matsize 500
	set maxvar 10000
	
	* ******************************************************************** *
	* Define global user path 
	* ******************************************************************** *

	* User 
	global package_dir "C:\WBG\github\196\chad_replication_package_final_corrections\chad_replication_package"						// Package
	global data_dir "${package_dir}/Data"		  	 							// Data
	global git_dir	"${package_dir}/Analysis"    								// Code 
sysdir set PLUS "${package_dir}\ado"
set varabbrev on
	* ******************************************************************** *
	* Set Globals & Programs
	* ******************************************************************** *
   
    * Standardize settings accross users 
    cap which ietoolkit
    if _rc == 111 ssc install ietoolkit
    ieboilstart, versionnumber(`version_number') adopath("${git_dir}/Do/00_settings", strict)  
   
	* Set globals 
	foreach ph in Baseline Followup {
		global phase `ph'
		qui do "${git_dir}/Do/00_globals.do"  
	}
	
	* Set programs 
		qui do "${do_folder}/00_programs.do"

	* ******************************************************************** *
	* Run Preparation  
	* ******************************************************************** *	 
	
	* Preparing 
	foreach ph in Baseline Followup { 
		global phase `ph'
		qui do "${do_folder}/00_globals.do" 
		qui do "${do_folder}/01_prepare.do" 
	}	 
	 
	* ******************************************************************** *
	* Run Cleaning & Construction
	* ******************************************************************** *
 
	* Cleaning & Construction
	foreach ph in Baseline Followup {
		global phase `ph'
		qui do "${do_folder}/00_globals.do" 
		qui do "${do_folder}/02_cleaning.do"
		qui do "${do_folder}/03_construct.do"
	}
	
	* ******************************************************************** *
	* Run Analysis 
	* ******************************************************************** *	

	* main analysis do-file 
	do "${do_folder}/04_merge_phases.do"
	do "${do_folder}/05_regs.do"	
	do "${do_folder}/06_balance_and_attrition.do"
	do "${do_folder}/07_cba.do"	
	